<?php
/**
 *  
 * @package    YoloTheme
 * @version    1.0.0
 * @created    18/12/2015
 * @author     Administrator <admin@yolotheme.com>
 * @copyright  Copyright (c) 2016, YoloTheme
 * @license    http://opensource.org/licenses/gpl-2.0.php GPL v2 or later
 * @link       http://yolotheme.com
 */
/*================================================
GET UPLOAD URL, DIRECTOR
================================================== */
if (!function_exists('yolo_upload_dir_name')):
	function yolo_upload_dir_name() {
		return apply_filters( 'yolo_upload_dir_name', 'yolo-custom-css' );
	}
endif;

if (!function_exists('yolo_upload_dir')):
	function yolo_upload_dir() {
		$upload_dir = wp_upload_dir();

		return $upload_dir['basedir'] . '/' . yolo_upload_dir_name();
	}
endif;

if (!function_exists('yolo_upload_url')):
	function yolo_upload_url() {
		$upload_dir = wp_upload_dir();

		$url = $upload_dir['baseurl'];
		if ( $upload_dir['baseurl'] && is_ssl() ) {
	        $url = str_replace( 'http://', 'https://', $upload_dir['baseurl'] );
	    }
		return $url . '/' . yolo_upload_dir_name();
	}
endif;

if (!function_exists('yolo_create_upload_dir')):
	function yolo_create_upload_dir( $wp_filesystem = null ) {
		if( empty( $wp_filesystem ) ) {
			return false;
		}

		$upload_dir = wp_upload_dir();
		global $wp_filesystem;

		$yolo_upload_dir = $wp_filesystem->find_folder( $upload_dir['basedir'] ) . yolo_upload_dir_name();
		if ( ! $wp_filesystem->is_dir( $yolo_upload_dir ) ) {
			if ( wp_mkdir_p( $yolo_upload_dir ) ) {
				return $yolo_upload_dir;
			}

			return false;
		}

		return $yolo_upload_dir;
	}
endif;
/*================================================
YOLO GET TEMPLATE PART
================================================== */
if (!function_exists('yolo_get_template')) {
	function yolo_get_template( $template, $name = null ) {
		get_template_part( 'templates/' . $template, $name);
	}
}

/*================================================
YOLO GET POST META
================================================== */
if ( !function_exists( 'yolo_get_post_meta' ) ) {
	function yolo_get_post_meta( $id, $key = "", $single = false ) {

		$GLOBALS['yolo_post_meta'] = isset( $GLOBALS['yolo_post_meta'] ) ? $GLOBALS['yolo_post_meta'] : array();
		if ( ! isset( $id ) ) {
			return;
		}
		if ( ! is_array( $id ) ) {
			if ( ! isset( $GLOBALS['yolo_post_meta'][ $id ] ) ) {
				$GLOBALS['yolo_post_meta'][ $id ] = get_post_meta( $id );
			}
			if ( ! empty( $key ) && isset( $GLOBALS['yolo_post_meta'][ $id ][ $key ] ) && ! empty( $GLOBALS['yolo_post_meta'][ $id ][ $key ] ) ) {
				if ( $single ) {
					return maybe_unserialize( $GLOBALS['yolo_post_meta'][ $id ][ $key ][0] );
				} else {
					return array_map( 'maybe_unserialize', $GLOBALS['yolo_post_meta'][ $id ][ $key ] );
				}
			}

			if ( $single ) {
				return '';
			} else {
				return array();
			}

		}

		return get_post_meta( $id, $key, $single );
	}
}
/* ==================================================
YOLO GET USER MENU LIST
================================================== */
if ( !function_exists( 'yolo_get_menu_list' ) ){
	function yolo_get_menu_list() {

		if ( !is_admin() ) {
			return array();
		}

		$user_menus = get_terms( 'nav_menu', array( 'hide_empty' => false ) );

		$menu_list = array();

		foreach ( $user_menus as $menu ) {
			$menu_list[ $menu->term_id ] = $menu->name;
		}

		return $menu_list;
	}
}

/* ==================================================
YOLO GET SIDEBAR LIST
================================================== */
if ( !function_exists( 'yolo_get_sidebar_list' ) ){
	function yolo_get_sidebar_list() {

		if ( !is_admin() ) {
			return array();
		}

		$sidebar_list = array();
		foreach ( $GLOBALS['wp_registered_sidebars'] as $sidebar ) {
			$sidebar_list[ $sidebar['id'] ] = ucwords( $sidebar['name'] );
		}

		return $sidebar_list;
	}
}

/* ==================================================  
YOLO CHECK IS BLOG PAGE
================================================== */
if ( !function_exists( 'yolo_is_blog_page' ) ){
	function yolo_is_blog_page() {
		global $post;

		//Post type must be 'post'.
		$post_type = get_post_type($post);

		return (
			( is_home() || is_archive() || is_single() )
			&& ($post_type == 'post')
		) ? true : false ;
	}
}

/* ================================================== 
YOLO ATTRIBUTE VALUE
================================================== */
if ( !function_exists( 'yolo_the_attr_value' ) ){
	function yolo_the_attr_value($attr) {
		foreach ($attr as $key) {
			echo esc_attr($key) . ' ';
		}
	}
}

/*================================================
YOLO CONVERT COLOR HEXA TO RGBA
================================================== */
if (!function_exists('yolo_hex2rgba')) {
	function yolo_hex2rgba($hex, $opacity) {
		$hex = str_replace("#", "", $hex);

		if(strlen($hex) == 3) {
			$r = hexdec(substr($hex,0,1).substr($hex,0,1));
			$g = hexdec(substr($hex,1,1).substr($hex,1,1));
			$b = hexdec(substr($hex,2,1).substr($hex,2,1));
		} elseif(strlen($hex) == 6) {
			$r = hexdec(substr($hex,0,2));
			$g = hexdec(substr($hex,2,2));
			$b = hexdec(substr($hex,4,2));
		}
		else {
			$r = 0;
			$g = 0;
			$b = 0;
			$opacity = 0;
		}

		return sprintf('rgba(%s,%s,%s,%s)', $r, $g, $b, $opacity);
	}
}

/*================================================
YOLO LIMIT WORDS
================================================== */
if( ! function_exists('yolo_limit_words') ) {
	function yolo_limit_words($string, $word_limit) {
		$words = preg_split('/\s+/', $string);

    	return implode(" ",array_splice($words,0,$word_limit));
	}
}

/*================================================
YOLO GET CURRENT PAGE URL
================================================== */
if (!function_exists('yolo_endsWith')) {
	function yolo_endsWith($haystack,$needle,$case=true)
	{
		$expectedPosition = strlen($haystack) - strlen($needle);

		if ($case)
			return strrpos($haystack, $needle, 0) === $expectedPosition;

		return strripos($haystack, $needle, 0) === $expectedPosition;
	}
}

/*================================================
YOLO GET SEARCH CATEGORY DROPDOWN
================================================== */
if (!function_exists('yolo_categories_binder')) {
	function yolo_categories_binder($categories, $parent,$class= 'search-category-dropdown', $is_anchor = false, $show_count = false) {
		$index = 0;
		$output = '';
		if (empty($categories) || !array($categories)) {
			return $output;
		}
		foreach ($categories as $key => $term) {
			if (empty($term) || (!isset($term->parent))) {
				continue;
			}
			if (((int)$term->parent !== (int)$parent) || ($parent === null) || ($term->parent === null)) {
				continue;
			}

			if ($index == 0) {
				$output = '<ul>';
				if ($parent == 0) {
					$output = '<ul class="'. esc_attr($class) .'">';
				}
			}

			$output .= '<li>';
			$output .= sprintf('%s%s%s',
				$is_anchor ? '<a href="' .  get_term_link((int)$term->term_id, 'product_cat') . '" title="' . esc_attr($term->name) . '">' : '<span data-id="' . esc_attr($term->term_id) . '">',
				$show_count ? esc_html($term->name.' (' . $term->count . ')') : esc_html($term->name),
				$is_anchor ? '</a>' : '</span>'
				);
			$output .= yolo_categories_binder($categories, $term->term_id,$class, $is_anchor,$show_count);
			$output .= '</li>';
			$index++;
		}

		if (!empty($output)) {
			$output .= '</ul>';
		}

		return $output;
	}
}


/*================================================
GET SIDEBAR MENU CANVAS
http://bavotasan.com/2011/adding-a-search-bar-to-the-nav-menu-in-wordpress/
================================================== */
if (!function_exists('yolo_add_canvas_menu_region')) {
	function yolo_add_canvas_menu_region() {
		?>
		<nav class="yolo-canvas-menu-wrapper" id = "off-canvas">
			<a href="#" class="yolo-canvas-menu-close"><i class="fa fa-close"></i></a>
			<div class="yolo-canvas-menu-inner sidebar">
				<?php if (is_active_sidebar('canvas-menu')) { dynamic_sidebar('canvas-menu'); } ?>
			</div>
		</nav>
		<?php
	}
	add_action('yolo_after_page_wrapper','yolo_add_canvas_menu_region');
}
/*================================================
YOLO ADD PROFILE LINK TO MENU
================================================*/
function yolo_get_button_login_register() {
	global $yolo_giraffe_options;

	$yolo_animated = isset($yolo_giraffe_options['menu_animation']) && !empty($yolo_giraffe_options['menu_animation']) ? $yolo_giraffe_options['menu_animation'] : 'fadeInUp1';
    $sub_menu_animate = 'animated ' . $yolo_animated;

	$login_popup  = $yolo_giraffe_options['login_register_popup'] ? true : false;
	$effect       = $yolo_giraffe_options['login_register_popup_effect'] ? $yolo_giraffe_options['login_register_popup_effect'] : 'flip';
	$class = $login_popup ? 'yolo-popup-login ' : '';
	$current_user = wp_get_current_user();
	$logout_link  = wp_logout_url( home_url( '/' ) );
	// Get wooCommerce links
	$login_link = $account_link = '#';
	if (class_exists( 'WooCommerce' ) ) {
		global $woocommerce;
		$login_link = wp_login_url( get_permalink() );
		$myaccount_page_id = wc_get_page_id('myaccount');
		if ( $myaccount_page_id > 0 ) {
			$account_link = get_permalink( $myaccount_page_id );
		}
		else {
			$account_link = wp_login_url( get_permalink() );
		}

		$edit_user_link = $account_link . 'edit-account/';
	}
	else {
		$account_link   = wp_login_url( get_permalink() );
		$edit_user_link = get_edit_user_link($current_user->ID);
	}
    if (!is_user_logged_in()) {
    	if($login_popup){
	    	wp_enqueue_script( 'custombox');
		    wp_enqueue_style( 'custombox');
	    	echo '<a href="'.esc_url($login_link).'" class="'.esc_attr($class).'yolo-login-button" data-effect="'.esc_attr($effect).'"><i class="ion-locked" aria-hidden="true"
	    	></i><span>'. esc_html__( 'Login / Register', 'yolo-giraffe' ) . '</span></a>';
	    }else{
	    	echo '<a href="'.esc_url($account_link).'" class="yolo-login-button"><i class="ion-locked" aria-hidden="true"
	    	></i><span>'. esc_html__( 'Login / Register', 'yolo-giraffe' ) . '</span></a>';
	    }

    } else {

		echo '<div class="yolo-account menu_style_dropdown">';
			echo '<a href="' . $account_link . '" class="yolo-login-button"><i class="fas fa-user"></i></a>';
			echo '<ul class="sub-menu '.$sub_menu_animate.'">';
			echo '<li>';
	        echo '<a href="' . $account_link . '"><i class="fas fa-tachometer-alt"></i> ' . esc_html__( 'My Account', 'yolo-giraffe' ) . '</a>';
	        echo '</li>';
	        echo '<li>';
	        echo '<a href="' . $edit_user_link . '"><i class="fa fa-edit"></i> ' . esc_html__( 'Edit Profile', 'yolo-giraffe' ) . '</a>';
	        echo '</li>';
	        echo '<li>';
	        echo '<a href="' . $logout_link . '"><i class="fas fa-sign-out-alt"></i> ' . esc_html__( 'Logout', 'yolo-giraffe' ) . '</a>';
	        echo '</li>';
	        echo '</ul>';
        echo '</div>';
    }
}