<?php
/**  
 *
 * @package    YoloTheme
 * @version    1.0.0
 * @created    23/12/2015
 * @author     Administrator <admin@yolotheme.com>
 * @copyright  Copyright (c) 2016, YoloTheme
 * @license    http://opensource.org/licenses/gpl-2.0.php GPL v2 or later
 * @link       http://yolotheme.com
 *
 */
/*================================================
THE BREADCRUMB
================================================== */
if (!function_exists('yolo_the_breadcrumb')) {
	function yolo_the_breadcrumb() {
		yolo_get_template('breadcrumb');
	}
}

/*================================================
GET BREADCRUMB
================================================== */
if (!function_exists('yolo_get_breadcrumb')) {
	function yolo_get_breadcrumb() {
		$items       = yolo_get_breadcrumb_items();
		$breadcrumbs = '<ul class="breadcrumbs">';
		$breadcrumbs .= join("", $items);
		$breadcrumbs .= '</ul>';

		echo wp_kses_post($breadcrumbs);
	}
}

/*================================================
GET BREADCRUMB ITEMS
================================================== */
if (!function_exists('yolo_get_breadcrumb_items')) {
	function yolo_get_breadcrumb_items() {
		global $wp_query;

		$on_front = get_option('show_on_front');

		$item = array();
		/* Front page. */
		if (is_front_page()) {
			$item['last'] = esc_html__('Home', 'yolo-giraffe' );
		}

		/* Link to front page. */
		if (!is_front_page()) {
			$item[] = '<li typeof="v:Breadcrumb"><a property="v:url" property="v:title" href="' . esc_url(home_url('/')) . '" class="home">' . esc_html__('Home', 'yolo-giraffe' ) . '</a></li>';
		}

		/* If bbPress is installed and we're on a bbPress page. */
		if (function_exists('is_bbpress') && is_bbpress()) {
			$item = array_merge($item, yolo_breadcrumb_get_bbpress_items());
		} elseif (function_exists('is_woocommerce') && is_woocommerce()) {
			$item = array_merge($item, yolo_filter_breadcrumb_items());
		} /* If viewing a home/post page. */
		elseif (is_home()) {
			$home_page = get_post($wp_query->get_queried_object_id());
			$item = array_merge($item, yolo_breadcrumb_get_parents($home_page->post_parent));
			$item['last'] = get_the_title($home_page->ID);
		} /* If viewing a singular post. */
		elseif (is_singular()) {

			$post = $wp_query->get_queried_object();
			$post_id = (int)$wp_query->get_queried_object_id();
			$post_type = $post->post_type;

			$post_type_object = get_post_type_object($post_type);

			if ('post' === $wp_query->post->post_type) {
				$categories = get_the_category($post_id);
				$item = array_merge($item, yolo_breadcrumb_get_term_parents($categories[0]->term_id, $categories[0]->taxonomy));
			}

			if ('page' !== $wp_query->post->post_type) {

				/* If there's an archive page, add it. */

				if (function_exists('get_post_type_archive_link') && !empty($post_type_object->has_archive))
					$item[] = '<li typeof="v:Breadcrumb"><a property="v:url" property="v:title" href="' . get_post_type_archive_link($post_type) . '" title="' . esc_attr($post_type_object->labels->name) . '">' . $post_type_object->labels->name . '</a></li>';

				if (isset($args["singular_{$wp_query->post->post_type}_taxonomy"]) && is_taxonomy_hierarchical($args["singular_{$wp_query->post->post_type}_taxonomy"])) {
					$terms = wp_get_object_terms($post_id, $args["singular_{$wp_query->post->post_type}_taxonomy"]);
					$item = array_merge($item, yolo_breadcrumb_get_term_parents($terms[0], $args["singular_{$wp_query->post->post_type}_taxonomy"]));
				} elseif (isset($args["singular_{$wp_query->post->post_type}_taxonomy"]))
					$item[] = get_the_term_list($post_id, $args["singular_{$wp_query->post->post_type}_taxonomy"], '', ', ', '');
			}

			if ((is_post_type_hierarchical($wp_query->post->post_type) || 'attachment' === $wp_query->post->post_type) && $parents = yolo_breadcrumb_get_parents($wp_query->post->post_parent)) {
				$item = array_merge($item, $parents);
			}

			$item['last'] = get_the_title();
		} /* If viewing any type of archive. */
		else if (is_archive()) {

			if (is_category() || is_tag() || is_tax()) {

				$term = $wp_query->get_queried_object();

				if ((is_taxonomy_hierarchical($term->taxonomy) && $term->parent) && $parents = yolo_breadcrumb_get_term_parents($term->parent, $term->taxonomy))
					$item = array_merge($item, $parents);

				$item['last'] = $term->name;
			} else if (function_exists('is_post_type_archive') && is_post_type_archive()) {
				$post_type_object = get_post_type_object(get_query_var('post_type'));
				$item['last'] = $post_type_object->labels->name;
			} else if (is_date()) {

				if (is_day())
					$item['last'] = esc_html__('Archives for ', 'yolo-giraffe' ) . get_the_time('F j, Y');

				elseif (is_month())
					$item['last'] = esc_html__('Archives for ', 'yolo-giraffe' ) . single_month_title(' ', false);

				elseif (is_year())
					$item['last'] = esc_html__('Archives for ', 'yolo-giraffe' ) . get_the_time('Y');
			} else if (is_author())
				$item['last'] = esc_html__('Archives by: ', 'yolo-giraffe' ) . get_the_author_meta('display_name', $wp_query->post->post_author);

		} /* If viewing search results. */
		else if (is_search())
			$item['last'] = esc_html__('Search results for "', 'yolo-giraffe' ) . stripslashes(strip_tags(get_search_query())) . '"';

		/* If viewing a 404 error page. */
		else if (is_404())
			$item['last'] = esc_html__('Page Not Found', 'yolo-giraffe' );

		if (isset($item['last'])) {
			$item['last'] = sprintf('<li><span>%s</span></li>', $item['last']);
		}

		return apply_filters('yolo_framework_filter_breadcrumb_items', $item);
	}
}

/*================================================
FILTER BREADCRUMB ITEMS
================================================== */
if (!function_exists('yolo_filter_breadcrumb_items')) {
	function yolo_filter_breadcrumb_items() {
		$item = array();
		$shop_page_id = wc_get_page_id('shop');

		if (get_option('page_on_front') != $shop_page_id) {
			$shop_name = $shop_page_id ? get_the_title($shop_page_id) : '';
			if (!is_shop()) {
				$item[] = '<li typeof="v:Breadcrumb"><a property="v:url" property="v:title" href="' . get_permalink($shop_page_id) . '">' . $shop_name . '</a></li>';
			} else {
				$item['last'] = $shop_name;
			}
		}

		if (is_tax('product_cat') || is_tax('product_tag')) {
			$current_term = get_term_by('slug', get_query_var('term'), get_query_var('taxonomy'));

		} elseif (is_product()) {
			global $post;
			$terms = wc_get_product_terms($post->ID, 'product_cat', array('orderby' => 'parent', 'order' => 'DESC'));
			if ($terms) {
				$current_term = $terms[0];
			}

		}

		if (!empty($current_term)) {
			if (is_taxonomy_hierarchical($current_term->taxonomy)) {
				$item = array_merge($item, yolo_breadcrumb_get_term_parents($current_term->parent, $current_term->taxonomy));
			}

			if (is_tax('product_cat') || is_tax('product_tag')) {
				$item['last'] = $current_term->name;
			} else {
				$item[] = '<li typeof="v:Breadcrumb"><a property="v:url" property="v:title" href="' . get_term_link($current_term->term_id, $current_term->taxonomy) . '">' . $current_term->name . '</a></li>';
			}
		}

		if (is_product()) {
			$item['last'] = get_the_title();
		}

		return apply_filters('yolo_filter_breadcrumb_items', $item);
	}
}


/*================================================
GET BREADCRUMB BBPRESS ITEMS
================================================== */
if (!function_exists('yolo_breadcrumb_get_bbpress_items')) {
	function yolo_breadcrumb_get_bbpress_items() {
		$item = array();
		$shop_page_id = wc_get_page_id('shop');

		if (get_option('page_on_front') != $shop_page_id) {
			$shop_name = $shop_page_id ? get_the_title($shop_page_id) : '';
			if (!is_shop()) {
				$item[] = '<li typeof="v:Breadcrumb"><a property="v:url" property="v:title" href="' . get_permalink($shop_page_id) . '">' . $shop_name . '</a></li>';
			} else {
				$item['last'] = $shop_name;
			}
		}

		if (is_tax('product_cat') || is_tax('product_tag')) {
			$current_term = get_term_by('slug', get_query_var('term'), get_query_var('taxonomy'));

		} elseif (is_product()) {
			global $post;
			$terms = wc_get_product_terms($post->ID, 'product_cat', array('orderby' => 'parent', 'order' => 'DESC'));
			if ($terms) {
				$current_term = $terms[0];
			}

		}

		if (!empty($current_term)) {
			if (is_taxonomy_hierarchical($current_term->taxonomy)) {
				$item = array_merge($item, yolo_breadcrumb_get_term_parents($current_term->parent, $current_term->taxonomy));
			}

			if (is_tax('product_cat') || is_tax('product_tag')) {
				$item['last'] = $current_term->name;
			} else {
				$item[] = '<li typeof="v:Breadcrumb"><a property="v:url" property="v:title" href="' . get_term_link($current_term->term_id, $current_term->taxonomy) . '">' . $current_term->name . '</a></li>';
			}
		}

		if (is_product()) {
			$item['last'] = get_the_title();
		}

		return apply_filters('yolo_filter_breadcrumb_items', $item);
	}
}

/*================================================
GET BREADCRUMB PARENTS
================================================== */
if (!function_exists('yolo_breadcrumb_get_parents')) {
	function yolo_breadcrumb_get_parents($post_id = '', $separator = '/') {
		$parents = array();

		if ($post_id == 0) {
			return $parents;
		}

		while ($post_id) {
			$page      = get_post($post_id);
			$parents[] = '<li typeof="v:Breadcrumb"><a property="v:url" property="v:title" href="' . get_permalink($post_id) . '" title="' . esc_attr(get_the_title($post_id)) . '">' . get_the_title($post_id) . '</a></li>';
			$post_id   = $page->post_parent;
		}

		if ($parents) {
			$parents = array_reverse($parents);
		}

		return $parents;
	}
}

/*================================================
GET BREADCRUMB TERM PARENTS
================================================== */
if (!function_exists('yolo_breadcrumb_get_term_parents')) {
	function yolo_breadcrumb_get_term_parents($parent_id = '', $taxonomy = '', $separator = '/') {
		$parents = array();

		if (empty($parent_id) || empty($taxonomy)) {
			return $parents;
		}

		while ($parent_id) {
			$parent = get_term($parent_id, $taxonomy);
			$parents[] = '<li typeof="v:Breadcrumb"><a property="v:url" property="v:title" href="' . get_term_link($parent, $taxonomy) . '" title="' . esc_attr($parent->name) . '">' . $parent->name . '</a></li>';
			$parent_id = $parent->parent;
		}

		if ($parents) {
			$parents = array_reverse($parents);
		}

		return $parents;
	}
}

if (!function_exists('yolo_post_content_meta')):
    function yolo_post_content_meta($is_shortcode = false, $hide_author = false, $hide_date = false, $hide_category = false, $hide_comment = false)
    {
        global $post;

        $html   = array();
        // Author
        if (!$hide_author):
            $authordata = get_userdata($post->post_author);
            $html[]     = '<span>';
            $html[]     = '<i class="far fa-user"></i>';
            $author     = sprintf(
                '<a href="%1$s" title="%2$s" rel="author">%3$s</a>',
                esc_url(get_author_posts_url($authordata->ID, get_the_author_meta('nicename', $authordata->ID))),
                esc_attr(sprintf(esc_html__('Posts by %s', 'yolo-giraffe'), $authordata->display_name)),
                $authordata->display_name
            );
            $html[] = $author;
            $html[] = '</span>';
        endif;
        // Date
        if (!$hide_date):
            $html[] = '<span>';
            $html[] = '<time class="entry-date" datetime="' . esc_attr(get_the_date('c')) . '">';
            $html[] = '<i class="far fa-calendar"></i>';
            $html[] = esc_html(get_the_date());
            $html[] = '</time>';
            $html[] = '</span>';
        endif;
        // Categories
        $categories_html = '';
        $separator       = ', ';

        $categories = get_the_category();
        foreach ($categories as $category) {
            $categories_html .= '<a' . ' href="' . get_category_link($category->term_id) . '"' . ' title="' . sprintf(esc_attr__("View all posts in: &ldquo;%s&rdquo;", 'yolo-giraffe'), $category->name) . '">' . ' ' . $category->name . '</a>' . $separator;
        }

        if (!$hide_category):
            $html[] = '<span>';
            $html[] = '<i class="fas fa-list-ul"></i>';
            $html[] = trim($categories_html, $separator) . '</span>';
        endif;
        // Comments
        $comments_html = '';

        if (comments_open()) {
            $comment_title  = '';
            $comment_number = '';
            if (get_comments_number() == 0) {
                $comment_title  = sprintf(esc_html__('Leave a comment on: &ldquo;%s&rdquo;', 'yolo-giraffe'), get_the_title());
                $comment_number = 0;
            } else if (get_comments_number() == 1) {
                $comment_title  = sprintf(esc_html__('View a comment on: &ldquo;%s&rdquo;', 'yolo-giraffe'), get_the_title());
                $comment_number = ' 1 ';
            } else {
                $comment_title  = sprintf(esc_html__('View all comments on: &ldquo;%s&rdquo;', 'yolo-giraffe'), get_the_title());
                $comment_number = ' ' . get_comments_number();
            }

            $comments_html .= '<span><a' . ' href="' . esc_url(get_comments_link()) . '"' . ' title="' . esc_attr($comment_title) . '"' . ' class="meta-comments">';
            $comments_html .= '<i class="far fa-comments"></i>';
            $comments_html .= $comment_number . '</a></span>';
        }
        if (!$hide_comment)
            $html[] = $comments_html;
        echo implode($html, "\n");
    }
endif;