<?php
/**
 * This function process data when register
 *
 * @package 	Giraffe
 * @author 		JAMES <luyentv@vietbrain.com>
 * @version 	1.0
 */

if ( ! function_exists( 'yolo_register_user' ) ) :
	
	function yolo_register_user() {

		/**
    	 * Check security
    	 */
    		check_ajax_referer( 'yolo-member', 'security', esc_html__( 'Security Breach! Please contact admin!', 'yolo-giraffe' ) );

    	/**
    	 * Process data
    	 */
    		if ( !empty( $_POST['email_address'] ) ) {
                unset( $_POST['action'] );
                unset( $_POST['security'] );

                $password              = yolo_validate_data( $_POST['password'] );
                $email_address         = yolo_validate_data( $_POST['email_address'] );
                $class_error           = array();
                $msg_error             = array();
                $end_process           = false;

                if ( strlen( $password ) < 6 ) {

                    $response['msg']    = esc_html__( 'Please enter 6 or more characters, letters and numbers.', 'yolo-giraffe' );
                    $response['status'] = 'error';
                    $msg_error[]        = esc_html__( 'Please enter 6 or more characters, letters and numbers.', 'yolo-giraffe' );
                    $class_error[]      = 'password';
                    $end_process        = true;

                }

                if ( !is_email( $email_address ) ) {

                    $response['msg']    = esc_html__( 'Invaild email address.', 'yolo-giraffe' );
                    $response['status'] = 'error';
                    $msg_error[]        = esc_html__( 'Invaild email address.', 'yolo-giraffe' );
                    $class_error[]      = 'email_address';
                    $end_process        = true;

                } elseif ( is_email( $email_address ) && email_exists( $email_address ) ) {

                    $response['msg']    = esc_html__( 'Email already exists.', 'yolo-giraffe' );
                    $response['status'] = 'error';
                    $msg_error[]        = esc_html__( 'Email already exists.', 'yolo-giraffe' );
                    $class_error[]      = 'email_address';
                    $end_process        = true;

                }

                if ( !empty( $end_process ) ) {
                    
                    $response['class_error'] = $class_error;
                    $response['msg_error']   = $msg_error;
                    wp_send_json( $response );

                }

                /**
                 * Create new user
                 */
                
                    if ( ( !$user_id && email_exists( $email_address ) == false ) ) {

                        $user_id = wp_create_user( $email_address, $password, $email_address );

                        if ( !empty( $user_id ) ) {

                            $url_redirect = apply_filters( 'yolo_url_redirect_register_user', get_home_url() );

                            $info_user = array(
                                'user_login'    => $email_address,
                                'user_password' => $password,
                                'remember'      => true
                            );
                         
                            wp_signon( $info_user, false );

                            $response['msg']          = esc_html__( 'Create user successfully. You are logging into...', 'yolo-giraffe' );
                            $response['status']       = 'success';
                            $response['url_redirect'] = $url_redirect;

                        } else {

                            $response['msg']    = esc_html__( 'Can\'t insert user to database, please contact admin!', 'yolo-giraffe' );
                            $response['status'] = 'error';

                        }

                    }

            } else {

                $response['msg']    = esc_html__( 'Don\'t empty user name!', 'yolo-giraffe' );
                $response['status'] = 'error';

            }

            wp_send_json( $response );

    }

    add_action( 'wp_ajax_yolo_register_user', 'yolo_register_user' );
    add_action( 'wp_ajax_nopriv_yolo_register_user', 'yolo_register_user' );

endif;

/**
 * This function process event login member
 *
 * @package     Giraffe
 * @author      JAMES <luyentv@vietbrain.com>
 * @version     1.0
 */

if ( ! function_exists( 'yolo_login_user' ) ) :
    
    function yolo_login_user() {
        /**
         * Check security
         */
            check_ajax_referer( 'yolo-member', 'security', esc_html__( 'Security Breach! Please contact admin!', 'yolo-giraffe' ) );

        /**
         * Process data
         */
            if ( !empty( $_POST['user_name_login'] ) && !empty( $_POST['password_login'] ) ) {

                unset( $_POST['action'] );
                unset( $_POST['security'] );

                $user_name             = yolo_validate_data( $_POST['user_name_login'] );
                $password              = yolo_validate_data( $_POST['password_login'] );
                

                $info_user = array(
                    'user_login'    => $user_name,
                    'user_password' => $password,
                    'remember'      => true
                );
             
                $user = wp_signon( $info_user, false );
             
                if ( is_wp_error( $user ) ) :

                    $response['msg']    = $user->get_error_message();
                    $response['status'] = 'error';
                
                else :
                    $url_redirect = apply_filters( 'yolo_url_redirect_login_user' );

                    $response['url_redirect'] = $url_redirect;
                    $response['msg']          = esc_html__( 'Login successfully! You are redirecting...', 'yolo-giraffe' );
                    $response['status']       = 'success';    

                endif;

            } else {
                
            	$response['msg']    = esc_html__( 'Don\'t empty user name and password!', 'yolo-giraffe' );

                $response['status'] = 'error';

            }

            wp_send_json( $response );

    }

    add_action( 'wp_ajax_yolo_login_user', 'yolo_login_user' );
    add_action( 'wp_ajax_nopriv_yolo_login_user', 'yolo_login_user' );

endif;