<?php

/**
 * ReduxFramework Sample Config File
 * For full documentation, please visit: http://docs.reduxframework.com/
 */

if ( ! class_exists( 'Redux_Framework_options_config' ) ) {

    class Redux_Framework_options_config {

        public $args     = array();
        public $sections = array();
        public $theme;
        public $ReduxFramework;

        public function __construct() {
            if (!class_exists('YoloReduxFramework')) {
                return;
            }

            $this->initSettings();
        }

        public function initSettings() {
            // Set the default arguments
            $this->setArguments();

            // Set a few help tabs so you can see how it's done
            $this->setHelpTabs();

            // Create the sections and fields
            $this->setSections();

            // If Redux is running as a plugin, this will remove the demo notice and links
            add_action('redux/loaded', array($this, 'remove_demo'));

            if (!isset($this->args['opt_name'])) {
                // No errors please
                return;
            }

            $this->ReduxFramework = new YoloReduxFramework($this->sections, $this->args);
        }

        /**
         * Filter hook for filtering the args. Good for child themes to override or add to the args array. Can also be used in other functions.
         * */
        public function change_arguments($args) {
            $args['dev_mode'] = false;

            return $args;
        }

        /**
         * Filter hook for filtering the default value of any given field. Very useful in development mode.
         * */
        public function change_defaults($defaults) {
            $defaults['str_replace'] = 'Testing filter hook!';

            return $defaults;
        }

        // Remove the demo link and the notice of integrated demo from the redux-framework plugin
        public function remove_demo() {
            // Used to hide the demo mode link from the plugin page. Only used when Redux is a plugin.
            if (class_exists('ReduxFrameworkPlugin')) {
                // Used to hide the activation notice informing users of the demo panel. Only used when Redux is a plugin.
                remove_action('admin_notices', array(ReduxFrameworkPlugin::instance(), 'admin_notices'));
            }
        }

        public function setSections() {

            $page_title_bg_url = get_template_directory_uri() . '/assets/images/bg-page-title.jpg';
            $page_404_bg_url   = get_template_directory_uri() . '/assets/images/404-bg.jpg';
            $single_title_bg_url = get_template_directory_uri() . '/assets/images/bg-single-teacher.jpg';
            $pages = get_pages(array('post_type'=>'page','post_status'=>'publish','parent' => -1));
            $page_options = array('none'=>esc_html__( '--Select page--', 'yolo-giraffe' ));
            foreach ($pages as $page) {
                $page_options[$page->ID] = $page->post_title;
            }
            // General Setting
            $this->sections[] = array(
                'title'  => esc_html__( 'General Setting', 'yolo-giraffe' ),
                'desc'      => esc_html__('Welcome to Giraffe theme options panel! Have fun customize the theme!', 'yolo-giraffe'),
                'icon'   => 'el el-wrench',
                'fields' => array(
                    array(
                        'id'       => 'home_preloader',
                        'type'     => 'image_select',
                        'title'    => esc_html__('Page Preloader', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Select Page Preloader. Select none if you don\'t want to use.', 'yolo-giraffe'),
                        'desc'     => '',
                        'class'    => 'yolo_home_preloader',
                        'options'  => array(
                            'none'              => array('title' => esc_html__('None', 'yolo-giraffe'), 'img' => get_template_directory_uri() . '/assets/images/theme-options/layout-wide.png'),
                            'ball-triangle.svg' => array('title' => esc_html__('Ball', 'yolo-giraffe'), 'img' => get_template_directory_uri() . '/assets/svg/ball-triangle.svg'),
                            'puff.svg'          => array('title' => esc_html__('Puff', 'yolo-giraffe'), 'img' => get_template_directory_uri() . '/assets/svg/puff.svg'),
                            'circles.svg'       => array('title' => esc_html__('Circles', 'yolo-giraffe'), 'img' => get_template_directory_uri() . '/assets/svg/circles.svg'),
                            'bars.svg'          => array('title' => esc_html__('Bars', 'yolo-giraffe'), 'img' => get_template_directory_uri() . '/assets/svg/bars.svg'),
                        ),
                        'default'  => 'none',
                    ),


                    array(
                        'id'       => 'home_preloader_bg_color',
                        'type'     => 'color_gradient',
                        'title'    => esc_html__('Preloader background color', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Set Preloader background color.', 'yolo-giraffe'),
                        'mode'     => 'background',
                        'default'  => array('to' => '#fff', 'from' => '#fff'),
                        'required' => array('home_preloader', '!=', 'none'),
                    ),

                    array(
                        'id'       => 'home_preloader_spinner_color',
                        'type'     => 'color_alpha',
                        'title'    => esc_html__('Preloader spinner color', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Pick a preloader spinner color.', 'yolo-giraffe'),
                        'default'  => '#f05c5c',
                        'required' => array('home_preloader', '!=', 'none'),
                    ),

                    array(
                        'id'       => 'home_preloader_spinner_size',
                        'type'     => 'slider',
                        'title'    => esc_html__('Preloader spinner size', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Set the size level of the preloader spinner.', 'yolo-giraffe'),
                        'default'  => '40',
                        "min"      => 40,
                        "step"     => 1,
                        "max"      => 200,
                        'required' => array('home_preloader', '!=', 'none'),
                    ),

                    array(
                        'id'       => 'back_to_top',
                        'type'     => 'switch',
                        'title'    => esc_html__('Back To Top', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Enable/Disable Back to top button.', 'yolo-giraffe'),
                        'default'  => true,
                    ),

                    array(
                        'id'       => 'layout_style',
                        'type'     => 'image_select',
                        'title'    => esc_html__( 'Layout Style', 'yolo-giraffe' ),
                        'subtitle' => esc_html__( 'Select the site layout style.', 'yolo-giraffe' ),
                        'desc'     => '',
                        'options'  => array(
                            'boxed' => array('title' => 'Boxed', 'img' => get_template_directory_uri().'/assets/images/theme-options/layout-boxed.png'),
                            'wide'  => array('title' => 'Wide', 'img' => get_template_directory_uri().'/assets/images/theme-options/layout-wide.png'),
                            'float' => array('title' => 'Float', 'img' => get_template_directory_uri().'/assets/images/theme-options/layout-float.png')
                        ),
                        'default'  => 'wide'
                    ),

                    array(
                        'id'       => 'layout_site_width',
                        'type'     => 'slider',
                        'title'    => esc_html__( 'Site Width (%)', 'yolo-giraffe' ),
                        'subtitle' => esc_html__( 'Set the site width of body.', 'yolo-giraffe' ),
                        'default'  => '90',
                        "min"      => 60,
                        "step"     => 1,
                        "max"      => 100,
                        'required' => array('layout_style','=','boxed'),
                    ),
                    array(
                        'id'       => 'layout_site_max_width',
                        'type'     => 'slider',
                        'title'    => esc_html__( 'Site Max Width (px)', 'yolo-giraffe' ),
                        'subtitle' => esc_html__( 'Set the site max width of body.', 'yolo-giraffe' ),
                        'default'  => '1200',
                        "min"      => 980,
                        "step"     => 10,
                        "max"      => 1600,
                        'required' => array('layout_style','=','boxed'),
                    ),

                    array(
                        'id'       => 'body_background_mode',
                        'type'     => 'button_set',
                        'title'    => esc_html__( 'Body Background Mode', 'yolo-giraffe' ),
                        'subtitle' => esc_html__( 'Chose Background Mode.', 'yolo-giraffe' ),
                        'desc'     => '',
                        'options'  => array(
                            'background' => 'Background',
                            'pattern'    => 'Pattern'
                        ),
                        'default'  => 'background',
                        'required' => array('layout_style','=','boxed'),
                    ),

                    array(
                        'id'       => 'body_background',
                        'type'     => 'background',
                        'output'   => array( 'body' ),
                        'title'    => esc_html__( 'Body Background', 'yolo-giraffe' ),
                        'subtitle' => esc_html__( 'Body background (Apply for Boxed layout style).', 'yolo-giraffe' ),
                        'default'  => array(
                            'background-color'      => '',
                            'background-repeat'     => 'no-repeat',
                            'background-position'   => 'center center',
                            'background-attachment' => 'fixed',
                            'background-size'       => 'cover'
                        ),
                        'required'  => array(
                            array('body_background_mode', '=', array('background'))
                        ),
                    ),
                    array(
                        'id'       => 'body_background_pattern',
                        'type'     => 'image_select',
                        'title'    => esc_html__( 'Background Pattern', 'yolo-giraffe' ),
                        'subtitle' => esc_html__( 'Body background pattern(Apply for Boxed layout style).', 'yolo-giraffe' ),
                        'desc'     => '',
                        'height'   => '40px',
                        'options'  => array(
                            'pattern-1.png' => array('title' => '', 'img' => get_template_directory_uri().'/assets/images/theme-options/pattern-1.png'),
                            'pattern-2.png' => array('title' => '', 'img' => get_template_directory_uri().'/assets/images/theme-options/pattern-2.png'),
                            'pattern-3.png' => array('title' => '', 'img' => get_template_directory_uri().'/assets/images/theme-options/pattern-3.png'),
                            'pattern-4.png' => array('title' => '', 'img' => get_template_directory_uri().'/assets/images/theme-options/pattern-4.png'),
                            'pattern-5.png' => array('title' => '', 'img' => get_template_directory_uri().'/assets/images/theme-options/pattern-5.png'),
                            'pattern-6.png' => array('title' => '', 'img' => get_template_directory_uri().'/assets/images/theme-options/pattern-6.png'),
                            'pattern-7.png' => array('title' => '', 'img' => get_template_directory_uri().'/assets/images/theme-options/pattern-7.png'),
                            'pattern-8.png' => array('title' => '', 'img' => get_template_directory_uri().'/assets/images/theme-options/pattern-8.png'),
                            'pattern-9.png' => array('title' => '', 'img' => get_template_directory_uri().'/assets/images/theme-options/pattern-9.png'),
                            'pattern-10.png' => array('title' => '', 'img' => get_template_directory_uri().'/assets/images/theme-options/pattern-10.png'),
                        ),
                        'default'  => 'pattern-1.png',
                        'required' => array(
                            array('body_background_mode', '=', array('pattern'))
                        ) ,
                    ),
                    array(
                        'id'       => 'google_api_key',
                        'type'     => 'text',
                        'title'    => esc_html__( 'Google API Key', 'yolo-giraffe' ),
                        'subtitle' => esc_html__( 'Set google API Key for Map.', 'yolo-giraffe' ),
                        'desc'     => '',
                    ),
                )
            );
            // Logo
            $this->sections[] = array(
                'title'  => esc_html__( 'Logo & Favicon', 'yolo-giraffe' ),
                'desc'   => '',
                'icon'   => 'el el-picture',
                'fields' => array(
                    array(
                        'id'       => 'custom_favicon',
                        'type'     => 'media',
                        'url'      => true,
                        'title'    => esc_html__('Custom favicon', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Upload a 16px x 16px Png/Gif/ico image that will represent your website favicon.', 'yolo-giraffe'),
                        'desc'     => ''
                    ),
                    array(
                        'id'       => 'logo',
                        'type'     => 'media',
                        'url'      => true,
                        'title'    => esc_html__('Logo', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Upload your logo here.', 'yolo-giraffe'),
                        'desc'     => '',
                        'default'  => array(
                            'url' => get_template_directory_uri() . '/assets/images/logo.png'
                        )
                    ),
                    array(
                        'id'             => 'logo_padding',
                        'type'           => 'spacing',
                        'mode'           => 'padding',
                        'units'          => 'px',
                        'units_extended' => 'false',
                        'title'          => esc_html__('Logo Padding', 'yolo-giraffe'),
                        'subtitle'       => esc_html__('This must be numeric (no px). Leave blank for default.', 'yolo-giraffe'),
                        'desc'           => esc_html__('If you would like to override the default logo padding, then you can do so here.', 'yolo-giraffe'),
                        'default'        => array(
                            'padding-top'    => '0',
                            'padding-bottom' => '0',
                            'padding-left'   => '0',
                            'padding-right'  => '0',
                            'units'          => 'px',
                        )
                    ),
                    array(
                            'id'       => 'sticky_logo',
                            'type'     => 'media',
                            'url'      => true,
                            'title'    => esc_html__('Sticky Logo', 'yolo-giraffe'),
                            'subtitle' => esc_html__('Upload a sticky version of your logo here. ', 'yolo-giraffe'),
                            'desc'     => '',
                            'default'  => array(
                            'url'      => get_template_directory_uri() . '/assets/images/logo.png'
                        )
                    ),
                )
            );
           // Header
            $this->sections[] = array(
                'title'  => esc_html__( 'Header', 'yolo-giraffe' ),
                'desc'   => '',
                'icon'   => 'el el-credit-card',
                'fields' => array(
                    array(
                        'id'       => 'header_layout',
                        'type'     => 'image_select',
                        'title'    => esc_html__('Header Layout', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Select a header layout option from the examples.', 'yolo-giraffe'),
                        'desc'     => '',
                        'class'    => 'header_layout',
                        'options'  => array(
                            'header-1'       => array('title' => 'Header 1', 'img' => get_template_directory_uri().'/assets/images/theme-options/header_1.jpg'),
                            'header-2'       => array('title' => 'Header 2', 'img' => get_template_directory_uri().'/assets/images/theme-options/header_2.jpg'),
                            'header-3'       => array('title' => 'Header 3', 'img' => get_template_directory_uri().'/assets/images/theme-options/header_3.jpg'),
                            'header-4'       => array('title' => 'Header 4', 'img' => get_template_directory_uri().'/assets/images/theme-options/header_4.jpg'),
                        ),
                        'default' => 'header-3'
                    ),


                    array(
                        'id'     => 'section-header-general',
                        'type'   => 'section',
                        'title'  => esc_html__('Header Navigation', 'yolo-giraffe'),
                        'indent' => true,
                    ),
                    array(
                        'id'       => 'menu_animation',
                        'type'     => 'select',
                        'title'    => esc_html__( 'Sub Menu Animation', 'yolo-giraffe' ),
                        'subtitle' => esc_html__( 'Select animation for sub menu.', 'yolo-giraffe' ),
                        'desc'     => '',
                        'options'  => array(
                            'fadeIn'            => 'fadeIn',
                            'fadeInUp1'         => 'fadeInUp',
                            'fadeInDown1'       => 'fadeInDown',
                            'bounceIn'          => 'bounceIn',
                            'flipInX'           => 'flipInX',
                            'rotateX'           => 'rotateX',
                            'bounceInRight'     => 'bounceInRight',
                            'fadeInRight'       => 'fadeInRight',
                        ),
                        'default' => 'rotateX'
                    ),

                     array(
                        'id'       => 'menu_sub_scheme',
                        'type'     => 'button_set',
                        'title'    => esc_html__( 'Sub menu scheme', 'yolo-giraffe' ),
                        'subtitle' => esc_html__( 'Set sub menu scheme.', 'yolo-giraffe' ),
                        'default'  => 'default',
                        'options'  => array(
                            'default'   => esc_html__('Default','yolo-giraffe'),
                            'customize' => esc_html__('Customize','yolo-giraffe')
                        )
                    ),

                    array(
                        'id'       => 'menu_sub_bg_color',
                        'type'     => 'color_alpha',
                        'title'    => esc_html__('Sub Menu Background Color', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Set Sub Menu Background Color.', 'yolo-giraffe'),
                        'default'  => '#fff',
                        
                        'required'  => array('menu_sub_scheme', '=', 'customize'),
                    ),

                    array(
                        'id'       => 'menu_sub_text_color',
                        'type'     => 'color_alpha',
                        'title'    => esc_html__('Sub Menu Text Color', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Set Sub Menu Text Color.', 'yolo-giraffe'),
                        'default'  => '#5e5e5e',
                        
                        'required'  => array('menu_sub_scheme', '=', 'customize'),
                    ),
                   
                    array(
                        'id'     => 'section-header-sticky',
                        'type'   => 'section',
                        'title'  => esc_html__('Header Sticky', 'yolo-giraffe'),
                        'indent' => true,
                    ),                    

                    array(
                        'id'       => 'header_sticky',
                        'type'     => 'switch',
                        'title'    => esc_html__( 'Header Sticky', 'yolo-giraffe' ),
                        'subtitle' => esc_html__( ' header Sticky.', 'yolo-giraffe' ),
                        'default'  => true
                    ),
                    array(
                        'id'       => 'header_sticky_effect',
                        'type'     => 'select',
                        'title'    => esc_html__( 'Header Sticky Effect', 'yolo-giraffe' ),
                        'subtitle' => esc_html__( 'Choose header sticky effect.', 'yolo-giraffe' ),
                        'desc'     => '',
                        'options'  => array(
                            'slideInDown,slideOutUp'         => esc_html__('Slide Up Down','yolo-giraffe'),
                            'bounceInDown,bounceOutUp'  => esc_html__('Bource','yolo-giraffe'),
                            'fadeInDown,fadeOutUp'            => esc_html__('Fade In Down','yolo-giraffe'),
                            'flipInX,flipOutX'          => esc_html__('Flip','yolo-giraffe'),
                            'swingInX,swingOutX'        => esc_html__('Swing','yolo-giraffe')
                        ),
                        'default'  => 'fadeInDown,fadeOutUp',
                        'required'  => array('header_sticky','=','1')
                    ),

                    array(
                        'id'       => 'header_sticky_scheme',
                        'type'     => 'button_set',
                        'title'    => esc_html__( 'Header sticky scheme', 'yolo-giraffe' ),
                        'subtitle' => esc_html__( 'Choose header sticky scheme.', 'yolo-giraffe' ),
                        'desc'     => '',
                        'options'  => array(
                            'inherit' => esc_html__('Inherit','yolo-giraffe'),
                            'gray'    => esc_html__('Gray','yolo-giraffe'),
                            'light'   => esc_html__('Light','yolo-giraffe'),
                            'dark'    => esc_html__('Dark','yolo-giraffe')
                        ),
                        'default'  => 'inherit',
                    ),
                )
            );

                // @ Header customize
                $option_customizer_disable = array(
                    'social-profile'       => esc_html__('Social Profile', 'yolo-giraffe'),
                    'shopping-cart'        => esc_html__('Shopping Cart', 'yolo-giraffe'),
                    'wishlist'             => esc_html__('Wishlist', 'yolo-giraffe'),
                    'search-button'        => esc_html__('Search Button', 'yolo-giraffe'),
                    'custom-text'          => esc_html__('Custom Text', 'yolo-giraffe'),
                    'canvas-menu'          => esc_html__('Canvas Menu', 'yolo-giraffe'),
                    'login-register'       => esc_html__('Login/Register', 'yolo-giraffe'),
                );
                // @ Social network
                $option_social = array(
                    'twitter'    => esc_html__('Twitter', 'yolo-giraffe'),
                    'facebook'   => esc_html__('Facebook', 'yolo-giraffe'),
                    'dribbble'   => esc_html__('Dribbble', 'yolo-giraffe'),
                    'vimeo'      => esc_html__('Vimeo', 'yolo-giraffe'),
                    'tumblr'     => esc_html__('Tumblr', 'yolo-giraffe'),
                    'skype'      => esc_html__('Skype', 'yolo-giraffe'),
                    'linkedin'   => esc_html__('LinkedIn', 'yolo-giraffe'),
                    'googleplus' => esc_html__('Google+', 'yolo-giraffe'),
                    'flickr'     => esc_html__('Flickr', 'yolo-giraffe'),
                    'youtube'    => esc_html__('YouTube', 'yolo-giraffe'),
                    'pinterest'  => esc_html__('Pinterest', 'yolo-giraffe'),
                    'foursquare' => esc_html__('Foursquare', 'yolo-giraffe'),
                    'instagram'  => esc_html__('Instagram', 'yolo-giraffe'),
                    'github'     => esc_html__('GitHub', 'yolo-giraffe'),
                    'xing'       => esc_html__('Xing', 'yolo-giraffe'),
                    'behance'    => esc_html__('Behance', 'yolo-giraffe'),
                    'deviantart' => esc_html__('Deviantart', 'yolo-giraffe'),
                    'soundcloud' => esc_html__('SoundCloud', 'yolo-giraffe'),
                    'yelp'       => esc_html__('Yelp', 'yolo-giraffe'),
                    'rss'        => esc_html__('RSS Feed', 'yolo-giraffe'),
                    'email'      => esc_html__('Email address', 'yolo-giraffe'),
                );
            
            // Header 1 Options
            $this->sections[] = array(
                'title'      => esc_html__('Header 1 Options', 'yolo-giraffe'),
                'desc'       => '',
                'subsection' => true,
                'fields'     => array(
                    array( 
                        'id'       => 'header_1_image',
                        'type'     => 'raw',
                        'class'    => 'header_demo_image',
                        'content'  =>  '<img src='.get_template_directory_uri().'/assets/images/theme-options/header_1.jpg />',

                    ),
                    array(
                        'id'      => 'header_1_height',
                        'type'    => 'slider',
                        'title'   => esc_html__('Header Height (px)', 'yolo-giraffe'),
                        'desc'    => esc_html__('You can set a height for the header. Empty value to default.', 'yolo-giraffe'),
                        'default' => 130,
                        'min'     => 0,
                        'step'    => 1,
                        'max'     => 300,
                    ),
                    array(
                        'id'       => 'header_1_layout_float',
                        'type'     => 'switch',
                        'title'    => esc_html__('Header Float', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Enable/Disable Header Float.', 'yolo-giraffe'),
                        'default'  => false,
                    ),

                    array(
                        'id'      => 'header_1_nav_layout',
                        'type'    => 'button_set',
                        'title'   => esc_html__('Header layout', 'yolo-giraffe'),
                        'options' => array(
                            'container'    => esc_html__('Container', 'yolo-giraffe'),
                            'nav-fullwith' => esc_html__('Full width', 'yolo-giraffe'),
                        ),
                        'default' => 'container',
                    ),
                    array(
                        'id'       => 'header_1_nav_layout_padding',
                        'type'     => 'slider',
                        'title'    => esc_html__('Header padding left/right (px)', 'yolo-giraffe'),
                        'default'  => '100',
                        "min"      => 0,
                        "step"     => 1,
                        "max"      => 200,
                        'required' => array('header_1_nav_layout', '=', 'nav-fullwith'),
                    ),

                    array(
                        'id'     => 'section-header-1-navigation',
                        'type'   => 'section',
                        'title'  => esc_html__('Header Navigation', 'yolo-giraffe'),
                        'indent' => true,
                    ),

                    array(
                        'id'      => 'header_1_nav_distance',
                        'type'    => 'slider',
                        'title'   => esc_html__('Navigation distance', 'yolo-giraffe'),
                        'desc'    => esc_html__('You can set distance between navigation items. Empty value to default.', 'yolo-giraffe'),
                        'default' => 40,
                        'min'     => 0,
                        'step'    => 1,
                        'max'     => 80,
                    ),

                    array(
                        'id'       => 'header_1_nav_bg_color',
                        'type'     => 'color_alpha',
                        'title'    => esc_html__('Navigation background color', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Set header navigation background color.', 'yolo-giraffe'),
                        'default'  => array(),
                        'mode'     => 'background',
                        'validate' => 'colorrgba',
                        'default'  => '#3f3a64',
                        'options'  => array(
                            'allow_empty' => false,
                        ),
                    ),

                    array(
                        'id'       => 'header_1_nav_text_color',
                        'type'     => 'color_alpha',
                        'title'    => esc_html__('Navigation text color', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Set header navigation text color.', 'yolo-giraffe'),
                        'default'  => '#fff',
                    ),

                    array(
                        'id'     => 'section-header-1-customize-right',
                        'type'   => 'section',
                        'title'  => esc_html__('Header Customize Right Logo', 'yolo-giraffe'),
                        'indent' => true,
                    ),
                    array(
                        'id'      => 'header_1_customize_right',
                        'type'    => 'sorter',
                        'title'   => 'Header Customize right ',
                        'desc'    => 'Organize how you want the layout to appear on the header right.',
                        'options' => array(
                            'enabled'  => array(
                            ),
                            'disabled' => array(
                                'shopping-cart' => esc_html__('Shopping Cart', 'yolo-giraffe'),
                                'wishlist'             => esc_html__('Wishlist', 'yolo-giraffe'),
                                'search-button'        => esc_html__('Search Button', 'yolo-giraffe'),
                                'social-profile'       => esc_html__('Social Profile', 'yolo-giraffe'),
                                'custom-text'          => esc_html__('Custom Text', 'yolo-giraffe'),
                                'canvas-menu'          => esc_html__('Canvas Menu', 'yolo-giraffe'),
                                'login-register'       => esc_html__('Login/Register', 'yolo-giraffe'),
                            ),
                        ),
                    ),
                    array(
                        'id'       => 'header_1_customize_right_social_profile',
                        'type'     => 'select',
                        'multi'    => true,
                        'width'    => '100%',
                        'title'    => esc_html__('Social profiles', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Select social for custom social profile.', 'yolo-giraffe'),
                        'options'  => $option_social,
                        'desc'     => '',
                        'default'  => array('facebook', 'twitter', 'googleplus', 'linkedin'),
                    ),
                    array(
                        'id'       => 'header_1_customize_right_text',
                        'type'     => 'ace_editor',
                        'mode'     => 'html',
                        'theme'    => 'chrome',
                        'title'    => esc_html__('Text Content', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Add content for custom text.', 'yolo-giraffe'),
                        'desc'     => '',
                        'default'  => '',
                        'options'  => array('minLines' => 5, 'maxLines' => 60),
                    ),

                    array(
                        'id'     => 'section-header-1-customize-nav',
                        'type'   => 'section',
                        'title'  => esc_html__('Header Customize Navigation Right', 'yolo-giraffe'),
                        'indent' => true,
                    ),

                    array(
                        'id'      => 'header_1_customize_nav',
                        'type'    => 'sorter',
                        'title'   => 'Header customize navigation',
                        'desc'    => 'Organize how you want the layout to appear on the header navigation.',
                        'options' => array(
                            'enabled'  => array(
                                'login-register'       => esc_html__('Login/Register', 'yolo-giraffe'),
                                'search-button'        => esc_html__('Search Button', 'yolo-giraffe'),
                                
                                
                            ),
                            'disabled' => array(
                                'wishlist'             => esc_html__('Wishlist', 'yolo-giraffe'),
                                'shopping-cart' => esc_html__('Shopping Cart', 'yolo-giraffe'),
                                'social-profile'       => esc_html__('Social Profile', 'yolo-giraffe'),
                                'custom-text'          => esc_html__('Custom Text', 'yolo-giraffe'),
                                'canvas-menu'          => esc_html__('Canvas Menu', 'yolo-giraffe'),
                               
                            ),
                        ),
                    ),
                    array(
                        'id'       => 'header_1_customize_nav_social_profile',
                        'type'     => 'select',
                        'multi'    => true,
                        'width'    => '100%',
                        'title'    => esc_html__('Social profiles', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Select social for social profile.', 'yolo-giraffe'),
                        'options'  => $option_social,
                        'desc'     => '',
                        'default'  => array('facebook', 'twitter', 'googleplus', 'linkedin'),
                    ),
                    array(
                        'id'       => 'header_1_customize_nav_text',
                        'type'     => 'ace_editor',
                        'mode'     => 'html',
                        'theme'    => 'chrome',
                        'title'    => esc_html__('Text Content', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Add content for custom text.', 'yolo-giraffe'),
                        'desc'     => '',
                        'default'  => '',
                        'options'  => array('minLines' => 5, 'maxLines' => 60),
                    ),
                ),
            );

            // Header 2 Option
            $this->sections[] = array(
                'title'      => esc_html__('Header 2 Options', 'yolo-giraffe'),
                'desc'       => '',
                'subsection' => true,
                'fields'     => array(
                    array(
                        'id'      => 'header_2_image',
                        'type'    => 'raw',
                        'class'   => 'header_demo_image',
                        'content' => '<img src=' . get_template_directory_uri() . '/assets/images/theme-options/header_2.jpg />',

                    ),
                    array(
                        'id'      => 'header_2_height',
                        'type'    => 'slider',
                        'title'   => esc_html__('Header Height (px)', 'yolo-giraffe'),
                        'desc'    => esc_html__('You can set a height for the header. Empty value to default.', 'yolo-giraffe'),
                        'default' => 130,
                        'min'     => 0,
                        'step'    => 1,
                        'max'     => 300,
                    ),
                    array(
                        'id'       => 'header_2_layout_float',
                        'type'     => 'switch',
                        'title'    => esc_html__('Header Float', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Enable/Disable Header Float.', 'yolo-giraffe'),
                        'default'  => false,
                    ),
                    array(
                        'id'      => 'header_2_nav_layout',
                        'type'    => 'button_set',
                        'title'   => esc_html__('Header navigation layout', 'yolo-giraffe'),
                        'options' => array(
                            'container'    => esc_html__('Container', 'yolo-giraffe'),
                            'nav-fullwith' => esc_html__('Full width', 'yolo-giraffe'),
                        ),
                        'default' => 'container',
                    ),
                    array(
                        'id'       => 'header_2_nav_layout_padding',
                        'type'     => 'slider',
                        'title'    => esc_html__('Header navigation padding left/right (px)', 'yolo-giraffe'),
                        'default'  => '100',
                        "min"      => 0,
                        "step"     => 1,
                        "max"      => 200,
                        'required' => array('header_2_nav_layout', '=', 'nav-fullwith'),
                    ),
                    array(
                        'id'     => 'section-header-2-navigation',
                        'type'   => 'section',
                        'title'  => esc_html__('Header Navigation', 'yolo-giraffe'),
                        'indent' => true,
                    ),
                    array(
                        'id'      => 'header_2_nav_distance',
                        'type'    => 'slider',
                        'title'   => esc_html__('Header navigation distance', 'yolo-giraffe'),
                        'desc'    => esc_html__('You can set distance between navigation items. Empty value to default', 'yolo-giraffe'),
                        'default' => 20,
                        'min'     => 0,
                        'step'    => 1,
                        'max'     => 50,
                    ),
                    array(
                        'id'       => 'header_2_nav_bg_color',
                        'type'     => 'color_alpha',
                        'title'    => esc_html__('Header navigation background color', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Set header navigation background color', 'yolo-giraffe'),
                        'default'  => '#3f3a64',
                    ),
                    array(
                        'id'       => 'header_2_nav_text_color',
                        'type'     => 'color_alpha',
                        'title'    => esc_html__('Header navigation text color', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Set header navigation text color', 'yolo-giraffe'),
                        'default'  => '#fff',
                    ),

                    // Header Customize Left
                    array(
                        'id'     => 'section-header-2-customize-left',
                        'type'   => 'section',
                        'title'  => esc_html__('Header Customize Left Logo', 'yolo-giraffe'),
                        'indent' => true,
                    ),
                    array(
                        'id'      => 'header_2_customize_left',
                        'type'    => 'sorter',
                        'title'   => 'Header customize left',
                        'desc'    => 'Organize how you want the layout to appear on the header left',
                        'options' => array(
                            'enabled'  => array(
                                'social-profile' => esc_html__('Social Profile', 'yolo-giraffe'),
                            ),
                            'disabled' => array(
                                'search-button'        => esc_html__('Search Button', 'yolo-giraffe'),
                                'custom-text'          => esc_html__('Custom Text', 'yolo-giraffe'),
                            ),
                        ),
                    ),
                    array(
                        'id'       => 'header_2_customize_left_social_profile',
                        'type'     => 'select',
                        'multi'    => true,
                        'width'    => '100%',
                        'title'    => esc_html__('Custom social profiles', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Select social profile for custom text', 'yolo-giraffe'),
                        'options'  => array(
                            'twitter'    => esc_html__('Twitter', 'yolo-giraffe'),
                            'facebook'   => esc_html__('Facebook', 'yolo-giraffe'),
                            'dribbble'   => esc_html__('Dribbble', 'yolo-giraffe'),
                            'vimeo'      => esc_html__('Vimeo', 'yolo-giraffe'),
                            'tumblr'     => esc_html__('Tumblr', 'yolo-giraffe'),
                            'skype'      => esc_html__('Skype', 'yolo-giraffe'),
                            'linkedin'   => esc_html__('LinkedIn', 'yolo-giraffe'),
                            'googleplus' => esc_html__('Google+', 'yolo-giraffe'),
                            'flickr'     => esc_html__('Flickr', 'yolo-giraffe'),
                            'youtube'    => esc_html__('YouTube', 'yolo-giraffe'),
                            'pinterest'  => esc_html__('Pinterest', 'yolo-giraffe'),
                            'foursquare' => esc_html__('Foursquare', 'yolo-giraffe'),
                            'instagram'  => esc_html__('Instagram', 'yolo-giraffe'),
                            'github'     => esc_html__('GitHub', 'yolo-giraffe'),
                            'xing'       => esc_html__('Xing', 'yolo-giraffe'),
                            'behance'    => esc_html__('Behance', 'yolo-giraffe'),
                            'deviantart' => esc_html__('Deviantart', 'yolo-giraffe'),
                            'soundcloud' => esc_html__('SoundCloud', 'yolo-giraffe'),
                            'yelp'       => esc_html__('Yelp', 'yolo-giraffe'),
                            'rss'        => esc_html__('RSS Feed', 'yolo-giraffe'),
                            'email'      => esc_html__('Email address', 'yolo-giraffe'),
                        ),
                        'desc'     => '',
                        'default'  => array('facebook', 'twitter', 'googleplus', 'linkedin'),
                    ),
                    array(
                        'id'       => 'header_2_customize_left_text',
                        'type'     => 'ace_editor',
                        'mode'     => 'html',
                        'theme'    => 'chrome',
                        'title'    => esc_html__('Custom Text Content', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Add Content for Custom Text', 'yolo-giraffe'),
                        'desc'     => '',
                        'default'  => '',
                        'options'  => array('minLines' => 5, 'maxLines' => 60),
                    ),

                    // Header Customize Right
                    array(
                        'id'     => 'section-header-2-customize-right',
                        'type'   => 'section',
                        'title'  => esc_html__('Header Customize Right Logo', 'yolo-giraffe'),
                        'indent' => true,
                    ),
                    array(
                        'id'      => 'header_2_customize_right',
                        'type'    => 'sorter',
                        'title'   => 'Header customize right',
                        'desc'    => 'Organize how you want the layout to appear on the header right',
                        'options' => array(
                            'enabled'  => array(
                                'search-button'        => esc_html__('Search Button', 'yolo-giraffe'),
                                'login-register'       => esc_html__('Login/Register', 'yolo-giraffe'),
                            ),
                            'disabled' => array(
                                'shopping-cart' => esc_html__('Shopping Cart', 'yolo-giraffe'),
                                'wishlist'      => esc_html__('Wishlist', 'yolo-giraffe'),
                                'social-profile'       => esc_html__('Social Profile', 'yolo-giraffe'),
                                'custom-text'          => esc_html__('Custom Text', 'yolo-giraffe'),
                                'canvas-menu'          => esc_html__('Canvas Menu', 'yolo-giraffe'),
                            ),
                        ),
                    ),
                    array(
                        'id'       => 'header_2_customize_right_social_profile',
                        'type'     => 'select',
                        'multi'    => true,
                        'width'    => '100%',
                        'title'    => esc_html__('Custom social profiles', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Select social profile for custom text', 'yolo-giraffe'),
                        'options'  => array(
                            'twitter'    => esc_html__('Twitter', 'yolo-giraffe'),
                            'facebook'   => esc_html__('Facebook', 'yolo-giraffe'),
                            'dribbble'   => esc_html__('Dribbble', 'yolo-giraffe'),
                            'vimeo'      => esc_html__('Vimeo', 'yolo-giraffe'),
                            'tumblr'     => esc_html__('Tumblr', 'yolo-giraffe'),
                            'skype'      => esc_html__('Skype', 'yolo-giraffe'),
                            'linkedin'   => esc_html__('LinkedIn', 'yolo-giraffe'),
                            'googleplus' => esc_html__('Google+', 'yolo-giraffe'),
                            'flickr'     => esc_html__('Flickr', 'yolo-giraffe'),
                            'youtube'    => esc_html__('YouTube', 'yolo-giraffe'),
                            'pinterest'  => esc_html__('Pinterest', 'yolo-giraffe'),
                            'foursquare' => esc_html__('Foursquare', 'yolo-giraffe'),
                            'instagram'  => esc_html__('Instagram', 'yolo-giraffe'),
                            'github'     => esc_html__('GitHub', 'yolo-giraffe'),
                            'xing'       => esc_html__('Xing', 'yolo-giraffe'),
                            'behance'    => esc_html__('Behance', 'yolo-giraffe'),
                            'deviantart' => esc_html__('Deviantart', 'yolo-giraffe'),
                            'soundcloud' => esc_html__('SoundCloud', 'yolo-giraffe'),
                            'yelp'       => esc_html__('Yelp', 'yolo-giraffe'),
                            'rss'        => esc_html__('RSS Feed', 'yolo-giraffe'),
                            'email'      => esc_html__('Email address', 'yolo-giraffe'),
                        ),
                        'desc'     => '',
                        'default'  => array('facebook', 'twitter', 'googleplus', 'linkedin'),
                    ),
                    array(
                        'id'       => 'header_2_customize_right_text',
                        'type'     => 'ace_editor',
                        'mode'     => 'html',
                        'theme'    => 'chrome',
                        'title'    => esc_html__('Custom Text Content', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Add Content for Custom Text', 'yolo-giraffe'),
                        'desc'     => '',
                        'default'  => '',
                        'options'  => array('minLines' => 5, 'maxLines' => 60),
                    ),
                    // Header Customize Nav
                    array(
                        'id'     => 'section-header-2-customize-nav',
                        'type'   => 'section',
                        'title'  => esc_html__('Header Customize Right Navigation', 'yolo-giraffe'),
                        'indent' => true,
                    ),
                    array(
                        'id'      => 'header_2_customize_nav',
                        'type'    => 'sorter',
                        'title'   => 'Header customize navigation',
                        'desc'    => 'Organize how you want the layout to appear on the header navigation',
                        'options' => array(
                            'enabled'  => array(
                                'canvas-menu' => esc_html__('Canvas Menu', 'yolo-giraffe'),
                            ),
                            'disabled' => array(
                                'social-profile'       => esc_html__('Social Profile', 'yolo-giraffe'),
                                'shopping-cart'        => esc_html__('Shopping Cart', 'yolo-giraffe'),
                                'wishlist'             => esc_html__('Wishlist', 'yolo-giraffe'),
                                'search-button'        => esc_html__('Search Button', 'yolo-giraffe'),
                                'login-register'       => esc_html__('Login/Register', 'yolo-giraffe'),
                            ),
                        ),
                    ),
                    array(
                        'id'       => 'header_2_customize_nav_social_profile',
                        'type'     => 'select',
                        'multi'    => true,
                        'width'    => '100%',
                        'title'    => esc_html__('Custom social profiles', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Select social profile for custom text', 'yolo-giraffe'),
                        'options'  => array(
                            'twitter'    => esc_html__('Twitter', 'yolo-giraffe'),
                            'facebook'   => esc_html__('Facebook', 'yolo-giraffe'),
                            'dribbble'   => esc_html__('Dribbble', 'yolo-giraffe'),
                            'vimeo'      => esc_html__('Vimeo', 'yolo-giraffe'),
                            'tumblr'     => esc_html__('Tumblr', 'yolo-giraffe'),
                            'skype'      => esc_html__('Skype', 'yolo-giraffe'),
                            'linkedin'   => esc_html__('LinkedIn', 'yolo-giraffe'),
                            'googleplus' => esc_html__('Google+', 'yolo-giraffe'),
                            'flickr'     => esc_html__('Flickr', 'yolo-giraffe'),
                            'youtube'    => esc_html__('YouTube', 'yolo-giraffe'),
                            'pinterest'  => esc_html__('Pinterest', 'yolo-giraffe'),
                            'foursquare' => esc_html__('Foursquare', 'yolo-giraffe'),
                            'instagram'  => esc_html__('Instagram', 'yolo-giraffe'),
                            'github'     => esc_html__('GitHub', 'yolo-giraffe'),
                            'xing'       => esc_html__('Xing', 'yolo-giraffe'),
                            'behance'    => esc_html__('Behance', 'yolo-giraffe'),
                            'deviantart' => esc_html__('Deviantart', 'yolo-giraffe'),
                            'soundcloud' => esc_html__('SoundCloud', 'yolo-giraffe'),
                            'yelp'       => esc_html__('Yelp', 'yolo-giraffe'),
                            'rss'        => esc_html__('RSS Feed', 'yolo-giraffe'),
                            'email'      => esc_html__('Email address', 'yolo-giraffe'),
                        ),
                        'desc'     => '',
                        'default'  => array('facebook', 'twitter', 'googleplus', 'linkedin'),
                    ),
                    array(
                        'id'       => 'header_2_customize_nav_text',
                        'type'     => 'ace_editor',
                        'mode'     => 'html',
                        'theme'    => 'chrome',
                        'title'    => esc_html__('Custom Text Content', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Add Content for Custom Text', 'yolo-giraffe'),
                        'desc'     => '',
                        'default'  => '',
                        'options'  => array('minLines' => 5, 'maxLines' => 60),
                    ),
                    

                ),
            );

            // Header 3 Options
            $this->sections[] = array(
                'title'      => esc_html__('Header 3 Options', 'yolo-giraffe'),
                'desc'       => '',
                'subsection' => true,
                'fields'     => array(
                    array( 
                        'id'       => 'header_3_image',
                        'type'     => 'raw',
                        'class'    => 'header_demo_image',
                        'content'  =>  '<img src='.get_template_directory_uri().'/assets/images/theme-options/header_3.jpg />',

                    ),
                    array(
                        'id'      => 'header_3_height',
                        'type'    => 'slider',
                        'title'   => esc_html__('Header Height (px)', 'yolo-giraffe'),
                        'desc'    => esc_html__('You can set a height for the header. Empty value to default.', 'yolo-giraffe'),
                        'default' => 100,
                        'min'     => 0,
                        'step'    => 1,
                        'max'     => 300,
                    ),
                    array(
                        'id'       => 'header_3_layout_float',
                        'type'     => 'switch',
                        'title'    => esc_html__('Header Float', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Enable/Disable Header Float.', 'yolo-giraffe'),
                        'default'  => false,
                    ),
                    array(
                        'id'      => 'header_3_nav_layout',
                        'type'    => 'button_set',
                        'title'   => esc_html__('Header layout', 'yolo-giraffe'),
                        'options' => array(
                            'container'    => esc_html__('Container', 'yolo-giraffe'),
                            'nav-fullwith' => esc_html__('Full width', 'yolo-giraffe'),
                        ),
                        'default' => 'container',
                    ),
                    array(
                        'id'       => 'header_3_nav_layout_padding',
                        'type'     => 'slider',
                        'title'    => esc_html__('Header padding left/right (px)', 'yolo-giraffe'),
                        'default'  => '60',
                        "min"      => 0,
                        "step"     => 1,
                        "max"      => 200,
                        'required' => array('header_3_nav_layout', '=', 'nav-fullwith'),
                    ),
                    
                    array(
                        'id'     => 'section-header-3-navigation',
                        'type'   => 'section',
                        'title'  => esc_html__('Header Navigation', 'yolo-giraffe'),
                        'indent' => true,
                    ),
                   
                    array(
                        'id'      => 'header_3_nav_distance',
                        'type'    => 'slider',
                        'title'   => esc_html__('Navigation distance', 'yolo-giraffe'),
                        'desc'    => esc_html__('You can set distance between navigation items. Empty value to default', 'yolo-giraffe'),
                        'default' => 20,
                        'min'     => 0,
                        'step'    => 1,
                        'max'     => 50,
                    ),

                    array(
                        'id'       => 'header_3_nav_bg_color',
                        'type'     => 'color_alpha',
                        'title'    => esc_html__('Navigation background color', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Set header navigation background color', 'yolo-giraffe'),
                        'default'  => array(),
                        'mode'     => 'background',
                        'validate' => 'colorrgba',
                        'default'  => '#fff',
                        'options'  => array(
                            'allow_empty' => false,
                        ),
                    ),

                    array(
                        'id'       => 'header_3_nav_text_color',
                        'type'     => 'color_alpha',
                        'title'    => esc_html__('Navigation text color', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Set header navigation text color', 'yolo-giraffe'),
                        'default'  => '#333',
                    ),

                     array(
                        'id'     => 'section-header-3-customize-nav',
                        'type'   => 'section',
                        'title'  => esc_html__('Header Customize Right Navigation', 'yolo-giraffe'),
                        'indent' => true,
                    ),

                    array(
                        'id'      => 'header_3_customize_nav',
                        'type'    => 'sorter',
                        'title'   => 'Header customize navigation right',
                        'desc'    => 'Organize how you want the layout to appear on the header navigation',
                        'options' => array(
                            'enabled'  => array(
                                
                            ),
                            'disabled' => array(
                                'search-button'        => esc_html__('Search Button', 'yolo-giraffe'),
                                'shopping-cart' => esc_html__('Shopping Cart', 'yolo-giraffe'),
                                'wishlist'             => esc_html__('Wishlist', 'yolo-giraffe'),
                                'social-profile'       => esc_html__('Social Profile', 'yolo-giraffe'),
                                'custom-text'          => esc_html__('Custom Text', 'yolo-giraffe'),
                                'canvas-menu'          => esc_html__('Canvas Menu', 'yolo-giraffe'),
                                'login-register'       => esc_html__('Login/Register', 'yolo-giraffe'),
                            ),
                        ),
                    ),
                    array(
                        'id'       => 'header_3_customize_nav_social_profile',
                        'type'     => 'select',
                        'multi'    => true,
                        'width'    => '100%',
                        'title'    => esc_html__('Social profiles', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Select social for social profile.', 'yolo-giraffe'),
                        'options'  => $option_social,
                        'desc'     => '',
                        'default'  => array('facebook', 'twitter', 'googleplus', 'linkedin'),
                    ),
                    array(
                        'id'       => 'header_3_customize_nav_text',
                        'type'     => 'ace_editor',
                        'mode'     => 'html',
                        'theme'    => 'chrome',
                        'title'    => esc_html__('Text Content', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Add content for custom text.', 'yolo-giraffe'),
                        'desc'     => '',
                        'default'  => '',
                        'options'  => array('minLines' => 5, 'maxLines' => 60),
                    ),
                ),
            );

            // Header 4 Options
            $this->sections[] = array(
                'title'      => esc_html__('Header 4 Options', 'yolo-giraffe'),
                'desc'       => '',
                'subsection' => true,
                'fields'     => array(
                    array( 
                        'id'       => 'header_4_image',
                        'type'     => 'raw',
                        'class'    => 'header_demo_image',
                        'content'  =>  '<img src='.get_template_directory_uri().'/assets/images/theme-options/header_4.jpg />',

                    ),
                    array(
                        'id'      => 'header_4_height',
                        'type'    => 'slider',
                        'title'   => esc_html__('Header Height (px)', 'yolo-giraffe'),
                        'desc'    => esc_html__('You can set a height for the header. Empty value to default.', 'yolo-giraffe'),
                        'default' => 100,
                        'min'     => 0,
                        'step'    => 1,
                        'max'     => 300,
                    ),
                    array(
                        'id'       => 'header_4_layout_float',
                        'type'     => 'switch',
                        'title'    => esc_html__('Header Float', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Enable/Disable Header Float.', 'yolo-giraffe'),
                        'default'  => false,
                    ),
                    array(
                        'id'      => 'header_4_nav_layout',
                        'type'    => 'button_set',
                        'title'   => esc_html__('Header layout', 'yolo-giraffe'),
                        'options' => array(
                            'container'    => esc_html__('Container', 'yolo-giraffe'),
                            'nav-fullwith' => esc_html__('Full width', 'yolo-giraffe'),
                        ),
                        'default' => 'container',
                    ),
                    array(
                        'id'       => 'header_4_nav_layout_padding',
                        'type'     => 'slider',
                        'title'    => esc_html__('Header padding left/right (px)', 'yolo-giraffe'),
                        'default'  => '60',
                        "min"      => 0,
                        "step"     => 1,
                        "max"      => 200,
                        'required' => array('header_4_nav_layout', '=', 'nav-fullwith'),
                    ),
                    
                    array(
                        'id'     => 'section-header-4-navigation',
                        'type'   => 'section',
                        'title'  => esc_html__('Header Navigation', 'yolo-giraffe'),
                        'indent' => true,
                    ),
                   
                    array(
                        'id'      => 'header_4_nav_distance',
                        'type'    => 'slider',
                        'title'   => esc_html__('Navigation distance', 'yolo-giraffe'),
                        'desc'    => esc_html__('You can set distance between navigation items. Empty value to default', 'yolo-giraffe'),
                        'default' => 25,
                        'min'     => 0,
                        'step'    => 1,
                        'max'     => 50,
                    ),

                    array(
                        'id'       => 'header_4_nav_bg_color',
                        'type'     => 'color_alpha',
                        'title'    => esc_html__('Navigation background color', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Set header navigation background color', 'yolo-giraffe'),
                        'default'  => array(),
                        'mode'     => 'background',
                        'validate' => 'colorrgba',
                        'default'  => '#fff',
                        'options'  => array(
                            'allow_empty' => false,
                        ),
                    ),

                    array(
                        'id'       => 'header_4_nav_text_color',
                        'type'     => 'color_alpha',
                        'title'    => esc_html__('Navigation text color', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Set header navigation text color', 'yolo-giraffe'),
                        'default'  => '#333',
                    ),

                     array(
                        'id'     => 'section-header-4-customize-nav',
                        'type'   => 'section',
                        'title'  => esc_html__('Header Customize Right', 'yolo-giraffe'),
                        'indent' => true,
                    ),

                    array(
                        'id'      => 'header_4_customize_right',
                        'type'    => 'sorter',
                        'title'   => 'Header customize right',
                        'desc'    => 'Organize how you want the layout to appear on the header navigation',
                        'options' => array(
                            'enabled'  => array(
                                'search-button'        => esc_html__('Search Button', 'yolo-giraffe'),
                            ),
                            'disabled' => array(
                                'shopping-cart' => esc_html__('Shopping Cart', 'yolo-giraffe'),
                                'wishlist'             => esc_html__('Wishlist', 'yolo-giraffe'),
                                'social-profile'       => esc_html__('Social Profile', 'yolo-giraffe'),
                                'custom-text'          => esc_html__('Custom Text', 'yolo-giraffe'),
                                'canvas-menu'          => esc_html__('Canvas Menu', 'yolo-giraffe'),
                                'login-register'       => esc_html__('Login/Register', 'yolo-giraffe'),
                                'button'               => esc_html__('Button', 'yolo-giraffe'),
                                'call-button'          => esc_html__('Call Button', 'yolo-giraffe'),
                            ),
                        ),
                    ),
                    array(
                        'id'       => 'header_4_customize_right_social_profile',
                        'type'     => 'select',
                        'multi'    => true,
                        'width'    => '100%',
                        'title'    => esc_html__('Social profiles', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Select social for social profile.', 'yolo-giraffe'),
                        'options'  => $option_social,
                        'desc'     => '',
                        'default'  => array('facebook', 'twitter', 'googleplus', 'linkedin'),
                    ),

                    array(
                        'id'       => 'header_4_customize_right_button_text',
                        'type'     => 'text',
                        'title'    => esc_html__('Button Text', 'yolo-giraffe'),
                        'default'  => 'Button',
                    ),

                    array(
                        'id'       => 'header_4_customize_right_button_link',
                        'type'     => 'text',
                        'title'    => esc_html__('Button Link', 'yolo-giraffe'),
                        'default'  => '#',
                    ),

                    array(
                        'id'       => 'header_4_customize_right_call_button_text',
                        'type'     => 'text',
                        'title'    => esc_html__('Call Button Text', 'yolo-giraffe'),
                        'default'  => 'Button',
                    ),

                    array(
                        'id'       => 'header_4_customize_right_call_button_number',
                        'type'     => 'text',
                        'title'    => esc_html__('Call Button Number', 'yolo-giraffe'),
                        'default'  => '#',
                    ),
                    array(
                        'id'       => 'header_4_customize_right_text',
                        'type'     => 'ace_editor',
                        'mode'     => 'html',
                        'theme'    => 'chrome',
                        'title'    => esc_html__('Text Content', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Add content for custom text.', 'yolo-giraffe'),
                        'desc'     => '',
                        'default'  => '',
                        'options'  => array('minLines' => 5, 'maxLines' => 60),
                    ),
                ),
            );
            

            // Top Bar
            $this->sections[] = array(
                'title'      => esc_html__( 'Top Bar', 'yolo-giraffe' ),
                'desc'       => '',
                'subsection' => true,
                'fields'     => array(
                    array(
                        'id'       => 'top_bar',
                        'type'     => 'switch',
                        'title'    => esc_html__( 'Top Bar', 'yolo-giraffe' ),
                        'subtitle' => esc_html__( 'Enable/disable top bar.', 'yolo-giraffe' ),
                        'default'  => true
                    ),
                    array(
                        'id'      => 'top_bar_layout_width',
                        'type'    => 'button_set',
                        'title'   => esc_html__('Top Bar Layout', 'yolo-giraffe'),
                        'subtitle'=> esc_html__('Select layout width for tob bar position.', 'yolo-giraffe'),
                        'options' => array(
                            'container'    => esc_html__('Container','yolo-giraffe'),
                            'topbar-fullwith' => esc_html__('Full width','yolo-giraffe'),
                        ),
                        'default'  => 'topbar-fullwith',
                        'required' => array('top_bar','=','1'),
                    ),
                    array(
                        'id'       => 'top_bar_layout_padding',
                        'type'     => 'slider',
                        'title'    => esc_html__('Top bar Padding left/right (px)', 'yolo-giraffe'),
                        'default'  => '60',
                        "min"      => 0,
                        "step"     => 1,
                        "max"      => 200,
                        'required' => array('top_bar_layout_width','=','topbar-fullwith'),
                    ),
                    array(
                        'id'       => 'top_bar_bg_color',
                        'type'     => 'color_alpha',
                        'title'    => esc_html__( 'Top Bar Background Color', 'yolo-giraffe' ),
                        'subtitle' => esc_html__( 'Set Top Bar background color.', 'yolo-giraffe' ),
                        'default'  => '#47b8e0',
                        'required' => array('top_bar','=','1'),
                        
                    ),

                    array(
                        'id'       => 'top_bar_text_color',
                        'type'     => 'color_alpha',
                        'title'    => esc_html__('Top Bar Text Color', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Pick a text color for the Top Bar.', 'yolo-giraffe'),
                        'default'  => 'rgba(255,255,255,0.9)',
                        'required' => array('top_bar','=','1'),
                        
                    ),
                    array(
                        'id'       => 'top_bar_layout',
                        'type'     => 'image_select',
                        'title'    => esc_html__('Top bar Layout Column', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Select the top bar column layout.', 'yolo-giraffe'),
                        'desc'     => '',
                        'options'  => array(
                            'top-bar-1' => array('title' => '', 'img' => get_template_directory_uri().'/assets/images/theme-options/top-bar-layout-1.jpg'),
                            'top-bar-2' => array('title' => '', 'img' => get_template_directory_uri().'/assets/images/theme-options/top-bar-layout-2.jpg'),
                            'top-bar-3' => array('title' => '', 'img' => get_template_directory_uri().'/assets/images/theme-options/top-bar-layout-3.jpg'),
                            'top-bar-4' => array('title' => '', 'img' => get_template_directory_uri().'/assets/images/theme-options/top-bar-layout-4.jpg'),
                        ),
                        'default'  => 'top-bar-2',
                        'required' => array('top_bar','=','1'),
                    ),
                    array(
                        'id'       => 'top_bar_left_sidebar',
                        'type'     => 'select',
                        'title'    => esc_html__('Top Left Sidebar', 'yolo-giraffe'),
                        'subtitle' => 'Choose the default top left sidebar.',
                        'data'     => 'sidebars',
                        'desc'     => '',
                        'default'  => 'top_bar_left',
                        'required' => array('top_bar_layout', '=', array('top-bar-1','top-bar-2','top-bar-3')),
                    ),
                    array(
                        'id'       => 'top_bar_right_sidebar',
                        'type'     => 'select',
                        'title'    => esc_html__('Top Right Sidebar', 'yolo-giraffe'),
                        'subtitle' => 'Choose the default top right sidebar.',
                        'data'     => 'sidebars',
                        'desc'     => '',
                        'default'  => 'top_bar_right',
                        'required' => array('top_bar_layout', '=', array('top-bar-1','top-bar-2','top-bar-3')),
                    ),
                    array(
                        'id'       => 'top_bar_center_sidebar',
                        'type'     => 'select',
                        'title'    => esc_html__('Top Center Sidebar', 'yolo-giraffe'),
                        'subtitle' => 'Choose the default top center sidebar.',
                        'data'     => 'sidebars',
                        'desc'     => '',
                        'default'  => 'top_bar_left',
                        'required' => array('top_bar_layout','=','top-bar-4'),
                    ),  
                )
            );

            // Mobile Header
            $this->sections[] = array(
                'title'      => esc_html__( 'Mobile Header', 'yolo-giraffe' ),
                'desc'       => '',
                'subsection' => true,
                'fields'     => array(
                    array(
                        'id'       => 'mobile_header_layout',
                        'type'     => 'image_select',
                        'title'    => esc_html__('Header Layout', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Select header mobile layout.', 'yolo-giraffe'),
                        'desc'     => '',
                        'options'  => array(
                            'header-mobile-1' => array('title' => '', 'img' => get_template_directory_uri().'/assets/images/theme-options/header-mobile-1.jpg'),
                            'header-mobile-2' => array('title' => '', 'img' => get_template_directory_uri().'/assets/images/theme-options/header-mobile-2.jpg'),
                            'header-mobile-3' => array('title' => '', 'img' => get_template_directory_uri().'/assets/images/theme-options/header-mobile-3.jpg'),
                            'header-mobile-4' => array('title' => '', 'img' => get_template_directory_uri().'/assets/images/theme-options/header-mobile-4.jpg'),
                        ),
                        'default' => 'header-mobile-1'
                    ),

                    array(
                        'id'       => 'mobile_header_menu_drop',
                        'type'     => 'button_set',
                        'title'    => esc_html__( 'Menu Drop Type', 'yolo-giraffe' ),
                        'subtitle' => esc_html__( 'Set menu drop type for mobile header.', 'yolo-giraffe' ),
                        'desc'     => '',
                        'options'  => array(
                            'dropdown' => esc_html__('Dropdown Menu','yolo-giraffe'),
                            'fly'      => esc_html__('Fly Menu','yolo-giraffe')
                        ),
                        'default'  => 'fly'
                    ),

                    array(
                        'id'       => 'mobile_header_logo',
                        'type'     => 'media',
                        'url'      => true,
                        'title'    => esc_html__('Mobile Logo', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Upload your logo here.', 'yolo-giraffe'),
                        'desc'     => '',
                        'default'  => array(
                            'url' => get_template_directory_uri() . '/assets/images/logo.png'
                        )
                    ),
                    array(
                        'id'      => 'logo_mobile_padding',
                        'type'    => 'slider',
                        'title'   => esc_html__('Logo Top/Bottom Padding', 'yolo-giraffe'),
                        'desc'    => esc_html__('If you would like to override the default logo top/bottom padding, then you can do so here', 'yolo-giraffe'),
                        'default' => 0,
                        'min'     => 0,
                        'step'    => 1,
                        'max'     => 50,
                    ),

                    array(
                        'id'       => 'mobile_header_top_bar',
                        'type'     => 'switch',
                        'title'    => esc_html__( 'Top Bar', 'yolo-giraffe' ),
                        'subtitle' => esc_html__( 'Enable Top bar.', 'yolo-giraffe' ),
                        'default'  => false
                    ),
                    array(
                        'id'       => 'mobile_header_stick',
                        'type'     => 'switch',
                        'title'    => esc_html__( 'Stick Mobile Header', 'yolo-giraffe' ),
                        'subtitle' => esc_html__( 'Enable Stick Mobile Header.', 'yolo-giraffe' ),
                        'default'  => false
                    ),
                    array(
                        'id'       => 'mobile_header_account',
                        'type'     => 'switch',
                        'title'    => esc_html__( 'Login/Register', 'yolo-giraffe' ),
                        'subtitle' => esc_html__( 'Enable/Disable.', 'yolo-giraffe' ),
                        'default'  => false
                    ),
                    array(
                        'id'       => 'mobile_header_search_nav_box',
                        'type'     => 'switch',
                        'title'    => esc_html__( 'Search Nav Box', 'yolo-giraffe' ),
                        'subtitle' => esc_html__( 'Enable/Disable.', 'yolo-giraffe' ),
                        'default'  => false
                    ),
                    array(
                        'id'       => 'mobile_header_search_icon',
                        'type'     => 'switch',
                        'title'    => esc_html__( 'Search Icon', 'yolo-giraffe' ),
                        'subtitle' => esc_html__( 'Enable Search Icon.', 'yolo-giraffe' ),
                        'default'  => true
                    ),
                    array(
                        'id'       => 'mobile_header_shopping_cart',
                        'type'     => 'switch',
                        'title'    => esc_html__( 'Shopping Cart', 'yolo-giraffe' ),
                        'subtitle' => esc_html__( 'Enable Shopping Cart.', 'yolo-giraffe' ),
                        'default'  => false
                    ),
                )
            );

            // Header Icon Actions
            $this->sections[] = array(
                'title'      => esc_html__('Header Icon Actions', 'yolo-giraffe'),
                'desc'       => '',
                'subsection' => true,
                'fields'     => array(

                    array(
                        'id'     => 'section-search-icon',
                        'type'   => 'section',
                        'title'  => esc_html__('Search Icon', 'yolo-giraffe'),
                        'indent' => true,
                    ),
                     array(
                        'id'       => 'search_box_type',
                        'type'     => 'button_set',
                        'title'    => esc_html__('Search Box Type', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Select search box type.', 'yolo-giraffe'),
                        'desc'     => '',
                        'options'  => array(
                            'standard' => esc_html__('Standard', 'yolo-giraffe'),
                            'ajax'     => esc_html__('Ajax Search', 'yolo-giraffe'),
                        ),
                        'default'  => 'standard',
                    ),

                    array(
                        'id'       => 'search_box_post_type',
                        'type'     => 'checkbox',
                        'title'    => esc_html__('Post Type For Ajax Search', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Select post type for ajax search.', 'yolo-giraffe'),
                        'options'  => array(
                            'post'    => esc_html__('Post', 'yolo-giraffe'),
                            'page'    => esc_html__('Page', 'yolo-giraffe'),
                            'product' => esc_html__('Product', 'yolo-giraffe'),
                        ),
                        'default'  => array(
                            'post'    => '1',
                            'page'    => '0',
                            'product' => '1',
                        ),
                        'required' => array('search_box_type', '=', 'ajax'),
                    ),

                    array(
                        'id'       => 'search_box_result_amount',
                        'type'     => 'slider',
                        'title'    => esc_html__('Amount Of Search Result', 'yolo-giraffe'),
                        'subtitle' => esc_html__('This must be numeric (no px) or empty (default: 8).', 'yolo-giraffe'),
                        'desc'     => esc_html__('Set mount of Search Result.', 'yolo-giraffe'),
                        'validate' => 'numeric',
                        'default'  => 8,
                        'min'      => 1,
                        'step'     => 1,
                        'max'      => 30,
                        'required' => array('search_box_type', '=', 'ajax'),
                    ),

                    array(
                        'id'     => 'section-shop-icon',
                        'type'   => 'section',
                        'title'  => esc_html__('Woo Icon', 'yolo-giraffe'),
                        'indent' => true,
                    ),
                    array(
                        'id'       => 'mini_cart_style',
                        'type'     => 'button_set',
                        'title'    => esc_html__('Mini Cart Style', 'yolo-giraffe'),
                        'subtitle' => esc_html__( 'Set hover/click type for cart icon action.', 'yolo-giraffe' ),
                        'desc'     => '',
                        'options'  => array(
                            'hover' => esc_html__('Dropdown Style','yolo-giraffe'),
                            'canvas'      => esc_html__('Fly Canvas Style','yolo-giraffe')
                        ),
                        'default'  => 'canvas'

                    ),
                    array(
                        'id'       => 'header_shopping_cart_button',
                        'type'     => 'checkbox',
                        'title'    => esc_html__('Mini Cart Button', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Select mini cart button action.', 'yolo-giraffe'),
                        'options'  => array(
                            'view-cart' => 'View Cart',
                            'checkout'  => 'Checkout',
                        ),
                        'default'  => array(
                            'view-cart' => '1',
                            'checkout'  => '1',
                        ),
                    ),

                    array(
                        'id'       => 'wishlist_style',
                        'type'     => 'switch',
                        'title'    => esc_html__('Wishlist Fly Canvas', 'yolo-giraffe'),
                        'subtitle' => 'Enable wishlist Fly canvas style.',
                        'desc'     => '',
                        'default'  => true,
                    ),

                    array(
                        'id'     => 'section-login-register',
                        'type'   => 'section',
                        'title'  => esc_html__('Login/Register', 'yolo-giraffe'),
                        'indent' => true,
                    ),

                    array(
                        'id'       => 'login_register_popup',
                        'type'     => 'switch',
                        'title'    => esc_html__('Login/Register Popup', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Enable/Disable.', 'yolo-giraffe'),
                        'default'  => true,
                    ),
                    
                    array(
                        'id'      => 'custombox_background_overflow',
                        'type'    => 'color_alpha',
                        'title'   => esc_html__('Background Overlay Color', 'yolo-giraffe'),
                        'desc'    => esc_html__('Set Background color for Popup Login/Register form.', 'yolo-giraffe'),
                        'default' => '#fff',
                        'required' => array('login_register_popup', '=', array('1'))
                    ),

                    array(
                        'id'       => 'login_register_popup_effect',
                        'type'     => 'select',
                        'title'    => esc_html__('Login/Register Popup effect', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Select effect for popup login/register form.', 'yolo-giraffe'),
                        'desc'     => '',
                        'options'  => array(
                            'fadein'        => esc_html__('Fadein', 'yolo-giraffe'),
                            'slide'         => esc_html__('Slide', 'yolo-giraffe'),
                            'blur'          => esc_html__('Blur', 'yolo-giraffe'),
                            'flip'          => esc_html__('Flip', 'yolo-giraffe'),
                            'superscaled'   => esc_html__('Superscaled', 'yolo-giraffe'),
                            'slit'          => esc_html__('Slit', 'yolo-giraffe'),
                            'rotate'        => esc_html__('Rotate', 'yolo-giraffe'),
                            'letmein'       => esc_html__('Letmein', 'yolo-giraffe'),
                            'corner'        => esc_html__('Corner', 'yolo-giraffe'),
                            'slidetogether' => esc_html__('Slidetogether', 'yolo-giraffe'),
                            'scale'         => esc_html__('Scale', 'yolo-giraffe'),
                            'door'          => esc_html__('Door', 'yolo-giraffe'),
                            'push'          => esc_html__('Push', 'yolo-giraffe'),
                            'contentscale'  => esc_html__('Contentscale', 'yolo-giraffe'),
                            'swell'         => esc_html__('Swell', 'yolo-giraffe')
                        ),
                        'default'  => 'superscaled',
                        'required' => array('login_register_popup', '=', array('1'))
                    ),
                    array(
                        'id'      => 'custombox_background_overflow',
                        'type'    => 'color_alpha',
                        'title'   => esc_html__('Background Overlay Color', 'yolo-giraffe'),
                        'desc'    => esc_html__('Set Background color for Popup Login/Register form.', 'yolo-giraffe'),
                        'default' => '#fff',
                        'required' => array('login_register_popup', '=', array('1'))
                    ),
                    array(
                        'id'       => 'bg-login',
                        'type'     => 'media',
                        'url'      => true,
                        'title'    => esc_html__('Background Image Form Popup', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Upload your image background.', 'yolo-giraffe'),
                        'desc'     => '',
                        'default'  => array(
                            'url' => get_template_directory_uri() . '/assets/images/bg-login.jpg',
                        ),
                        'required' => array('login_register_popup', '=', array('1'))
                    ),
                    array(
                        'id'       => 'login_redirect_page_to',
                        'type'     => 'switch',
                        'title'    => esc_html__('Login Redirect To', 'yolo-giraffe'),
                        'default'  => false,
                        'required' => array('login_register_popup', '=', array('1'))
                        
                    ),
                    array(
                        'id'      => 'redirect_to_this_page',
                        'type'    => 'text',
                        'title'   => esc_html__('Page Redirect', 'yolo-giraffe'),
                        'required' => array('login_redirect_page_to', '=', array('1'))
                    ),
                )
            );

            // Pages Setting
            $this->sections[] = array(
                'title'  => esc_html__( 'Pages', 'yolo-giraffe' ),
                'desc'   => '',
                'icon'   => 'el el-file',
                'fields' => array(
                    array(
                        'id'     => 'section-page-layout',
                        'type'   => 'section',
                        'title'  => esc_html__('Page Layout', 'yolo-giraffe'),
                        'indent' => true,
                    ),
                    array(
                        'id'       => 'page_layout',
                        'type'     => 'button_set',
                        'title'    => esc_html__('Layout', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Select Page Layout.', 'yolo-giraffe'),
                        'desc'     => '',
                        'options'  => array(
                            'full'            => esc_html__( 'Full Width', 'yolo-giraffe' ),
                            'container'       => esc_html__( 'Container', 'yolo-giraffe' ),
                        ),
                        'default'  => 'container'
                    ),
                    // Add to fix page background color
                    array(
                        'id'       => 'page_background_color',
                        'mode'     => 'background-color',
                        'type'     => 'color_alpha',
                        'title'    => esc_html__( 'Page Background Color', 'yolo-giraffe' ),
                        'subtitle' => esc_html__( 'Select page background color.', 'yolo-giraffe' ),
                        'default'  => '#fff',
                        'output'         => array('#yolo-wrapper'),
                        
                    ),
                    array(
                        'id'       => 'page_sidebar',
                        'type'     => 'image_select',
                        'title'    => esc_html__('Sidebar', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Set Sidebar Style', 'yolo-giraffe'),
                        'options'  => array(
                            'none'  => array('title' => '', 'img' => get_template_directory_uri().'/assets/images/theme-options/sidebar-none.png'),
                            'left'  => array('title' => '', 'img' => get_template_directory_uri().'/assets/images/theme-options/sidebar-left.png'),
                            'right' => array('title' => '', 'img' => get_template_directory_uri().'/assets/images/theme-options/sidebar-right.png'),
                        ),
                        'default' => 'none'
                    ),

                    array(
                        'id'       => 'page_sidebar_width',
                        'type'     => 'button_set',
                        'title'    => esc_html__('Sidebar Width', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Set Sidebar width', 'yolo-giraffe'),
                        'desc'     => '',
                        'options'  => array('small' => 'Small (1/4)', 'large' => 'Large (1/3)'),
                        'default'  => 'large',
                        'required' => array('page_sidebar', '=', array('left','both','right')),
                    ),

                    array(
                        'id'       => 'page_left_sidebar',
                        'type'     => 'select',
                        'title'    => esc_html__('Left Sidebar', 'yolo-giraffe'),
                        'subtitle' => "Choose the default left sidebar",
                        'data'     => 'sidebars',
                        'desc'     => '',
                        'default'  => 'sidebar-1',
                        'required' => array('page_sidebar', '=', array('left','both')),
                    ),
                    array(
                        'id'       => 'page_right_sidebar',
                        'type'     => 'select',
                        'title'    => esc_html__('Right Sidebar', 'yolo-giraffe'),
                        'subtitle' => "Choose the default right sidebar",
                        'data'     => 'sidebars',
                        'desc'     => '',
                        'default'  => 'sidebar-1',
                        'required' => array('page_sidebar', '=', array('right','both')),
                    ),
                    array(
                        'id'       => 'page_comment',
                        'type'     => 'switch',
                        'title'    => esc_html__('Page Comment', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Enable/Disable page comment', 'yolo-giraffe'),
                        'default'  => true
                    ),
                    array(
                        'id'     => 'section-page-title',
                        'type'   => 'section',
                        'title'  => esc_html__('Page Title', 'yolo-giraffe'),
                        'indent' => true,
                    ),
                    array(
                        'id'       => 'show_page_title',
                        'type'     => 'switch',
                        'title'    => esc_html__('Show Page Title', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Show/Hide Page Title', 'yolo-giraffe'),
                        'default'  => true
                    ),
                    array(
                        'id'       => 'page_title_layout',
                        'type'     => 'button_set',
                        'title'    => esc_html__('Page Title Layout', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Select Page Title Layout', 'yolo-giraffe'),
                        'desc'     => '',
                        'options'  => array(
                            'full'            => 'Full Width',
                            'container'       => 'Container',
                            'container-fluid' => 'Container Fluid'
                        ),
                        'default'  => 'full',
                        'required' => array('show_page_title', '=', array('1')),
                    ),

                    array(
                        'id'             => 'page_title_margin',
                        'type'           => 'spacing',
                        'mode'           => 'margin',
                        'units'          => 'px',
                        'units_extended' => 'false',
                        'title'          => esc_html__('Page Title Margin', 'yolo-giraffe'),
                        'subtitle'       => esc_html__('This must be numeric (no px). Leave blank for default value.', 'yolo-giraffe'),
                        'desc'           => esc_html__('If you would like to override the default page title top/bottom margin, please set it here.', 'yolo-giraffe'),
                        'left'           => false,
                        'right'          => false,
                        'output'         => array('.page-title-margin'),
                        'default'        => array(
                            'margin-top'     => '0px',
                            'margin-bottom'  => '85px',
                            'units'          => 'px',
                        ),
                        'required'  => array('show_page_title', '=', array('1')),
                    ),

                    array(
                        'id'       => 'page_title_style',
                        'type'     => 'image_select',
                        'title'    => esc_html__('Page Title Style', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Select page title style', 'yolo-giraffe'),
                        'desc'     => '',
                        'options'  => array(
                            'page-title-style-1' => array('title' => '', 'img' => get_template_directory_uri().'/assets/images/theme-options/page-title-style-1.png'),
                            'page-title-style-2' => array('title' => '', 'img' => get_template_directory_uri().'/assets/images/theme-options/page-title-style-2.png'),
                            'page-title-style-3' => array('title' => '', 'img' => get_template_directory_uri().'/assets/images/theme-options/page-title-style-3.png'),
                            'page-title-style-4' => array('title' => '', 'img' => get_template_directory_uri().'/assets/images/theme-options/page-title-style-4.png'),
                            'page-title-style-5' => array('title' => '', 'img' => get_template_directory_uri().'/assets/images/theme-options/page-title-style-5.png'),
                        ),
                        'default' => 'page-title-style-2',
                        'required' => array('show_page_title', '=', array('1')),
                    ),

                    array(
                        'id'       => 'page_title_parallax',
                        'type'     => 'switch',
                        'title'    => esc_html__( 'Page Title Parallax', 'yolo-giraffe' ),
                        'subtitle' => esc_html__( 'Enable Page Title Parallax', 'yolo-giraffe' ),
                        'default'  => false,
                        'required' => array('show_page_title', '=', array('1')),
                    ),

                    array(
                        'id'       => 'page_title_height',
                        'type'     => 'slider',
                        'width'    => false,
                        'title'    => esc_html__('Page Title Height', 'yolo-giraffe'),
                        'desc'     => esc_html__('You can set a height for the page title here', 'yolo-giraffe'),
                        'output'   => array('.page-title-height'),
                        'min'      => 10,
                        'step'     => 1,
                        'max'      => 500,
                        'default'  => 150,
                        'required' => array('show_page_title', '=', array('1')),
                    ),

                    array(
                        'id'       => 'page_title_bg_image',
                        'type'     => 'media',
                        'url'      => true,
                        'title'    => esc_html__('Page Title Background', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Upload page title background.', 'yolo-giraffe'),
                        'desc'     => '',
                        'default'  => array(
                            'url' => $page_title_bg_url
                        ),
                        'required'  => array('show_page_title', '=', array('1')),
                    ),
                    array(
                        'id'     => 'section-page-title-background-color',
                        'type'   => 'section',
                        'title'  => esc_html__('Page Title Scheme', 'yolo-giraffe'),
                        'indent' => true
                    ),

                    array(
                        'id'       => 'page_title_color',
                        'type'     => 'color_alpha',
                        'title'    => esc_html__('Page Title Text Color', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Pick a color for page title.', 'yolo-giraffe'),
                        'default'  => '#fff',
                    ),
                    array(
                        'id'       => 'page_sub_title_color',
                        'type'     => 'color_alpha',
                        'title'    => esc_html__('Page Sub Title Text Color', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Pick a color for page sub title.', 'yolo-giraffe'),
                        'default'  => '#fff',
                    ),
                    array(
                        'id'       => 'page_title_bg_color',
                        'type'     => 'color_alpha',
                        'title'    => esc_html__('Page Title Background Color', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Pick a background color for page title.', 'yolo-giraffe'),
                        'default'  => '#3f3a64',
                        'required' => array('show_page_title', '=', array('1')),
                    ),
                    array(
                        'id'     => 'section-page-title-breadcrumbs',
                        'type'   => 'section',
                        'title'  => esc_html__('Breadcrumbs', 'yolo-giraffe'),
                        'indent' => true,
                    ),
                    array(
                        'id'       => 'breadcrumbs_in_page_title',
                        'type'     => 'switch',
                        'title'    => esc_html__('Breadcrumbs', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Enable/Disable Breadcrumbs In Pages', 'yolo-giraffe'),
                        'default'  => true,
                        'required' => array('show_page_title', '=', array('1')),
                    ),
                )
            );

	        // Blog Setting
	        $this->sections[] = array(
				'title'      => esc_html__( 'Blog', 'yolo-giraffe' ),
				'desc'       => '',
				'icon'       => 'el el-pencil',
				'fields'     => array(
                    array(
                        'id'     => 'section-archive-layout',
                        'type'   => 'section',
                        'title'  => esc_html__('Blog Layout', 'yolo-giraffe'),
                        'indent' => true,
                    ),
			        array(
						'id'       => 'archive_layout',
						'type'     => 'button_set',
						'title'    => esc_html__( 'Layout', 'yolo-giraffe' ),
						'subtitle' => esc_html__( 'Select Archive Layout', 'yolo-giraffe' ),
						'desc'     => '',
						'options'  => array(
							'full'            => esc_html__( 'Full Width', 'yolo-giraffe' ),
							'container'       => esc_html__( 'Container', 'yolo-giraffe' ),
							'container-fluid' => esc_html__( 'Container Fluid', 'yolo-giraffe'),
				        	),
				        'default'  => 'container'
			        ),

			        array(
						'id'       => 'archive_sidebar',
						'type'     => 'image_select',
						'title'    => esc_html__('Sidebar', 'yolo-giraffe'),
						'subtitle' => esc_html__('Set Sidebar Style', 'yolo-giraffe'),
						'desc'     => '',
						'options'  => array(
					        'none'     => array('title' => '', 'img' => get_template_directory_uri() . '/assets/images/theme-options/sidebar-none.png'),
					        'left'     => array('title' => '', 'img' => get_template_directory_uri() . '/assets/images/theme-options/sidebar-left.png'),
					        'right'    => array('title' => '', 'img' => get_template_directory_uri() . '/assets/images/theme-options/sidebar-right.png'),
				        ),
				        'default'  => 'right'
			        ),

			        array(
						'id'       => 'archive_sidebar_width',
						'type'     => 'button_set',
						'title'    => esc_html__( 'Sidebar Width', 'yolo-giraffe' ),
						'subtitle' => esc_html__( 'Set Sidebar width', 'yolo-giraffe' ),
						'desc'     => '',
						'options'  => array(
							'small' => esc_html__( 'Small (1/4)', 'yolo-giraffe' ),
							'large' => esc_html__( 'Large (1/3)', 'yolo-giraffe' ),
						),
						'default'  => 'large',
						'required' => array('archive_sidebar', '=', array('left','right')),
			        ),

			        array(
						'id'       => 'archive_left_sidebar',
						'type'     => 'select',
						'title'    => esc_html__( 'Left Sidebar', 'yolo-giraffe' ),
						'subtitle' => esc_html__( 'Choose the default left sidebar', 'yolo-giraffe' ),
						'data'     => 'sidebars',
						'desc'     => '',
						'default'  => 'sidebar-1',
						'required' => array('archive_sidebar', '=', array('left')),
			        ),

			        array(
						'id'       => 'archive_right_sidebar',
						'type'     => 'select',
						'title'    => esc_html__( 'Right Sidebar', 'yolo-giraffe' ),
						'subtitle' => esc_html__( 'Choose the default right sidebar', 'yolo-giraffe' ),
						'data'     => 'sidebars',
						'desc'     => '',
						'default'  => 'sidebar-1',
						'required' => array('archive_sidebar', '=', array('right')),
			        ),

			        array(
						'id'       => 'archive_paging_style',
						'type'     => 'button_set',
						'title'    => esc_html__( 'Paging Style', 'yolo-giraffe' ),
						'subtitle' => esc_html__( 'Select archive paging style', 'yolo-giraffe' ),
						'desc'     => '',
						'options'  => array(
							'default'         => esc_html__( 'Default', 'yolo-giraffe' ),
							'load-more'       => esc_html__( 'Load More', 'yolo-giraffe' ),
							'infinity-scroll' => esc_html__( 'Infinity Scroll', 'yolo-giraffe' )
						),
						'default'  => 'default'
			        ),
                    array(
						'id'       => 'archive_paging_align',
						'type'     => 'button_set',
						'title'    => esc_html__( 'Paging Align', 'yolo-giraffe' ),
						'subtitle' => esc_html__( 'Select archive paging align', 'yolo-giraffe' ),
						'desc'     => '',
						'options'  => array(
							'left'   => esc_html__( 'Left','yolo-giraffe' ),
							'center' => esc_html__( 'Center','yolo-giraffe' ),
							'right'  => esc_html__( 'Right','yolo-giraffe' )
                        ),
                        'default' => 'right'
                    ),
                    array(
                        'id'       => 'archive_feature_img_size',
                        'type'     => 'select',
                        'title'    => esc_html__('Archive Feature Image Size', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Select archive feature image size', 'yolo-giraffe'),
                        'desc'     => '',
                        'options'  => array(
                            'thumbnail' => esc_html__('Thumbnail', 'yolo-giraffe'),
                            'medium'    => esc_html__('Medium', 'yolo-giraffe'),
                            'large'     => esc_html__('Large', 'yolo-giraffe'),
                            'full'      => esc_html__('Full', 'yolo-giraffe'),
                        ),
                        'default'  => 'full',
                    ),
			        array(
                        'id'       => 'archive_display_type',
                        'type'     => 'select',
                        'title'    => esc_html__('Archive Display Type', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Select archive display type', 'yolo-giraffe'),
                        'desc'     => '',
                        'options'  => array(
                            'listing'  => esc_html__('List', 'yolo-giraffe'),
                            'horizontal' => esc_html__('Horizontal', 'yolo-giraffe'),
                            'grid'         => esc_html__('Grid', 'yolo-giraffe'),
                            'masonry'      => esc_html__('Masonry', 'yolo-giraffe'),
                        ),
                        'default'  => 'horizontal',
                    ),

			        array(
						'id'       => 'archive_display_columns',
						'type'     => 'select',
						'title'    => esc_html__('Archive Display Columns', 'yolo-giraffe'),
						'subtitle' => esc_html__('Choose the number of columns to display on archive pages.','yolo-giraffe'),
						'options'  => array(
					        '2'		=> '2',
					        '3'		=> '3',
				        ),
						'desc'     => '',
						'default'  => '2',
						'required' => array('archive_display_type','=',array('grid','masonry')),
			        ),
                    array(
                        'id'     => 'section-archive-title',
                        'type'   => 'section',
                        'title'  => esc_html__('Blog Archive Title', 'yolo-giraffe'),
                        'indent' => true,
                    ),
                    array(
                        'id'       => 'inherit_archive_title',
                        'type'     => 'switch',
                        'title'    => esc_html__('Inherit Page Title ', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Enable/Disable Inherit Page Title Setting', 'yolo-giraffe'),
                        'default'  => false
                    ),
                    array(
                        'id'       => 'show_archive_title',
                        'type'     => 'switch',
                        'title'    => esc_html__('Show Archive Title', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Enable/Disable Archive Title', 'yolo-giraffe'),
                        'default'  => true,
                        'required' => array('inherit_archive_title','=',array('0')),
                    ),
                    array(
                        'id'       => 'archive_title_parallax',
                        'type'     => 'switch',
                        'title'    => esc_html__( 'Archive Title Parallax', 'yolo-giraffe' ),
                        'subtitle' => esc_html__( 'Enable Archive Title Parallax', 'yolo-giraffe' ),
                        'default'  => false,
                        'required' => array('show_archive_title','=',array('1')),
                    ),
                    array(
                        'id'       => 'archive_title_height',
                        'type'     => 'slider',
                        'title'    => esc_html__('Archive Title Height', 'yolo-giraffe'),
                        'desc'     => esc_html__('You can set a height for the archive title here', 'yolo-giraffe'),
                        'min'      => 10,
                        'step'     => 1,
                        'max'      => 500,
                        'default'  => 150,
                        'output'   => array('.archive-title-height'),
                        'required' => array('show_archive_title', '=', array('1')),
                    ),
                    array(
                        'id'       => 'archive_title_bg_image',
                        'type'     => 'media',
                        'url'      => true,
                        'title'    => esc_html__('Archive Title Background', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Upload archive title background.', 'yolo-giraffe'),
                        'desc'     => '',
                        'required' => array('show_archive_title','=',array('1')),
                    ),

		        )
	        );
            // Single Blog
            $this->sections[] = array(
                'title'      => esc_html__( 'Single Blog', 'yolo-giraffe' ),
                'desc'       => '',
                'subsection' => true,
                'fields'     => array(
                    array(
                        'id'     => 'section-single-blog-layout',
                        'type'   => 'section',
                        'title'  => esc_html__('Single Blog Layout', 'yolo-giraffe'),
                        'indent' => true,
                    ),
                    array(
                        'id'       => 'single_blog_layout',
                        'type'     => 'button_set',
                        'title'    => esc_html__('Layout', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Select Single Blog Layout', 'yolo-giraffe'),
                        'desc'     => '',
                        'options'  => array('full' => 'Full Width','container' => 'Container', 'container-fluid' => 'Container Fluid'),
                        'default'  => 'container'
                    ),

                    array(
                        'id'       => 'single_blog_sidebar',
                        'type'     => 'image_select',
                        'title'    => esc_html__('Sidebar', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Set Sidebar Style', 'yolo-giraffe'),
                        'desc'     => '',
                        'options'  => array(
                            'none'  => array('title' => '', 'img' => get_template_directory_uri().'/assets/images/theme-options/sidebar-none.png'),
                            'left'  => array('title' => '', 'img' => get_template_directory_uri().'/assets/images/theme-options/sidebar-left.png'),
                            'right' => array('title' => '', 'img' => get_template_directory_uri().'/assets/images/theme-options/sidebar-right.png'),
                        ),
                        'default'  => 'right'
                    ),

                    array(
                        'id'       => 'single_blog_sidebar_width',
                        'type'     => 'button_set',
                        'title'    => esc_html__('Sidebar Width', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Set Sidebar width', 'yolo-giraffe'),
                        'desc'     => '',
                        'options'  => array('small' => 'Small (1/4)', 'large' => 'Large (1/3)'),
                        'default'  => 'large',
                        'required' => array('single_blog_sidebar', '=', array('left','right')),
                    ),


                    array(
                        'id'       => 'single_blog_left_sidebar',
                        'type'     => 'select',
                        'title'    => esc_html__('Left Sidebar', 'yolo-giraffe'),
                        'subtitle' => "Choose the default left sidebar",
                        'data'     => 'sidebars',
                        'desc'     => '',
                        'default'  => 'sidebar-1',
                        'required' => array('single_blog_sidebar', '=', array('left')),
                    ),

                    array(
                        'id'       => 'single_blog_right_sidebar',
                        'type'     => 'select',
                        'title'    => esc_html__('Right Sidebar', 'yolo-giraffe'),
                        'subtitle' => "Choose the default right sidebar",
                        'data'     => 'sidebars',
                        'desc'     => '',
                        'default'  => 'sidebar-1',
                        'required' => array('single_blog_sidebar', '=', array('right')),
                    ),

                    array(
                        'id'       => 'show_post_navigation',
                        'type'     => 'switch',
                        'title'    => esc_html__('Show Post Navigation', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Enable/Disable Post Navigation', 'yolo-giraffe'),
                        'default'  => true
                    ),

                    array(
                        'id'       => 'show_author_info',
                        'type'     => 'switch',
                        'title'    => esc_html__('Show Author Info', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Enable/Disable Author Info', 'yolo-giraffe'),
                        'default'  => false
                    ),
                    array(
                        'title'    => esc_html__('Social Share', 'yolo-giraffe'),
                        'id'       => 'social_sharing',
                        'type'     => 'checkbox',
                        'subtitle' => esc_html__('Show the social sharing in blog posts', 'yolo-giraffe'),

                        //Must provide key => value pairs for multi checkbox options
                        'options'  => array(
                            'facebook'  => 'Facebook',
                            'twitter'   => 'Twitter',
                            'linkedin'  => 'Linkedin',
                            'google'    => 'Google',
                            'tumblr'    => 'Tumblr',
                            'pinterest' => 'Pinterest'
                        ),

                        //See how default has changed? you also don't need to specify opts that are 0.
                        'default' => array(
                            'facebook'  => '1',
                            'twitter'   => '1',
                            'linkedin'  => '1',
                            'pinterest'  => '1',
                        )
                    ),
                    array(
                        'id'     => 'section-single-blog-title',
                        'type'   => 'section',
                        'title'  => esc_html__('Single Blog Title', 'yolo-giraffe'),
                        'indent' => true,
                    ),
                    array(
                        'id'       => 'inherit_single_blog_title',
                        'type'     => 'switch',
                        'title'    => esc_html__('Inherit Page Title ', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Enable/Disable Inherit Page Title Setting', 'yolo-giraffe'),
                        'default'  => false,
                    ),

                    array(
                        'id'       => 'show_single_blog_title',
                        'type'     => 'switch',
                        'title'    => esc_html__('Show Single Blog Title', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Enable/Disable Single Blog Title', 'yolo-giraffe'),
                        'default'  => true,
                        'required' => array('inherit_single_blog_title', '=', array('0')),
                    ),

                    array(
                        'id'       => 'single_blog_title_parallax',
                        'type'     => 'switch',
                        'title'    => esc_html__( 'Single Blog Title Parallax', 'yolo-giraffe' ),
                        'subtitle' => esc_html__( 'Enable Single Blog Title Parallax', 'yolo-giraffe' ),
                        'default'  => false,
                        'required' => array('show_single_blog_title', '=', array('1')),
                    ),
                    array(
                        'id'       => 'single_blog_title_height',
                        'type'     => 'slider',
                        'title'    => esc_html__('Single Blog Title Height', 'yolo-giraffe'),
                        'desc'     => esc_html__('You can set a height for the single blog title here', 'yolo-giraffe'),
                        'required' => array('show_single_blog_title', '=', array('1')),
                        'min'      => 10,
                        'step'     => 1,
                        'max'      => 500,
                        'default'  => 150,
                        'output'   => array('.single-blog-title-height'),
                    ),
                    array(
                        'id'       => 'single_blog_title_bg_image',
                        'type'     => 'media',
                        'url'      => true,
                        'title'    => esc_html__('Single Blog Title Background', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Upload single blog title background.', 'yolo-giraffe'),
                        'desc'     => '',
                        'required'  => array('show_single_blog_title', '=', array('1'))
                    ),
                    array(
                        'id'       => 'breadcrumbs_in_single_blog_title',
                        'type'     => 'switch',
                        'title'    => esc_html__('Breadcrumbs', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Enable/Disable Breadcrumbs In Single Blog', 'yolo-giraffe'),
                        'default'  => true,
                        'required' => array('inherit_single_blog_title', '=', array('0')),
                    ),
                )
            );
	        // Search Page Setting
            $this->sections[] = array(
                'title'  => esc_html__( 'Search Page', 'yolo-giraffe' ),
                'desc'   => '',
                'subsection' => true,
                'fields' => array(
                    array(
                        'id'       => 'search_layout',
                        'type'     => 'button_set',
                        'title'    => esc_html__('Layout', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Select Search Layout', 'yolo-giraffe'),
                        'desc'     => '',
                        'options'  => array('full' => 'Full Width','container' => 'Container', 'container-fluid' => 'Container Fluid'),
                        'default'  => 'container'
                    ),

                    array(
                        'id'       => 'search_sidebar',
                        'type'     => 'image_select',
                        'title'    => esc_html__('Sidebar', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Set Sidebar Style', 'yolo-giraffe'),
                        'desc'     => '',
                        'options'  => array(
                            'none'  => array('title' => '', 'img' => get_template_directory_uri() . '/assets/images/theme-options/sidebar-none.png'),
                            'left'  => array('title' => '', 'img' => get_template_directory_uri() . '/assets/images/theme-options/sidebar-left.png'),
                            'right' => array('title' => '', 'img' => get_template_directory_uri() . '/assets/images/theme-options/sidebar-right.png'),
                        ),
                        'default' => 'right'
                    ),

                    array(
                        'id'       => 'search_sidebar_width',
                        'type'     => 'button_set',
                        'title'    => esc_html__('Sidebar Width', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Set Sidebar width', 'yolo-giraffe'),
                        'desc'     => '',
                        'options'  => array('small' => 'Small (1/4)', 'large' => 'Large (1/3)'),
                        'default'  => 'large',
                        'required' => array('search_sidebar', '=', array('left','right')),
                    ),

                    array(
                        'id'       => 'search_left_sidebar',
                        'type'     => 'select',
                        'title'    => esc_html__('Left Sidebar', 'yolo-giraffe'),
                        'subtitle' => "Choose the default left sidebar",
                        'data'     => 'sidebars',
                        'desc'     => '',
                        'default'  => 'sidebar-1',
                        'required' => array('search_sidebar', '=', array('left')),
                    ),

                    array(
                        'id'       => 'search_right_sidebar',
                        'type'     => 'select',
                        'title'    => esc_html__('Right Sidebar', 'yolo-giraffe'),
                        'subtitle' => "Choose the default right sidebar",
                        'data'     => 'sidebars',
                        'desc'     => '',
                        'default'  => 'sidebar-1',
                        'required' => array('search_sidebar', '=', array('right')),
                    ),

                    array(
                        'id'       => 'search_paging_style',
                        'type'     => 'button_set',
                        'title'    => esc_html__('Paging Style', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Select search paging style', 'yolo-giraffe'),
                        'desc'     => '',
                        'options'  => array('default' => 'Default', 'load-more' => 'Load More', 'infinity-scroll' => 'Infinity Scroll'),
                        'default'  => 'default'
                    ),
                    array(
                        'id'       => 'search_paging_align',
                        'type'     => 'button_set',
                        'title'    => esc_html__('Paging Align', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Select search paging align', 'yolo-giraffe'),
                        'desc'     => '',
                        'options'  => array(
                            'left'   => esc_html__('Left','yolo-giraffe'),
                            'center' => esc_html__('Center','yolo-giraffe'),
                            'right'  => esc_html__('Right','yolo-giraffe')
                        ),
                        'default' => 'right'
                    ),
                )
            );

	        // Shop
            $this->sections[] = array(
                'title'  => esc_html__( 'Shop', 'yolo-giraffe' ),
                'desc'   => '',
                'icon'   => 'el el-shopping-cart',
                'fields' => array(
                    array(
                        'id'       => 'add_link_for_img',
                        'type'     => 'switch',
                        'title'    => esc_html__( 'Add Link for Product Image', 'yolo-giraffe' ),
                        'subtitle' => esc_html__( 'Enable/Disable Link for Product Image', 'yolo-giraffe' ),
                        'default'  => true
                    ),
                    array(
                        'id'       => 'product_show_rating',
                        'type'     => 'switch',
                        'title'    => esc_html__( 'Show Rating', 'yolo-giraffe' ),
                        'subtitle' => esc_html__( 'Show/Hide Rating product', 'yolo-giraffe' ),
                        'default'  => true
                    ),


                    array(
                        'id'       => 'product_sale_flash_mode',
                        'type'     => 'button_set',
                        'title'    => esc_html__( 'Sale Badge Mode', 'yolo-giraffe' ),
                        'subtitle' => esc_html__( 'Chose Sale Badge Mode', 'yolo-giraffe' ),
                        'desc'     => '',
                        'options'  => array(
                            'text'    => 'Text',
                            'percent' => 'Percent'
                        ),
                        'default'  => 'Text'
                    ),

                    array(
                        'id'       => 'product_button_tooltip',
                        'type'     => 'switch',
                        'title'    => esc_html__( 'Button Tooltip', 'yolo-giraffe' ),
                        'subtitle' => esc_html__( 'Enable/Disable Button Tooltip', 'yolo-giraffe' ),
                        'default'  => false
                    ),
                    array(
                        'id'       => 'product_quick_view',
                        'type'     => 'switch',
                        'title'    => esc_html__( 'Quick View Button', 'yolo-giraffe' ),
                        'subtitle' => esc_html__( 'Enable/Disable Quick View', 'yolo-giraffe' ),
                        'default'  => false
                    ),
                    array(
                        'id'       => 'product_add_to_cart',
                        'type'     => 'switch',
                        'title'    => esc_html__( 'Add To Cart Button', 'yolo-giraffe' ),
                        'subtitle' => esc_html__( 'Enable/Disable Add To Cart Button', 'yolo-giraffe' ),
                        'default'  => true
                    ),
                    array(
                        'id'       => 'product_add_wishlist',
                        'type'     => 'switch',
                        'title'    => esc_html__( 'Add To Wishlist Button', 'yolo-giraffe' ),
                        'subtitle' => esc_html__( 'Enable/Disable Add To Wishlist Button', 'yolo-giraffe' ),
                        'default'  => false
                    ),
                    array(
                        'id'       => 'product_add_to_compare',
                        'type'     => 'switch',
                        'title'    => esc_html__( 'Add To Compare Button', 'yolo-giraffe' ),
                        'subtitle' => esc_html__( 'Enable/Disable Add To Compare Button', 'yolo-giraffe' ),
                        'default'  => false
                    ),
                )
            );

            // Archive Product
            $this->sections[] = array(
                'title'  => esc_html__( 'Archive Product', 'yolo-giraffe' ),
                'desc'   => '',
                'subsection' => true,
                'fields' => array(
                    array(
                        'id'     => 'section-archive-product-layout',
                        'type'   => 'section',
                        'title'  => esc_html__('Archive Product Layout', 'yolo-giraffe'),
                        'indent' => true,
                    ),
                    array(
                        'id'       => 'show_page_shop_content',
                        'type'     => 'button_set',
                        'title'    => esc_html__('Show Page Shop Content', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Enable/Disable Shop Page Content', 'yolo-giraffe'),
                        'desc'     => '',
                        'options'  => array('0' => 'Off','before' => 'Show Before Archive','after' => 'Show After Archive'),
                        'default'  => '0'
                    ),
                    array(
                        'id'       => 'archive_container_layout',
                        'type'     => 'button_set',
                        'title'    => esc_html__('Archive Container', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Select Archive Container Layout', 'yolo-giraffe'),
                        'desc'     => '',
                        'options'  => array('full' => 'Full Width','container' => 'Container', 'container-fluid' => 'Container Fluid'),
                        'default'  => 'container'
                    ),
                    array(
                        'id'       => 'product_per_page',
                        'type'     => 'slider',
                        'title'    => esc_html__('Products Per Page', 'yolo-giraffe'),
                        'desc'     => esc_html__('This must be numeric or empty (default 12).', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Set Products Per Page in archive product', 'yolo-giraffe'),
                        'validate' => 'numeric',
                        'min'      => 1,
                        'step'     => 1,
                        'max'      => 50,
                        'default'  => 8,
                    ),
                    array(
                        'id'       => 'product_display_columns',
                        'type'     => 'select',
                        'title'    => esc_html__('Product Display Columns', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Choose the number of columns to display on shop/category pages.','yolo-giraffe'),
                        'options'  => array(
                            '2'     => '2',
                            '3'     => '3',
                            '4'     => '4',
                            '5'     => '5'
                        ),
                        'desc'    => '',
                        'default' => '4',
                        'select2' => array('allowClear' =>  false) ,
                    ),
                    array(
                        'id'     => 'section-archive-product-layout-start',
                        'type'   => 'section',
                        'title'  => esc_html__('Layout Options', 'yolo-giraffe'),
                        'indent' => true
                    ),
                    array(
                        'id'       => 'archive_product_ajax',
                        'type'     => 'button_set',
                        'title'    => esc_html__('Ajax', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Ajax Filter: Enable/Disable', 'yolo-giraffe'),
                        'options'  => array(
                            'enable'       => esc_html__('Enable', 'yolo-giraffe'),
                            'disable'       => esc_html__('Disable', 'yolo-giraffe')
                        ),
                        'default'  => 'enable'
                    ),
                    array(
                        'id'       => 'archive_product_display',
                        'type'     => 'select',
                        'title'    => esc_html__('Select Product Display', 'yolo-giraffe'),
                        'subtitle' => '',
                        'options'  => array(
                            'grid'       => esc_html__('Grid', 'yolo-giraffe'),
                            'list'       => esc_html__('List', 'yolo-giraffe')
                        ),
                        'default'  => 'grid',
                    ),
                    array(
                        'id'       => 'archive_product_styles',
                        'type'     => 'select',
                        'title'    => esc_html__('Select Product Style', 'yolo-giraffe'),
                        'subtitle' => '',
                        'options'  => array(
                            'fitRows'       => esc_html__('FitRows', 'yolo-giraffe'),
                            'masonry'       => esc_html__('Masonry', 'yolo-giraffe')
                        ),
                        'default'  => 'fitRows',
                        'required' => array('archive_product_display', '=', array('grid')),
                    ),
                    array(
                        'id'       => 'archive_product_sidebar',
                        'type'     => 'image_select',
                        'title'    => esc_html__('Sidebar Filter Layout', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Set Archive Product Sidebar', 'yolo-giraffe'),
                        'desc'     => '',
                        'options'  => array(
                            'top'  => array('title' => '', 'img' => get_template_directory_uri().'/assets/images/theme-options/sidebar-none.png'),
                            'left'  => array('title' => '', 'img' => get_template_directory_uri().'/assets/images/theme-options/sidebar-left.png'),
                            'right' => array('title' => '', 'img' => get_template_directory_uri().'/assets/images/theme-options/sidebar-right.png')
                        ),
                        'default'  => 'top'
                    ),
                    array(
                        'id'       => 'show_categories',
                        'type'     => 'switch',
                        'title'    => esc_html__('Show Categories', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Show/Hide categories', 'yolo-giraffe'),
                        'default'  => false,
                    ),
                    array(
                        'id'       => 'show_filters',
                        'type'     => 'switch',
                        'title'    => esc_html__('Show Filters', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Show/Hide filters', 'yolo-giraffe'),
                        'default'  => false,
                        'required' => array('archive_product_sidebar', '=', array('top')),
                    ),
                    array(
                        'id'       => 'yolo_auto_close_filter',
                        'type'     => 'switch',
                        'title'    => esc_html__('Auto Close Filter', 'yolo-giraffe'),
                        'subtitle' => '',
                        'default'  => true,
                        'required' => array('show_filters', '=', true),
                    ),
                    array(
                        'id'       => 'show_search',
                        'type'     => 'switch',
                        'title'    => esc_html__('Show Search', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Show/Hide search', 'yolo-giraffe'),
                        'default'  => false,
                    ),
                    array(
                        'id'       => 'archive_product_sidebar_width',
                        'type'     => 'button_set',
                        'title'    => esc_html__('Sidebar Width', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Set Sidebar width', 'yolo-giraffe'),
                        'desc'     => '',
                        'options'  => array(
                            'small' => 'Small (1/4)',
                            'large' => 'Large (1/3)'
                        ),
                        'default'  => 'small',
                        'required' => array('archive_product_sidebar', '=', array('left','both','right')),
                    ),
                    array(
                        'id'     => 'section-archive-product-layout-end',
                        'type'   => 'section',
                        'indent' => false
                    ),
                    array(
                        'id'     => 'section-archive-product-title',
                        'type'   => 'section',
                        'title'  => esc_html__('Archive Product Title', 'yolo-giraffe'),
                        'indent' => true,
                    ),
                    array(
                        'id'       => 'inherit_archive_product_title',
                        'type'     => 'switch',
                        'title'    => esc_html__('Inherit Page Title ', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Enable/Disable Inherit Page Title Setting', 'yolo-giraffe'),
                        'default'  => false
                    ),
                    array(
                        'id'       => 'show_archive_product_title',
                        'type'     => 'switch',
                        'title'    => esc_html__('Show Archive Title', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Enable/Disable Archive Product Title', 'yolo-giraffe'),
                        'default'  => true,
                        'required' => array('inherit_archive_product_title', '=', array('0')),
                    ),
                    array(
                        'id'       => 'archive_product_title_parallax',
                        'type'     => 'switch',
                        'title'    => esc_html__( 'Archive Product Title Parallax', 'yolo-giraffe' ),
                        'subtitle' => esc_html__( 'Enable Archive Product Title Parallax', 'yolo-giraffe' ),
                        'default'  => false,
                        'required' => array('show_archive_product_title', '=', array('1')),
                    ),
                    array(
                        'id'       => 'archive_product_title_height',
                        'type'     => 'slider',
                        'title'    => esc_html__('Archive Product Title Height', 'yolo-giraffe'),
                        'desc'     => esc_html__('You can set a height for the archive product title here', 'yolo-giraffe'),
                        'required' => array('show_archive_product_title', '=', array('1')),
                        'min'      => 10,
                        'step'     => 1,
                        'max'      => 500,
                        'default'  => 300,
                        'output'   => array('.archive-product-title-height'),
                    ),

                    array(
                        'id'       => 'archive_product_title_bg_image',
                        'type'     => 'media',
                        'url'      => true,
                        'title'    => esc_html__('Archive Product Title Background', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Upload archive product title background.', 'yolo-giraffe'),
                        'desc'     => '',
                        'default'  => array(
                            'url' => $page_title_bg_url
                        ),
                        'required'  => array('show_archive_product_title', '=', array('1')),
                    ),

                )
            );

            // Single Product
            $this->sections[] = array(
                'title'      => esc_html__( 'Single Product', 'yolo-giraffe' ),
                'desc'       => '',
                'subsection' => true,
                'fields'     => array(
                    array(
                        'id'       => 'sp_layout',
                        'type'     => 'product_block',
                        'title'    => esc_html__('Select Single Product Layout', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Set Single Product Layout', 'yolo-giraffe'),
                    ),
                    array(
                        'id'       => 'single_product_show_image_thumb',
                        'type'     => 'switch',
                        'title'    => esc_html__( 'Show Image Thumb', 'yolo-giraffe' ),
                        'subtitle' => esc_html__( 'Show/Hide Image Thumb product', 'yolo-giraffe' ),
                        'default'  => true
                    ),

                    array(
                        'id'     => 'section-single-product-layout-start',
                        'type'   => 'section',
                        'title'  => esc_html__('Layout Options', 'yolo-giraffe'),
                        'indent' => true
                    ),

                    array(
                        'id'       => 'single_product_layout',
                        'type'     => 'button_set',
                        'title'    => esc_html__('Single Product Layout', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Select Single Product Layout', 'yolo-giraffe'),
                        'desc'     => '',
                        'options'  => array(
                            'full'            => 'Full Width',
                            'container'       => 'Container',
                            'container-fluid' => 'Container Fluid'
                        ),
                        'default'  => 'container'
                    ),
                    array(
                        'id'       => 'single_product_sidebar',
                        'type'     => 'image_select',
                        'title'    => esc_html__('Single Product Sidebar', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Set Single Product Sidebar', 'yolo-giraffe'),
                        'desc'     => '',
                        'options'  => array(
                            'none'  => array('title' => '', 'img' => get_template_directory_uri().'/assets/images/theme-options/sidebar-none.png'),
                            'left'  => array('title' => '', 'img' => get_template_directory_uri().'/assets/images/theme-options/sidebar-left.png'),
                            'right' => array('title' => '', 'img' => get_template_directory_uri().'/assets/images/theme-options/sidebar-right.png'),
                        ),
                        'default' => 'none'
                    ),
                    array(
                        'id'       => 'single_product_sidebar_width',
                        'type'     => 'button_set',
                        'title'    => esc_html__('Single Product Sidebar Width', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Set Sidebar width', 'yolo-giraffe'),
                        'desc'     => '',
                        'options'  => array('small' => 'Small (1/4)', 'large' => 'Large (1/3)'),
                        'default'  => 'small',
                        'required' => array('single_product_sidebar', '=', array('left','right')),
                    ),
                    array(
                        'id'       => 'single_product_left_sidebar',
                        'type'     => 'select',
                        'title'    => esc_html__('Single Product Left Sidebar', 'yolo-giraffe'),
                        'subtitle' => "Choose the default Single Product left sidebar",
                        'data'     => 'sidebars',
                        'desc'     => '',
                        'default'  => 'woocommerce',
                        'required' => array('single_product_sidebar', '=', array('left')),
                    ),
                    array(
                        'id'       => 'single_product_right_sidebar',
                        'type'     => 'select',
                        'title'    => esc_html__('Single Product Right Sidebar', 'yolo-giraffe'),
                        'subtitle' => "Choose the default Single Product right sidebar",
                        'data'     => 'sidebars',
                        'desc'     => '',
                        'default'  => 'woocommerce',
                        'required' => array('single_product_sidebar', '=', array('right')),
                    ),


                    array(
                        'id'     => 'section-single-product-layout-end',
                        'type'   => 'section',
                        'indent' => false
                    ),
                   
                    array(
                        'id'     => 'section-single-product-related-start',
                        'type'   => 'section',
                        'title'  => esc_html__('Product Related Options', 'yolo-giraffe'),
                        'indent' => true
                    ),
                    array(
                        'id'       => 'related_product_count',
                        'type'     => 'text',
                        'title'    => esc_html__('Related Product Total Record', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Total Record Of Related Product.', 'yolo-giraffe'),
                        'validate' => 'number',
                        'default'  => '6',
                    ),

                    array(
                        'id'       => 'related_product_display_columns',
                        'type'     => 'select',
                        'title'    => esc_html__('Related Product Display Columns', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Choose the number of columns to display on related product.','yolo-giraffe'),
                        'options'  => array(
                            '3'     => '3',
                            '4'     => '4',
                        ),
                        'desc'    => '',
                        'default' => '4'
                    ),

                    array(
                        'id'      => 'related_product_condition',
                        'type'    => 'checkbox',
                        'title'   => esc_html__('Related Product Condition', 'yolo-giraffe'),
                        'options' => array(
                            'category' => esc_html__('Same Category','yolo-giraffe'),
                            'tag'      => esc_html__('Same Tag','yolo-giraffe'),
                        ),
                        'default' => array(
                            'category' => '1',
                            'tag'      => '1',
                        ),
                    ),

                    array(
                        'id'     => 'section-single-product-related-end',
                        'type'   => 'section',
                        'indent' => false
                    ),
                    array(
                        'id'     => 'section-single-product-title',
                        'type'   => 'section',
                        'title'  => esc_html__('Single Product Title', 'yolo-giraffe'),
                        'indent' => true,
                    ),
                    array(
                        'id'       => 'inherit_single_product_title',
                        'type'     => 'switch',
                        'title'    => esc_html__('Inherit Page Title ', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Enable/Disable Inherit Page Title Setting', 'yolo-giraffe'),
                        'default'  => false
                    ),
                    array(
                        'id'       => 'show_single_product_title',
                        'type'     => 'switch',
                        'title'    => esc_html__('Show Single Title', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Enable/Disable Single Product Title', 'yolo-giraffe'),
                        'default'  => true,
                        'required' => array('inherit_single_product_title', '=', array('0')),
                    ),
                    array(
                        'id'       => 'custom_single_product_title',
                        'type'     => 'text',
                        'title'    => esc_html__('Custom Single Product Title', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Enter a custom page title if you would like. ', 'yolo-giraffe'),
                        'desc'     => '',
                        'default'  => esc_html__('Product Details','yolo-giraffe'),
                        'required' => array('show_single_product_title', '=', array('1')),
                    ),
                    array(
                        'id'       => 'single_product_title_parallax',
                        'type'     => 'switch',
                        'title'    => esc_html__( 'Single Product Title Parallax', 'yolo-giraffe' ),
                        'subtitle' => esc_html__( 'Enable Single Product Title Parallax', 'yolo-giraffe' ),
                        'default'  => false,
                        'required' => array('show_single_product_title', '=', array('1')),
                    ),                    
                    array(
                        'id'       => 'single_product_title_height',
                        'type'     => 'slider',
                        'title'    => esc_html__('Single Product Title Height', 'yolo-giraffe'),
                        'subtitle' => esc_html__('This must be numeric (no px) or empty.', 'yolo-giraffe'),
                        'desc'     => esc_html__('You can set a height for the single product title here', 'yolo-giraffe'),
                        'required' => array('show_single_product_title', '=', array('1')),
                        'min'      => 10,
                        'step'     => 1,
                        'max'      => 500,
                        'default'  => 300,
                        'output'   => array('.single-product-title-height'),
                    ),

                    array(
                        'id'       => 'single_product_title_bg_image',
                        'type'     => 'media',
                        'url'      => true,
                        'title'    => esc_html__('Single Product Title Background', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Upload single product title background.', 'yolo-giraffe'),
                        'desc'     => '',
                        'default'  => array(
                            'url' => $page_title_bg_url
                        ),
                        'required'  => array('show_single_product_title', '=', array('1')),
                    ),

                    array(
                        'id'       => 'breadcrumbs_in_single_product_title',
                        'type'     => 'switch',
                        'title'    => esc_html__('Breadcrumbs in Single Product', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Enable/Disable Breadcrumbs in Single Product', 'yolo-giraffe'),
                        'default'  => true,
                        'required' => array('inherit_single_product_title', '=', array('0')),
                    ),

                )
            );
            // Footer
            $this->sections[] = array(
                'title'  => esc_html__( 'Footer', 'yolo-giraffe' ),
                'desc'   => '',
                'icon'   => 'el el-website',
                'fields' => array(
                    array(
                        'id'       => 'footer',
                        'type'     => 'footer',
                        'title'    => esc_html__('Select Footer Block', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Set Footer Block', 'yolo-giraffe'),
                    ),

                )
            );
            // Styling Options
            $this->sections[] = array(
                'title'  => esc_html__( 'Styling Options', 'yolo-giraffe' ),
                'icon'   => 'el el-magic',
                'fields' => array(
                    array(
                        'id'       => 'primary_color',
                        'type'     => 'color_alpha',
                        'title'    => esc_html__('Primary Color', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Set Primary Color', 'yolo-giraffe'),
                        'default'  => '#f05c5c',
                        
                    ),
                    array(
                        'id'       => 'secondary_color',
                        'type'     => 'color_alpha',
                        'title'    => esc_html__('Secondary Color', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Set Secondary Color', 'yolo-giraffe'),
                        'default'  => '#1ec0ff',
                        
                    ),

                    array(
                        'id'       => 'text_color',
                        'type'     => 'color_alpha',
                        'title'    => esc_html__('Text Color', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Set Text Color.', 'yolo-giraffe'),
                        'default'  => '#696969',
                        
                    ),
                    array(
                        'id'       => 'heading_color',
                        'type'     => 'color_alpha',
                        'title'    => esc_html__('Heading Color', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Set Heading Color.', 'yolo-giraffe'),
                        'default'  => '#3f3a64',
                        
                    ),
                )
            );
            // Typography
            $this->sections[] = array(
                'icon'   => 'el el-font',
                'title'  => esc_html__('Typography', 'yolo-giraffe'),
                'fields' => array(

                    array(
                        'id'             => 'body_font',
                        'type'           => 'typography',
                        'title'          => esc_html__('Body Font', 'yolo-giraffe'),
                        'subtitle'       => esc_html__('Specify the body font properties.', 'yolo-giraffe'),
                        'google'         => true,
                        'line-height'    => false,
                        'color'          => false,
                        'letter-spacing' => false,
                        'text-align'     => false,
                        'all_styles'     => true, // Enable all Google Font style/weight variations to be added to the page
                        'output'         => array('body'), // An array of CSS selectors to apply this font style to dynamically
                        'compiler'       => array('body'), // An array of CSS selectors to apply this font style to dynamically
                        'units'          => 'px', // Defaults to px
                        'default'        => array(
                            'font-size'   => '14px',
                            'font-family' => 'Montserrat',
                            'font-weight' => '500',
                            'google'      => true,
                        ),
                    ),

                    array(
                        'id'          => 'secondary_font',
                        'type'        => 'typography',
                        'title'       => esc_html__('Secondary Font', 'yolo-giraffe'),
                        'subtitle'    => esc_html__('Specify the Secondary font properties. Ex: Button...', 'yolo-giraffe'),
                        'google'      => true,
                        'line-height' => false,
                        'all_styles'  => true, // Enable all Google Font style/weight variations to be added to the page
                        'color'       => false,
                        'text-align'  => false,
                        'font-style'  => false,
                        'subsets'     => true,
                        'font-size'   => true,
                        'font-weight' => true,
                        'units'       => 'px', // Defaults to px
                        'default'     => array(
                            'font-family' => 'Fredoka One',
                            'font-size'   => '16px',
                            'font-weight' => '400',
                            'google'      => true,
                        ),
                    ),

                    array(
                        'id'          => 'third_font',
                        'type'        => 'typography',
                        'title'       => esc_html__('Third Font', 'yolo-giraffe'),
                        'subtitle'    => esc_html__('Specify the Third font properties. Ex: Sub Title', 'yolo-giraffe'),
                        'google'      => true,
                        'line-height' => false,
                        'all_styles'  => true, // Enable all Google Font style/weight variations to be added to the page
                        'color'       => false,
                        'text-align'  => false,
                        'font-style'  => false,
                        'subsets'     => true,
                        'font-size'   => true,
                        'font-weight' => true,
                        'units'       => 'px', // Defaults to px
                        'default'     => array(
                            'font-family' => 'Gloria Hallelujah',
                            'font-size'   => '18px',
                            'font-weight' => '400',
                            'google'      => true,
                        ),
                    ),

                    array(
                        'id' => 'section-menu-font',
                        'type' => 'section',
                        'title' => esc_html__('Menu Font', 'yolo-giraffe'),
                        'indent' => true
                    ),

                    array(
                        'id'             => 'menu_font',
                        'type'           => 'typography',
                        'title'          => esc_html__('Menu Font', 'yolo-giraffe'),
                        'subtitle'       => esc_html__('Specify the Menu font properties.', 'yolo-giraffe'),
                        'google'         => true,
                        'all_styles'     => false, // Enable all Google Font style/weight variations to be added to the page
                        'color'          => false,
                        'line-height'    => false,
                        'text-align'     => false,
                        'font-style'     => false,
                        'subsets'        => true,
                        'text-transform' => false,
                        'units'          => 'px', // Defaults to px
                        'default'        => array(
                            'font-family'    => 'Montserrat',
                            'font-size'      => '16px',
                            'font-weight'    => '600',
                            'text-transform' => 'none',
                        ),
                    ),
                    array(
                        'id' => 'section-heading-font',
                        'type' => 'section',
                        'title' => esc_html__('Heading Font', 'yolo-giraffe'),
                        'indent' => true
                    ),


                    array(
                        'id'             =>'h1_font',
                        'type'           => 'typography',
                        'title'          => esc_html__('H1 Font', 'yolo-giraffe'),
                        'subtitle'       => esc_html__('Specify the H1 font properties.', 'yolo-giraffe'),
                        'google'         => true,
                        'letter-spacing' => false,
                        'color'          => false,
                        'line-height'    => false,
                        'text-align'     => false,
                        'all_styles'     => true, // Enable all Google Font style/weight variations to be added to the page
                        'output'         => array('h1'), // An array of CSS selectors to apply this font style to dynamically
                        'compiler'       => array('h1'), // An array of CSS selectors to apply this font style to dynamically
                        'units'          =>'px', // Defaults to px
                        'default'        => array(
                            'font-size'   => '36px',
                            'font-family' => 'Fredoka One',
                            'font-weight' => '400',
                        ),
                    ),
                    array(
                        'id'             =>'h2_font',
                        'type'           => 'typography',
                        'title'          => esc_html__('H2 Font', 'yolo-giraffe'),
                        'subtitle'       => esc_html__('Specify the H2 font properties.', 'yolo-giraffe'),
                        'google'         => true,
                        'letter-spacing' => false,
                        'color'          => false,
                        'line-height'    => false,
                        'text-align'     => false,
                        'all_styles'     => true, // Enable all Google Font style/weight variations to be added to the page
                        'output'         => array('h2'), // An array of CSS selectors to apply this font style to dynamically
                        'compiler'       => array('h2'), // An array of CSS selectors to apply this font style to dynamically
                        'units'          =>'px', // Defaults to px
                        'default'        => array(
                            'font-size'   => '30px',
                            'font-family' => 'Fredoka One',
                            'font-weight' => '400',
                        ),
                    ),
                    array(
                        'id'             =>'h3_font',
                        'type'           => 'typography',
                        'title'          => esc_html__('H3 Font', 'yolo-giraffe'),
                        'subtitle'       => esc_html__('Specify the H3 font properties.', 'yolo-giraffe'),
                        'google'         => true,
                        'color'          => false,
                        'line-height'    => false,
                        'letter-spacing' => false,
                        'text-align'     => false,
                        'all_styles'     => true, // Enable all Google Font style/weight variations to be added to the page
                        'output'         => array('h3'), // An array of CSS selectors to apply this font style to dynamically
                        'compiler'       => array('h3'), // An array of CSS selectors to apply this font style to dynamically
                        'units'          =>'px', // Defaults to px
                        'default'        => array(
                            'font-size'   => '26px',
                            'font-family' => 'Fredoka One',
                            'font-weight' => '400',
                        ),
                    ),
                    array(
                        'id'             =>'h4_font',
                        'type'           => 'typography',
                        'title'          => esc_html__('H4 Font', 'yolo-giraffe'),
                        'subtitle'       => esc_html__('Specify the H4 font properties.', 'yolo-giraffe'),
                        'google'         => true,
                        'color'          => false,
                        'line-height'    => false,
                        'letter-spacing' => false,
                        'text-align'     => false,
                        'all_styles'     => true, // Enable all Google Font style/weight variations to be added to the page
                        'output'         => array('h4'), // An array of CSS selectors to apply this font style to dynamically
                        'compiler'       => array('h4'), // An array of CSS selectors to apply this font style to dynamically
                        'units'          =>'px', // Defaults to px
                        'default'        => array(
                            'font-size'   => '22px',
                            'font-family' => 'Fredoka One',
                            'font-weight' => '400',
                        ),
                    ),
                    array(
                        'id'             =>'h5_font',
                        'type'           => 'typography',
                        'title'          => esc_html__('H5 Font', 'yolo-giraffe'),
                        'subtitle'       => esc_html__('Specify the H5 font properties.', 'yolo-giraffe'),
                        'google'         => true,
                        'line-height'    => false,
                        'color'          => false,
                        'letter-spacing' => false,
                        'text-align'     => false,
                        'all_styles'     => true, // Enable all Google Font style/weight variations to be added to the page
                        'output'         => array('h5'), // An array of CSS selectors to apply this font style to dynamically
                        'compiler'       => array('h5'), // An array of CSS selectors to apply this font style to dynamically
                        'units'          =>'px', // Defaults to px
                        'default'        => array(
                            'font-size'   => '18px',
                            'font-family' => 'Fredoka One',
                            'font-weight' => '400',
                        ),
                    ),
                    array(
                        'id'             =>'h6_font',
                        'type'           => 'typography',
                        'title'          => esc_html__('H6 Font', 'yolo-giraffe'),
                        'subtitle'       => esc_html__('Specify the H6 font properties.', 'yolo-giraffe'),
                        'google'         => true,
                        'color'          => false,
                        'line-height'    => false,
                        'letter-spacing' => false,
                        'text-align'     => false,
                        'all_styles'     => true, // Enable all Google Font style/weight variations to be added to the page
                        'output'         => array('h6'), // An array of CSS selectors to apply this font style to dynamically
                        'compiler'       => array('h6'), // An array of CSS selectors to apply this font style to dynamically
                        'units'          =>'px', // Defaults to px
                        'default'        => array(
                            'font-size'   => '14px',
                            'font-family' => 'Fredoka One',
                            'font-weight' => '400',
                        ),
                    ),

                    array(
                        'id' => 'section-page-title-font',
                        'type' => 'section',
                        'title' => esc_html__('Page Title Font', 'yolo-giraffe'),
                        'indent' => true
                    ), 

                    array(
                        'id'             => 'page_title_font',
                        'type'           => 'typography',
                        'title'          => esc_html__('Page Title Font', 'yolo-giraffe'),
                        'subtitle'       => esc_html__('Specify the page title font properties.', 'yolo-giraffe'),
                        'google'         => true,
                        'all_styles'     => true, // Enable all Google Font style/weight variations to be added to the page
                        'line-height'    => false,
                        'color'          => false,
                        'text-align'     => false,
                        'font-style'     => true,
                        'subsets'        => false,
                        'font-size'      => true,
                        'font-weight'    => true,
                        'text-transform' => true,
                        'output'         => array('.page-title-inner h1'), // An array of CSS selectors to apply this font style to dynamically
                        'compiler'       => array(), // An array of CSS selectors to apply this font style to dynamically
                        'units'          => 'px', // Defaults to px
                        'default'        => array(
                            'font-family'    => 'Fredoka One',
                            'font-size'      => '40px',
                            'font-weight'    => '400',
                        ),
                    ),

                    array(
                        'id'             => 'page_sub_title_font',
                        'type'           => 'typography',
                        'title'          => esc_html__('Page Sub Title Font', 'yolo-giraffe'),
                        'subtitle'       => esc_html__('Specify the page sub title font properties.', 'yolo-giraffe'),
                        'google'         => true,
                        'all_styles'     => true, // Enable all Google Font style/weight variations to be added to the page
                        'line-height'    => false,
                        'color'          => false,
                        'font-style'     => true,
                        'text-align'     => false,
                        'subsets'        => false,
                        'font-size'      => true,
                        'font-weight'    => true,
                        'text-transform' => true,
                        'output'         => array('.page-title-inner .page-sub-title'), // An array of CSS selectors to apply this font style to dynamically
                        'compiler'       => array(), // An array of CSS selectors to apply this font style to dynamically
                        'units'          => 'px', // Defaults to px
                        'default'        => array(
                            'font-family'    => 'Montserrat',
                            'font-size'      => '16px',
                            'font-weight'    => '500',
                        ),
                    ),


                ),
            );
// Social Profiles
            $this->sections[] = array(
                'title'  => esc_html__( 'Social Profiles', 'yolo-giraffe' ),
                'desc'   => '',
                'icon'   => 'el el-globe',
                'fields' => array(
                    array(
                        'id'       => 'facebook_url',
                        'type'     => 'text',
                        'title'    => esc_html__('Facebook URL', 'yolo-giraffe'),
                        'subtitle' => "Please enter in your Facebook URL",
                        'desc'     => '',
                        'default'  => ''
                    ),
                    array(
                        'id'       => 'twitter_url',
                        'type'     => 'text',
                        'title'    => esc_html__('Twitter URL', 'yolo-giraffe'),
                        'subtitle' => "Please enter in your Twitter URL.",
                        'desc'     => '',
                        'default'  => ''
                    ),

                    array(
                        'id'       => 'dribbble_url',
                        'type'     => 'text',
                        'title'    => esc_html__('Dribbble URL', 'yolo-giraffe'),
                        'subtitle' => "Please enter in your Dribbble URL.",
                        'desc'     => '',
                        'default'  => ''
                    ),
                    array(
                        'id'       => 'vimeo_url',
                        'type'     => 'text',
                        'title'    => esc_html__('Vimeo URL', 'yolo-giraffe'),
                        'subtitle' => "Please enter in your Vimeo URL.",
                        'desc'     => '',
                        'default'  => ''
                    ),
                    array(
                        'id'       => 'tumblr_url',
                        'type'     => 'text',
                        'title'    => esc_html__('Tumblr URL', 'yolo-giraffe'),
                        'subtitle' => "Please enter in your Tumblr URL.",
                        'desc'     => '',
                        'default'  => ''
                    ),
                    array(
                        'id'       => 'skype_username',
                        'type'     => 'text',
                        'title'    => esc_html__('Skype ID', 'yolo-giraffe'),
                        'subtitle' => "Please enter your skype ID.",
                        'default'  => ''
                    ),
                    array(
                        'id'       => 'linkedin_url',
                        'type'     => 'text',
                        'title'    => esc_html__('LinkedIn URL', 'yolo-giraffe'),
                        'subtitle' => "Please enter in your Linkedin URL.",
                        'desc'     => '',
                        'default'  => ''
                    ),
                    array(
                        'id'       => 'googleplus_url',
                        'type'     => 'text',
                        'title'    => esc_html__('Google+ URL', 'yolo-giraffe'),
                        'subtitle' => "Please enter in your Google+ URL.",
                        'desc'     => '',
                        'default'  => ''
                    ),
                    array(
                        'id'       => 'flickr_url',
                        'type'     => 'text',
                        'title'    => esc_html__('Flickr URL', 'yolo-giraffe'),
                        'subtitle' => "Please enter in your Flickr URL.",
                        'desc'     => '',
                        'default'  => ''
                    ),
                    array(
                        'id'       => 'youtube_url',
                        'type'     => 'text',
                        'title'    => esc_html__('YouTube URL', 'yolo-giraffe'),
                        'subtitle' => "Please enter in your Youtube URL.",
                        'desc'     => '',
                        'default'  => ''
                    ),
                    array(
                        'id'       => 'pinterest_url',
                        'type'     => 'text',
                        'title'    => esc_html__('Pinterest URL', 'yolo-giraffe'),
                        'subtitle' => "Please enter in your Pinterest URL.",
                        'desc'     => '',
                        'default'  => ''
                    ),
                    array(
                        'id'       => 'foursquare_url',
                        'type'     => 'text',
                        'title'    => esc_html__('Foursquare URL', 'yolo-giraffe'),
                        'subtitle' => "Please enter in your Foursqaure URL",
                        'desc'     => '',
                        'default'  => ''
                    ),
                    array(
                        'id'       => 'instagram_url',
                        'type'     => 'text',
                        'title'    => esc_html__('Instagram URL', 'yolo-giraffe'),
                        'subtitle' => "Please enter in your Instagram URL",
                        'desc'     => '',
                        'default'  => ''
                    ),
                    array(
                        'id'       => 'github_url',
                        'type'     => 'text',
                        'title'    => esc_html__('GitHub URL', 'yolo-giraffe'),
                        'subtitle' => "Please enter in your GitHub URL",
                        'desc'     => '',
                        'default'  => ''
                    ),
                    array(
                        'id'       => 'xing_url',
                        'type'     => 'text',
                        'title'    => esc_html__('Xing URL', 'yolo-giraffe'),
                        'subtitle' => "Please enter in your Xing URL",
                        'desc'     => '',
                        'default'  => ''
                    ),
                    array(
                        'id'       => 'behance_url',
                        'type'     => 'text',
                        'title'    => esc_html__('Behance URL', 'yolo-giraffe'),
                        'subtitle' => "Please enter in your Behance URL",
                        'desc'     => '',
                        'default'  => ''
                    ),
                    array(
                        'id'       => 'deviantart_url',
                        'type'     => 'text',
                        'title'    => esc_html__('Deviantart URL', 'yolo-giraffe'),
                        'subtitle' => "Please enter in your Deviantart URL",
                        'desc'     => '',
                        'default'  => ''
                    ),
                    array(
                        'id'       => 'soundcloud_url',
                        'type'     => 'text',
                        'title'    => esc_html__('SoundCloud URL', 'yolo-giraffe'),
                        'subtitle' => "Please enter in your SoundCloud URL",
                        'desc'     => '',
                        'default'  => ''
                    ),
                    array(
                        'id'       => 'yelp_url',
                        'type'     => 'text',
                        'title'    => esc_html__('Yelp URL', 'yolo-giraffe'),
                        'subtitle' => "Please enter in your Yelp URL",
                        'desc'     => '',
                        'default'  => ''
                    ),
                    array(
                        'id'       => 'rss_url',
                        'type'     => 'text',
                        'title'    => esc_html__('RSS Feed URL', 'yolo-giraffe'),
                        'subtitle' => "Please enter in your RSS Feed URL",
                        'desc'     => '',
                        'default'  => ''
                    ),
                    array(
                        'id'       => 'email_address',
                        'type'     => 'text',
                        'title'    => esc_html__('Email address', 'yolo-giraffe'),
                        'subtitle' => "Please enter in your email address",
                        'desc'     => '',
                        'default'  => ''
                    ),
                    array(
                        'id'   =>'social-profile-divide-0',
                        'type' => 'divide'
                    ),
                )
            );

            // 404 Page error
            $this->sections[] = array(
                'title'      => esc_html__( '404 Setting', 'yolo-giraffe' ),
                'desc'       => '',
                'icon'       => 'el el-remove-circle',
                'fields'     => array(
                    array(
                        'id'        => 'page_title_404',
                        'type'      => 'text',
                        'title'     => esc_html__('Page Title 404', 'yolo-giraffe'),
                        'default'   => esc_html__('PAGE NOT FOUND!', 'yolo-giraffe'),
                    ),
                    array(
                        'id'        => 'sub_page_title_404',
                        'type'      => 'text',
                        'title'     => esc_html__( 'SubPage Title 404', 'yolo-giraffe' ),
                        'default'   => esc_html__( 'The page you were looking for appears to have been moved, deleted or does not exist.', 'yolo-giraffe' ),
                    ),
                    array(
                        'id'       => 'page_404_bg_image',
                        'type'     => 'media',
                        'url'      => true,
                        'title'    => esc_html__('Background 404 page', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Upload your background image here.', 'yolo-giraffe'),
                        'desc'     => '',
                        'default'  =>  array(
                            'url'  => $page_404_bg_url,
                        )
                    ),
                    array(
                        'id'        => 'go_back_404',
                        'type'      => 'text',
                        'title'     => esc_html__('Go back label', 'yolo-giraffe'),
                        'default'   => esc_html__('Back to Homepage', 'yolo-giraffe'),
                    ),
                    array(
                        'id'        => 'go_back_url_404',
                        'type'      => 'text',
                        'title'     => esc_html__('Go back link', 'yolo-giraffe'),
                        'default'   => '',
                    )
                )
            );

            // Teacher
            $this->sections[] = array(
                'title'      => esc_html__('Teacher','yolo-giraffe'),
                'desc'       => '',
                'icon'       => 'fa fa-user',
                'fields'     => array(
                    
                    array(
                        'id'     => 'section-archive-teacher-setting',
                        'type'   => 'section',
                        'title'  => esc_html__('Archive Teacher', 'yolo-giraffe'),
                        'indent' => true
                    ),
                    array(
                        'id'       => 'archive_teacher_sidebar',
                        'type'     => 'image_select',
                        'title'    => esc_html__('Sidebar Layout', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Set Archive Teacher Sidebar', 'yolo-giraffe'),
                        'desc'     => '',
                        'options'  => array(
                            'none'  => array('title' => '', 'img' => get_template_directory_uri().'/assets/images/theme-options/sidebar-none.png'),
                            'left'  => array('title' => '', 'img' => get_template_directory_uri().'/assets/images/theme-options/sidebar-left.png'),
                            'right' => array('title' => '', 'img' => get_template_directory_uri().'/assets/images/theme-options/sidebar-right.png')
                        ),
                        'default'  => 'none'
                    ),
                    array(
                        'id'       => 'inherit_archive_teacher_title',
                        'type'     => 'switch',
                        'title'    => esc_html__('Inherit Page Title ', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Enable/Disable Inherit Page Title Setting', 'yolo-giraffe'),
                        'default'  => true
                    ),
                    array(
                        'id'       => 'show_archive_teacher_title',
                        'type'     => 'switch',
                        'title'    => esc_html__('Show Archive Title', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Enable/Disable Archive Teacher Title', 'yolo-giraffe'),
                        'default'  => true,
                        'required' => array('inherit_archive_teacher_title', '=', array('0')),
                    ),
                    array(
                        'id'       => 'archive_teacher_title_parallax',
                        'type'     => 'switch',
                        'title'    => esc_html__( 'Archive Teacher Title Parallax', 'yolo-giraffe' ),
                        'subtitle' => esc_html__( 'Enable Archive Teacher Title Parallax', 'yolo-giraffe' ),
                        'default'  => false,
                        'required' => array('show_archive_teacher_title', '=', array('1')),
                    ),
                    array(
                        'id'       => 'archive_teacher_title_height',
                        'type'     => 'slider',
                        'title'    => esc_html__('Archive Teacher Title Height', 'yolo-giraffe'),
                        'desc'     => esc_html__('You can set a height for the archive teacher title here', 'yolo-giraffe'),
                        'required' => array('show_archive_teacher_title', '=', array('1')),
                        'min'      => 10,
                        'step'     => 1,
                        'max'      => 500,
                        'default'  => 300,
                        'output'   => array('.archive-teacher-title-height'),
                    ),
                    array(
                        'id'       => 'archive_teacher_title_bg_image',
                        'type'     => 'media',
                        'url'      => true,
                        'title'    => esc_html__('Archive Teacher Title Background', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Upload archive teacher title background.', 'yolo-giraffe'),
                        'desc'     => '',
                        'default'  => array(
                            'url' => $page_title_bg_url
                        ),
                        'required'  => array('show_archive_teacher_title', '=', array('1')),
                    ),
                    array(
                        'id'       => 'title_archive_teacher',
                        'type'     => 'text',
                        'title'    => esc_html__('Title Content Archive', 'yolo-giraffe'),
                        'subtitle' => "Please enter in your Title",
                        'desc'     => '',
                        'default'  => '',
                        'required'  => array('show_archive_teacher_title', '=', array('1')),
                    ),
                    array(
                        'id'      => 'archive_teacher_layout',
                        'type'    => 'select',
                        'multi'   => false,
                        'title'   => esc_html__('Archive Teacher Layout', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Select Archive Teacher Layout', 'yolo-giraffe'),
                        'options' => array(
                            'layout-1'   => esc_html__('Layout 1', 'yolo-giraffe'),
                            'layout-2'   => esc_html__('Layout 2', 'yolo-giraffe'),
                            'layout-3'   => esc_html__('Layout 3', 'yolo-giraffe'),
                            'layout-4'   => esc_html__('Layout 4', 'yolo-giraffe'),
                        ),
                        'desc'     => '',
                        'default'  => 'layout-1',
                    ),

                    array(
                        'id'      => 'archive_teacher_columns',
                        'type'    => 'select',
                        'multi'   => false,
                        'title'   => esc_html__('Archive Teacher Column', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Select Archive Teacher Column Display', 'yolo-giraffe'),
                        'options' => array(
                            '2'   => esc_html__('2 Columns', 'yolo-giraffe'),
                            '3'   => esc_html__('3 Columns', 'yolo-giraffe'),
                            '4'   => esc_html__('4 Columns', 'yolo-giraffe'),
                        ),
                        'desc'     => '',
                        'default'  => '2',
                    ),

                    // For single teacher

                    array(
                        'id'     => 'section-single-teacher-title',
                        'type'   => 'section',
                        'title'  => esc_html__('Single Teacher', 'yolo-giraffe'),
                        'indent' => true
                    ),
                    array(
                        'id'       => 'single_teacher_sidebar',
                        'type'     => 'image_select',
                        'title'    => esc_html__('Sidebar Layout', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Set Teacher Sidebar Position', 'yolo-giraffe'),
                        'desc'     => '',
                        'options'  => array(
                            'left'  => array('title' => '', 'img' => get_template_directory_uri().'/assets/images/theme-options/sidebar-left.png'),
                            'right' => array('title' => '', 'img' => get_template_directory_uri().'/assets/images/theme-options/sidebar-right.png')
                        ),
                        'default'  => 'right'
                    ),
                    array(
                        'id'       => 'single_teacher_title_parallax',
                        'type'     => 'switch',
                        'title'    => esc_html__( 'Single Teacher Title Parallax', 'yolo-giraffe' ),
                        'subtitle' => esc_html__( 'Enable Single Teacher Title Parallax', 'yolo-giraffe' ),
                        'default'  => false,
                    ),
                    array(
                        'id'       => 'single_teacher_title_height',
                        'type'     => 'slider',
                        'title'    => esc_html__('Single Teacher Title Height', 'yolo-giraffe'),
                        'desc'     => esc_html__('You can set a height for the single teacher title here', 'yolo-giraffe'),
                        'min'      => 10,
                        'step'     => 1,
                        'max'      => 500,
                        'default'  => 300,
                        'output'   => array('.single-teacher-title-height'),
                    ),
                    array(
                        'id'       => 'single_teacher_title_bg_image',
                        'type'     => 'media',
                        'url'      => true,
                        'title'    => esc_html__('Single Teacher Title Background', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Upload single teacher title background.', 'yolo-giraffe'),
                        'desc'     => '',
                        'default'  => array(
                            'url' => $page_title_bg_url
                        ),
                    ),
                )
            );
            
            // Single Class
            $this->sections[]  = array(
                'title'         => esc_html__('Class','yolo-giraffe'),
                'desc'          => '',
                'icon'          => 'fa fa-calendar',
                'fields'        => array(
                    
                    array(
                        'id'     => 'section-archive-class-setting',
                        'type'   => 'section',
                        'title'  => esc_html__('Archive Class', 'yolo-giraffe'),
                        'indent' => true
                    ),
                    array(
                        'id'       => 'archive_class_sidebar',
                        'type'     => 'image_select',
                        'title'    => esc_html__('Sidebar Layout', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Set Archive Class Sidebar', 'yolo-giraffe'),
                        'desc'     => '',
                        'options'  => array(
                            'none'  => array('title' => '', 'img' => get_template_directory_uri().'/assets/images/theme-options/sidebar-none.png'),
                            'left'  => array('title' => '', 'img' => get_template_directory_uri().'/assets/images/theme-options/sidebar-left.png'),
                            'right' => array('title' => '', 'img' => get_template_directory_uri().'/assets/images/theme-options/sidebar-right.png')
                        ),
                        'default'  => 'right'
                    ),
                    array(
                        'id'       => 'inherit_archive_class_title',
                        'type'     => 'switch',
                        'title'    => esc_html__('Inherit Page Title ', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Enable/Disable Inherit Page Title Setting', 'yolo-giraffe'),
                        'default'  => true
                    ),
                    array(
                        'id'       => 'show_archive_class_title',
                        'type'     => 'switch',
                        'title'    => esc_html__('Show Archive Title', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Enable/Disable Archive Class Title', 'yolo-giraffe'),
                        'default'  => true,
                        'required' => array('inherit_archive_class_title', '=', array('0')),
                    ),
                    array(
                        'id'       => 'archive_class_title_parallax',
                        'type'     => 'switch',
                        'title'    => esc_html__( 'Archive Class Title Parallax', 'yolo-giraffe' ),
                        'subtitle' => esc_html__( 'Enable Archive Class Title Parallax', 'yolo-giraffe' ),
                        'default'  => false,
                        'required' => array('show_archive_class_title', '=', array('1')),
                    ),
                    array(
                        'id'       => 'archive_class_title_height',
                        'type'     => 'slider',
                        'title'    => esc_html__('Archive Class Title Height', 'yolo-giraffe'),
                        'desc'     => esc_html__('You can set a height for the archive class title here', 'yolo-giraffe'),
                        'required' => array('show_archive_class_title', '=', array('1')),
                        'min'      => 10,
                        'step'     => 1,
                        'max'      => 500,
                        'default'  => 300,
                        'output'   => array('.archive-class-title-height'),
                    ),
                    array(
                        'id'       => 'archive_class_title_bg_image',
                        'type'     => 'media',
                        'url'      => true,
                        'title'    => esc_html__('Archive Class Title Background', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Upload archive class title background.', 'yolo-giraffe'),
                        'desc'     => '',
                        'default'  => array(
                            'url' => $page_title_bg_url
                        ),
                        'required'  => array('show_archive_class_title', '=', array('1')),
                    ),
                    array(
                        'id'       => 'title_archive_class',
                        'type'     => 'text',
                        'title'    => esc_html__('Title Content Archive', 'yolo-giraffe'),
                        'subtitle' => "Please enter in your Title",
                        'desc'     => '',
                        'default'  => '',
                        'required'  => array('show_archive_class_title', '=', array('1')),
                    ),

                    ///
                    array(
                        'id'     => 'section-single-class-setting',
                        'type'   => 'section',
                        'title'  => esc_html__('Single Class', 'yolo-giraffe'),
                        'indent' => true
                    ),
                    array(
                        'id'       => 'single_class_sidebar',
                        'type'     => 'image_select',
                        'title'    => esc_html__('Sidebar Layout', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Set Class Sidebar Position', 'yolo-giraffe'),
                        'desc'     => '',
                        'options'  => array(
                            'left'  => array('title' => '', 'img' => get_template_directory_uri().'/assets/images/theme-options/sidebar-left.png'),
                            'right' => array('title' => '', 'img' => get_template_directory_uri().'/assets/images/theme-options/sidebar-right.png')
                        ),
                        'default'  => 'right'
                    ),
                    array(
                        'id'       => 'single_class_title_parallax',
                        'type'     => 'switch',
                        'title'    => esc_html__( 'Single Class Title Parallax', 'yolo-giraffe' ),
                        'subtitle' => esc_html__( 'Enable Single Class Title Parallax', 'yolo-giraffe' ),
                        'default'  => false,
                    ),
                    array(
                        'id'       => 'single_class_title_height',
                        'type'     => 'slider',
                        'title'    => esc_html__('Single Class Title Height', 'yolo-giraffe'),
                        'desc'     => esc_html__('You can set a height for the single class title here', 'yolo-giraffe'),
                        'min'      => 10,
                        'step'     => 1,
                        'max'      => 500,
                        'default'  => 300,
                        'output'   => array('.single-class-title-height'),
                    ),
                    array(
                        'id'       => 'single_class_title_bg_image',
                        'type'     => 'media',
                        'url'      => true,
                        'title'    => esc_html__('Single Class Title Background', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Upload single class title background.', 'yolo-giraffe'),
                        'desc'     => '',
                        'default'  => array(
                            'url' => $page_title_bg_url
                        ),
                    ),
                     array(
                        'id'       => 'breadcrumbs_in_class_title',
                        'type'     => 'switch',
                        'title'    => esc_html__('Breadcrumbs', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Enable/Disable Breadcrumbs In Pages', 'yolo-giraffe'),
                        'default'  => true,
                    ),
                )
            );

            // Single Event
            $this->sections[]  = array(
                'title'         => esc_html__('Event','yolo-giraffe'),
                'desc'          => '',
                'icon'          => 'fa fa-bullhorn',
                'fields'        => array(
                    
                    array(  
                        'id'     => 'section-archive-event-setting',
                        'type'   => 'section',
                        'title'  => esc_html__('Archive Event', 'yolo-giraffe'),
                        'indent' => true
                    ),
                    array(
                        'id'       => 'archive_event_sidebar',
                        'type'     => 'image_select',
                        'title'    => esc_html__('Sidebar Layout', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Set Archive Events Sidebar', 'yolo-giraffe'),
                        'desc'     => '',
                        'options'  => array(
                            'none'  => array('title' => '', 'img' => get_template_directory_uri().'/assets/images/theme-options/sidebar-none.png'),
                            'left'  => array('title' => '', 'img' => get_template_directory_uri().'/assets/images/theme-options/sidebar-left.png'),
                            'right' => array('title' => '', 'img' => get_template_directory_uri().'/assets/images/theme-options/sidebar-right.png')
                        ),
                        'default'  => 'right'
                    ),
                    array(
                        'id'       => 'inherit_archive_event_title',
                        'type'     => 'switch',
                        'title'    => esc_html__('Inherit Page Title ', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Enable/Disable Inherit Page Title Setting', 'yolo-giraffe'),
                        'default'  => true
                    ),
                    array(
                        'id'       => 'show_archive_event_title',
                        'type'     => 'switch',
                        'title'    => esc_html__('Show Archive Title', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Enable/Disable Archive Event Title', 'yolo-giraffe'),
                        'default'  => true,
                        'required' => array('inherit_archive_event_title', '=', array('0')),
                    ),
                    array(
                        'id'       => 'archive_event_title_parallax',
                        'type'     => 'switch',
                        'title'    => esc_html__( 'Archive Event Title Parallax', 'yolo-giraffe' ),
                        'subtitle' => esc_html__( 'Enable Archive Event Title Parallax', 'yolo-giraffe' ),
                        'default'  => false,
                        'required' => array('show_archive_event_title', '=', array('1')),
                    ),
                    array(
                        'id'       => 'archive_event_title_height',
                        'type'     => 'slider',
                        'title'    => esc_html__('Archive Event Title Height', 'yolo-giraffe'),
                        'desc'     => esc_html__('You can set a height for the archive event title here', 'yolo-giraffe'),
                        'required' => array('show_archive_event_title', '=', array('1')),
                        'min'      => 10,
                        'step'     => 1,
                        'max'      => 500,
                        'default'  => 300,
                        'output'   => array('.archive-event-title-height'),
                    ),
                    array(
                        'id'       => 'archive_event_title_bg_image',
                        'type'     => 'media',
                        'url'      => true,
                        'title'    => esc_html__('Archive Event Title Background', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Upload archive event title background.', 'yolo-giraffe'),
                        'desc'     => '',
                        'default'  => array(
                            'url' => $page_title_bg_url
                        ),
                        'required'  => array('show_archive_event_title', '=', array('1')),
                    ),
                    array(
                        'id'       => 'title_archive_event',
                        'type'     => 'text',
                        'title'    => esc_html__('Title Content Archive', 'yolo-giraffe'),
                        'subtitle' => "Please enter in your Title",
                        'desc'     => '',
                        'default'  => '',
                        'required'  => array('show_archive_event_title', '=', array('1')),
                    ),

                    // Single Event
                    array(
                        'id'     => 'section-single-event-setting',
                        'type'   => 'section',
                        'title'  => esc_html__('Single Event', 'yolo-giraffe'),
                        'indent' => true
                    ),
                    array(
                        'id'       => 'single_event_sidebar',
                        'type'     => 'image_select',
                        'title'    => esc_html__('Sidebar Layout', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Set Events Sidebar Position', 'yolo-giraffe'),
                        'desc'     => '',
                        'options'  => array(
                            'left'  => array('title' => '', 'img' => get_template_directory_uri().'/assets/images/theme-options/sidebar-left.png'),
                            'right' => array('title' => '', 'img' => get_template_directory_uri().'/assets/images/theme-options/sidebar-right.png')
                        ),
                        'default'  => 'right'
                    ),
                    array(
                        'id'       => 'single_event_title_parallax',
                        'type'     => 'switch',
                        'title'    => esc_html__( 'Single Event Title Parallax', 'yolo-giraffe' ),
                        'subtitle' => esc_html__( 'Enable Single Event Title Parallax', 'yolo-giraffe' ),
                        'default'  => false,
                    ),
                    array(
                        'id'       => 'single_event_title_height',
                        'type'     => 'slider',
                        'title'    => esc_html__('Single Event Title Height', 'yolo-giraffe'),
                        'desc'     => esc_html__('You can set a height for the single event title here', 'yolo-giraffe'),
                        'min'      => 10,
                        'step'     => 1,
                        'max'      => 500,
                        'default'  => 300,
                        'output'   => array('.single-event-title-height'),
                    ),
                    array(
                        'id'       => 'single_event_title_bg_image',
                        'type'     => 'media',
                        'url'      => true,
                        'title'    => esc_html__('Single Event Title Background', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Upload single event title background.', 'yolo-giraffe'),
                        'desc'     => '',
                        'default'  => array(
                            'url' => $page_title_bg_url
                        ),
                    ),
                )
            );

			// Custom CSS & Script
            $this->sections[] = array(
                'title'  => esc_html__( 'Custom CSS & Script', 'yolo-giraffe' ),
                'desc'   => esc_html__( 'If you change Custom CSS, you must "Save & Generate CSS"', 'yolo-giraffe' ),
                'icon'   => 'el el-edit',
                'fields' => array(
                    array(
                        'id'       => 'custom_css',
                        'type'     => 'ace_editor',
                        'mode'     => 'css',
                        'theme'    => 'monokai',
                        'title'    => esc_html__('Custom CSS', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Add some CSS to your theme by adding it to this textarea. Please do not include any style tags.', 'yolo-giraffe'),
                        'desc'     => '',
                        'default'  => '',
                        'options'  => array('minLines'=> 10, 'maxLines' => 60)
                    ),
                    array(
                        'id'       => 'custom_js',
                        'type'     => 'ace_editor',
                        'mode'     => 'javascript',
                        'theme'    => 'chrome',
                        'title'    => esc_html__('Custom JS', 'yolo-giraffe'),
                        'subtitle' => esc_html__('Add some custom JavaScript to your theme by adding it to this textarea. Please do not include any script tags.', 'yolo-giraffe'),
                        'desc'     => '',
                        'default'  => '',
                        'options'  => array('minLines'=> 10, 'maxLines' => 60)
                    ),

                )
            );
            
        }

        public function setHelpTabs() {
        }

        /**
         * All the possible arguments for Redux.
         * For full documentation on arguments, please refer to: https://github.com/ReduxFramework/ReduxFramework/wiki/Arguments
         * */
        public function setArguments() {

            $theme = wp_get_theme(); // For use with some settings. Not necessary.
            $this->args = array(
                // TYPICAL -> Change these values as you need/desire
                'opt_name'           => 'yolo_giraffe_options',
                // This is where your data is stored in the database and also becomes your global variable name.
                'display_name'       => $theme->get( 'Name' ),
                // Name that appears at the top of your panel
                'display_version'    => $theme->get( 'Version' ),
                // Version that appears at the top of your panel
                'menu_type'          => 'submenu',
                //Specify if the admin menu should appear or not. Options: menu or submenu (Under appearance only)
                'allow_sub_menu'     => true,
                // Show the sections below the admin menu item or not
                'menu_title'         => esc_html__( 'Theme Options', 'yolo-giraffe' ),
                'page_title'         => esc_html__( 'Theme Options', 'yolo-giraffe' ),
                // You will need to generate a Google API key to use this feature.
                // Please visit: https://developers.google.com/fonts/docs/developer_api#Auth
                'google_api_key'     => '',
                // Must be defined to add google fonts to the typography module

                'async_typography'   => false,
                // Use a asynchronous font on the front end or font string
                'admin_bar'          => true,
                // Show the panel pages on the admin bar
                'global_variable'    => '',
                // Set a different name for your global variable other than the opt_name
                'dev_mode'           => false,
                // Show the time the page took to load, etc
                'forced_dev_mode_off' => true,
                // To forcefully disable the dev mode
                'templates_path'     => get_template_directory().'/framework/core/templates/panel',
                // Path to the templates file for various Redux elements
                'customizer'         => true,
                // Enable basic customizer support

                // OPTIONAL -> Give you extra features
                'page_priority'      => null,
                // Order where the menu appears in the admin area. If there is any conflict, something will not show. Warning.
                'page_parent'        => 'yolo-options',
                // For a full list of options, visit: http://codex.wordpress.org/Function_Reference/add_theme_page#Parameters
                'page_permissions'   => 'manage_options',
                // Permissions needed to access the options panel.
                'menu_icon'          => '',
                // Specify a custom URL to an icon
                'last_tab'           => '',
                // Force your panel to always open to a specific tab (by id)
                'page_icon'          => 'icon-themes',
                // Icon displayed in the admin panel next to your menu_title
                'page_slug'          => '_options',
                // Page slug used to denote the panel
                'save_defaults'      => true,
                // On load save the defaults to DB before user clicks save or not
                'default_show'       => false,
                // If true, shows the default value next to each field that is not the default value.
                'default_mark'       => '',
                // What to print by the field's title if the value shown is default. Suggested: *
                'show_import_export' => true,
                // Shows the Import/Export panel when not used as a field.

                // CAREFUL -> These options are for advanced use only
                'transient_time'     => 60 * MINUTE_IN_SECONDS,
                'output'             => true,
                // Global shut-off for dynamic CSS output by the framework. Will also disable google fonts output
                'output_tag'         => true,
                // Allows dynamic CSS to be generated for customizer and google fonts, but stops the dynamic CSS from going to the head
                // 'footer_credit'     => '',                   // Disable the footer credit of Redux. Please leave if you can help it.

                // FUTURE -> Not in use yet, but reserved or partially implemented. Use at your own risk.
                'database'           => '',
                // possible: options, theme_mods, theme_mods_expanded, transient. Not fully functional, warning!
                'system_info'        => false,
                // REMOVE

                // HINTS
                'hints'              => array(
                    'icon'          => 'icon-question-sign',
                    'icon_position' => 'right',
                    'icon_color'    => 'lightgray',
                    'icon_size'     => 'normal',
                    'tip_style'     => array(
                        'color'   => 'light',
                        'shadow'  => true,
                        'rounded' => false,
                        'style'   => '',
                    ),
                    'tip_position'  => array(
                        'my' => 'top left',
                        'at' => 'bottom right',
                    ),
                    'tip_effect'    => array(
                        'show' => array(
                            'effect'   => 'slide',
                            'duration' => '500',
                            'event'    => 'mouseover',
                        ),
                        'hide' => array(
                            'effect'   => 'slide',
                            'duration' => '500',
                            'event'    => 'click mouseleave',
                        ),
                    ),
                )
            );

            // SOCIAL ICONS -> Setup custom links in the footer for quick links in your panel footer icons.
            $args['share_icons'][] = array(
                'url'   => 'https://github.com/ReduxFramework/ReduxFramework',
                'title' => 'Visit us on GitHub',
                'icon'  => 'el el-github'
                //'img'   => '', // You can use icon OR img. IMG needs to be a full URL.
            );
            $args['share_icons'][] = array(
                'url'   => 'https://www.facebook.com/pages/Redux-Framework/243141545850368',
                'title' => 'Like us on Facebook',
                'icon'  => 'el el-facebook'
            );
            $args['share_icons'][] = array(
                'url'   => 'http://twitter.com/reduxframework',
                'title' => 'Follow us on Twitter',
                'icon'  => 'el el-twitter'
            );
            $args['share_icons'][] = array(
                'url'   => 'http://www.linkedin.com/company/redux-framework',
                'title' => 'Find us on LinkedIn',
                'icon'  => 'el el-linkedin'
            );

        }

    }

    global $reduxConfig;
    $reduxConfig = new Redux_Framework_options_config();
}