<?php
/**
 * Theme functions for YOLO Framework.
 * This file include the framework functions, it should remain intact between themes.
 * For theme specified functions, see file functions-<theme name>.php
 *
 * @package    YoloTheme
 * @version    1.0.0
 * @author     Administrator <admin@yolotheme.com>
 * @copyright  Copyright (c) 2016, YoloTheme
 * @license    http://opensource.org/licenses/gpl-2.0.php GPL v2 or later
 * @link       http://yolotheme.com
*/

// Load the Options Panel
require get_template_directory()  . '/framework/yolo-framework.php';

if (!function_exists('yolo_timetable_get_class_by_teacher')) {
    function yolo_timetable_get_class_by_teacher($teacher_id) {
        global $post, $post_class;
        $args = array(
            'posts_per_page' => -1,
            'post_type'      => 'yolo_class',
            'post_status'    => 'publish',
            'meta_query' => array(
                array(
                    'key'     => '_teacher',
                    'value'   => serialize( strval( $teacher_id ) ),
                    'compare' => 'LIKE',
                ),
            ),
        );
        $r = new WP_Query($args);
        if($r->have_posts()):
            $post_class = 'class-item-wrap col-6 col-sm-6 col-md-6 col-lg-6';
            $show_date = true;
            $show_time = true;
            $post_options = compact('post_class', 'show_date', 'show_time');

            while ($r->have_posts()): 
                $r->the_post();
                yolo_timetable_get_template( 'content-class.php' ); 
            endwhile;
        endif;
        wp_reset_query();
    }
}

if (!function_exists('yolo_timetable_get_gallery')) {
    function yolo_timetable_get_gallery($gallery)
    {
        if (!empty($gallery)) {
            wp_enqueue_script('owl-carousel');
            wp_enqueue_style('owl-carousel');
            $data_section_id = uniqid();
            ?>
            <div class="gallery-top">
                <div class="post-slideshow owl-carousel owl-theme" id="post_slideshow_<?php echo esc_attr($data_section_id); ?>">
                    <?php if( count($gallery) > 0 ) :
                        $index = 0;
                        foreach($gallery as $image) :
                            $urls = wp_get_attachment_image_src($image,'full');
                            $img  = '';
                            if ($urls) {
                                if(count($urls)>0) {
                                    $resize = yolo_image_resize($urls[0],1080,768);
                                    if( $resize != null && is_array($resize) )
                                        $img = $resize['url'];
                                }
                            } else {
                                continue;
                            }
                    ?>
                    <div class="item">
                        <a class="nav-post-slideshow" href="javascript:;" data-section-id="<?php echo esc_attr($data_section_id) ?>" data-index="<?php echo esc_attr($index++) ?>">
                            <img alt="portfolio" src="<?php echo esc_url($img) ?>" width = "<?php echo esc_attr($resize['width']);?>" height = "<?php echo esc_attr($resize['height']);?>"/>
                        </a>
                    </div>
                        <?php endforeach; ?>
                    <?php endif; ?>
                </div>
            </div>
            <div class="paging-wrap">
                <div class="slideshow-paging owl-carousel owl-theme" data-current-index="0" data-total-items="<?php echo esc_attr(count($gallery)) ?>" id="slideshow_paging_<?php echo esc_attr($data_section_id) ?>">
                    <?php if(count($gallery) > 0){
                        $index = 0;
                        foreach($gallery as $image){
                            $urls = wp_get_attachment_image_src($image,'full');
                            $img = '';
                            if ($urls) {
                                if(count($urls)>0){
                                    $resize = yolo_image_resize($urls[0],180,130);
                                    if($resize!=null && is_array($resize) )
                                        $img = $resize['url'];
                                } 
                            } else {
                                continue;
                            }
                            ?>
                            <div class="item">
                                <a href="javascript:;" class="nav-slideshow" data-section-id="<?php echo esc_attr($data_section_id) ?>" data-index="<?php echo esc_attr($index++) ?>" >
                                    <img alt="portfolio" src="<?php echo esc_url($img) ?>" width = "<?php echo esc_attr($resize['width']);?>" height = "<?php echo esc_attr($resize['height']);?>"/>
                                </a>
                            </div>
                        <?php }
                    }
                    ?>
                </div>
            </div>
            <script>
                (function($) {
                    "use strict";
                    $(document).ready(function(){
                        var sync1    = $(".post-slideshow");
                        var sync2    = $(".slideshow-paging");
                        var flag     = false;
                        var duration = 500;

                        sync1.owlCarousel({
                                items: 1,
                                margin: 0,
                                <?php if(is_rtl()) : ?> rtl : true, <?php endif;?>
                                nav: false,
                                dots: false
                            })
                            .on('changed.owl.carousel', function (e) {
                                if (!flag) {
                                    flag = true;
                                    sync2.trigger('to.owl.carousel', [e.item.index, duration, true]);
                                    flag = false;
                                }
                                // Add class synced to current slide
                                var current = e.item.index;
                                $(".slideshow-paging")
                                    .find(".owl-item")
                                    .removeClass("synced")
                                    .eq(current)
                                    .addClass("synced");
                            });

                        sync2.owlCarousel({
                                margin: 20,
                                items: 5,
                                <?php if(is_rtl()) : ?> rtl : true, <?php endif;?>
                                nav: true,
                                navText: ["<i class='fa fa-angle-left'></i>","<i class='fa fa-angle-right'></i>"],
                                center: false,
                                dots: false,
                                responsive: {
                                    0: {
                                        items: 3
                                    },
                                    500: {
                                        items: 4
                                    },
                                    991: {
                                        items: 4
                                    },
                                    1200: {
                                        items: 5
                                    },
                                },
                                onInitialized : function(){
                                    sync2.find(".owl-item").eq(0).addClass("synced");
                                }
                            })
                            .on('click', '.owl-item', function () {
                                sync1.trigger('to.owl.carousel', [$(this).index(), duration, true]);
                            })
                            .on('changed.owl.carousel', function (e) {
                                if (!flag) {
                                    flag = true;        
                                    sync1.trigger('to.owl.carousel', [e.item.index, duration, true]);
                                    flag = false;
                                }
                            });
                    })
                })(jQuery);
            </script>
            <?php
        }
    }
}

if (!function_exists('yolo_timetable_single_class_tab_teacher')) {
    function yolo_timetable_single_class_tab_teacher($teacher_id) {
        global $yolo_giraffe_options;
        
        $style = isset($yolo_giraffe_options['archive_teacher_layout']) ? $yolo_giraffe_options['archive_teacher_layout'] : 'layout-2';

        $thumbnail    = get_the_post_thumbnail_url( $teacher_id );

        if ($style == 'layout-2' || $style == 'layout-1') {
        ?>
            <article class=" teacher-item-wrap ">
                <div class="yolo-flex -row teacher-item"  <?php if($style== 'layout-2'): ?> style="background-color: <?php echo rand_color('hex') ?>" <?php endif;  ?>>
                    <div class="teacher-avatar-wrap yolo-flex -col -center fb-5">
                        <div class="entry-teacher-bg" style="background-image: url('<?php echo esc_url($thumbnail); ?>')"></div>
                        <a class="teacher-avatar" href="<?php echo get_permalink( $teacher_id ) ; ?>">
                        </a>
                        <?php
                            $facebook  =   yolo_timetable_get_post_meta( $teacher_id, "_yolo_teacher_facebook", '' );
                            $google    =   yolo_timetable_get_post_meta( $teacher_id, "_yolo_teacher_google", '' );
                            $twitter   =   yolo_timetable_get_post_meta( $teacher_id, "_yolo_teacher_twitter", '' );
                            $pinterest =   yolo_timetable_get_post_meta( $teacher_id, "_yolo_teacher_pinterest", '' );
                        ?>
                        <?php if(!empty($facebook) || !empty($twitter) || !empty($google) || !empty($linkedin) || !empty($pinterest)):?>
                            <div class="teacher-social">
                                <ul>
                                    <?php echo ( !empty($facebook) ? '<li><a href="' . $facebook . '" class="fab fa-facebook-f"></a></li>' : '' ); ?>
                                    <?php echo ( !empty($google) ? '<li><a href="' . $google . '" class="fab fa-google-plus-g"></a></li>' : '' ); ?>
                                    <?php echo ( !empty($twitter) ? '<li><a href="' . $twitter . '" class="fab fa-twitter"></a></li>' : '' ); ?>
                                    <?php echo ( !empty($pinterest) ? '<li><a href="' . $pinterest . '" class="fab fa-pinterest-p"></a></li>' : '' ); ?>
                                </ul>
                            </div>
                        <?php endif; ?>
                    </div>
                    
                    <div class="teacher-info  fb-7">
                        <h3 class="teacher-title">
                            <a title="<?php printf( esc_html__( 'Post by %s','yolo-giraffe'), get_the_title($teacher_id) ); ?>" href="<?php echo get_permalink($teacher_id) ; ?>" rel="author">
                                <?php echo get_the_title($teacher_id) ?>
                            </a>
                        </h3>
                        <div class="teacher-category">
                            <?php
                                echo get_the_term_list($teacher_id, 'class_category',' ',', ');
                            ?>
                        </div>
                        <div class="teacher-excerpt">
                            <?php
                            global $post;
                            $excerpt = $post->post_excerpt;
                            if(empty($excerpt))
                                $excerpt = $post->post_content;
                            
                            $excerpt = strip_shortcodes($excerpt);
                            $exc_length = YOLO_Settings()->get_option('yolo_teacher_excerpt_length', 15);
                            echo '<p>' . wp_trim_words($excerpt, $exc_length, '...') . '</p>';
                            $telephone = preg_replace('/\s+/','',yolo_timetable_get_post_meta( $teacher_id, '_yolo_teacher_phone'));
                            ?>
                        </div>
                        
                        <div class="btn-call-me">
                            <a class="btn call-me" title="<?php printf( esc_html__( 'Post by %s','yolo-giraffe'), get_the_title( $teacher_id ) ); ?>" href="tel:<?php echo esc_attr($telephone); ?>" rel="author">
                                <i class="fa fa-phone-square" aria-hidden="true"></i>
                                <?php echo yolo_timetable_get_post_meta( $teacher_id, '_yolo_teacher_phone'); ?>
                            </a>
                        </div>
                    </div>
                </div>
            </article>
        <?php } else { ?>
            <article class="col-6 col-sm-6 col-md-6 teacher-item-wrap yolo_teacher type-yolo_teacher <?php echo esc_attr($style); ?>">
                <div class="teacher-item">
                    <div class="teacher-avatar">
                        <?php echo get_the_post_thumbnail( $teacher_id ); ?>
                        <div class="teacher-infor-main <?php echo (!empty($style) && $style == 'layout-3')? 'hidden' : ''; ?>">
                            <h4 class="teacher-title">
                                <a title="<?php printf( esc_html__( 'Post by %s','yolo-giraffe'), get_the_title($teacher_id) ); ?>" href="<?php echo get_permalink($teacher_id) ; ?>" rel="author">
                                    <?php echo get_the_title($teacher_id) ?>
                                </a>
                            </h4>
                            <div class="teacher-category">
                                <?php
                                     echo get_the_term_list($teacher_id, 'class_category',' ',', ');
                                ?>
                            </div>
                        </div>
                    </div>
                    <div class="infor-overlay">
                        <div class="teacher-infor">
                            <h4 class="teacher-title">
                                <a title="<?php printf( esc_html__( 'Post by %s','yolo-giraffe'), get_the_title($teacher_id) ); ?>" href="<?php echo get_permalink($teacher_id) ; ?>" rel="author">
                                    <?php echo get_the_title($teacher_id) ?>
                                </a>
                            </h4>
                            <div class="teacher-category">
                                <?php
                                    echo get_the_term_list($teacher_id, 'class_category',' ',', ');
                                ?>
                            </div>
                            <div class="thumbnail-img">
                                <a class="teacher-avatar-hover" href="<?php echo get_permalink($teacher_id) ; ?>" style="background-image: url('<?php echo esc_url($thumbnail); ?>')">
                                </a>
                            </div>
                            <?php
                                $facebook       =   yolo_timetable_get_post_meta( $teacher_id, "_yolo_teacher_facebook", '' );
                                $google         =   yolo_timetable_get_post_meta( $teacher_id, "_yolo_teacher_google", '' );
                                $twitter        =   yolo_timetable_get_post_meta( $teacher_id, "_yolo_teacher_twitter", '' );
                                $pinterest      =   yolo_timetable_get_post_meta( $teacher_id, "_yolo_teacher_pinterest", '' );
                            ?>
                            <?php if(!empty($facebook) || !empty($twitter) || !empty($google) || !empty($linkedin) || !empty($pinterest)):?>
                                <div class="teacher-social">
                                    <?php echo ( !empty($facebook) ? '<a href="' . $facebook . '" class="fab fa-facebook-f"></a>' : '' ); ?>
                                    <?php echo ( !empty($google) ? '<a href="' . $google . '" class="fab fa-google-plus-g"></a>' : '' ); ?>
                                    <?php echo ( !empty($twitter) ? '<a href="' . $twitter . '" class="fab fa-twitter"></a>' : '' ); ?>
                                    <?php echo ( !empty($pinterest) ? '<a href="' . $pinterest . '" class="fab fa-pinterest-p"></a>' : '' ); ?>
                                </div>
                            <?php endif; ?>
                            <?php $email    =  yolo_timetable_get_post_meta( $teacher_id,'_yolo_teacher_email','');?>
                            <?php if(isset($email) || !empty($email)): ?>
                                <span class="email"><?php echo esc_attr($email); ?></span>
                            <?php endif; ?>
                        </div>
                    </div>
                </div>
            </article>
        <?php } ?>
    <?php
    }
}

if (!function_exists('yolo_timetable_single_class_basic_info')) {
    function yolo_timetable_single_class_basic_info($post_id){
        ?>
        <div class="basic-info class-teacher">
            <div class="basic-img">
                <?php 
                    $teacher_ids = yolo_get_post_meta($post_id,'_teacher',true);
                    $class_tr    = '';

                    if( !empty( $teacher_ids )):
                        foreach ($teacher_ids as $k => $teid) :
                            if ( $k==2 ) break;
                            if (count($teacher_ids) > 1) {
                                if ( $k == 0 ) {
                                    $class_tr = 'first';
                                } else {
                                    $class_tr = 'second';
                                }
                            } else {
                                $class_tr = '';
                            }
                            $teacher_image_url = wp_get_attachment_image_src( get_post_thumbnail_id($teid), array(90, 90) ); 
                            ?>
                            <div class="loop-item-teacher <?php echo esc_attr( $class_tr ); ?>" style="background-image:url('<?php echo esc_url($teacher_image_url[0]); ?>');">
                            </div>
                        <?php
                        endforeach;
                endif; ?>
            </div>
            <div class="basic-content">
                <h5 class="item-label"><?php esc_html_e('Teacher','yolo-giraffe'); ?></h5>
                <div class="item-value">
                    <?php 
                    $teacher_ids = yolo_get_post_meta($post_id,'_teacher',true);
                    if( !empty( $teacher_ids )):
                        foreach ($teacher_ids as $k => $teid) :
                            ?>
                            <a href="<?php echo get_permalink($teid)?>"><?php echo get_the_title($teid)?></a>
                            <?php if ( ($k+1) < count($teacher_ids) ) echo ','; ?>
                        <?php
                        endforeach;
                    endif; ?>
                </div>
            </div>
        </div>
        <div class="basic-info class-category">
            <div class="basic-img">
                <?php 
                    $cat_ids = get_the_terms($post_id,'class_category', 1);
                    $class_tr    = '';
                    foreach($cat_ids as $catid):
                        $thumb_id = get_term_meta( $catid->term_id, 'thumbnail_id', true ); ?>

                        <div class="thumbnail <?php echo esc_attr( $class_tr ); ?>">
                            <?php  echo wp_get_attachment_image ( $thumb_id, 'thumbnail'); ?>
                        </div>
                    <?php 
                    endforeach; 
                    ?>
            </div>
            <div class="basic-content">
                <h5 class="item-label"><?php esc_html_e('Categories','yolo-giraffe'); ?></h5>
                <div class="item-value">
                    <?php echo get_the_term_list($post_id, 'class_category','',', ')?>
                </div>
            </div>
        </div>
        <?php
    }
}