<?php
/**
 * Mini-cart
 *
 * Contains the markup for the mini-cart, used by the cart widget.
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/cart/mini-cart.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see     https://docs.woocommerce.com/document/template-structure/
 * @author  WooThemes
 * @package WooCommerce/Templates
 * @version 3.7.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}
global $yolo_giraffe_options;
$mini_cart_style = isset($yolo_giraffe_options['mini_cart_style']) ? $yolo_giraffe_options['mini_cart_style'] : 'hover';

if (!isset($args) || !isset($args['list_class'])) {
	$args['list_class'] = '';
}

$custom_class = 'scrollbar-inner';
if( $mini_cart_style == 'canvas' )
	$custom_class = 'scrollbar-inner-canvas';

?>

<?php do_action( 'woocommerce_before_mini_cart' ); ?>

	<ul class="woocommerce-mini-cart cart_list product_list_widget <?php echo esc_attr( $args['list_class'] );?>">

		<?php if ( ! WC()->cart->is_empty() ) : ?>

			<?php do_action( 'woocommerce_before_mini_cart_contents' ); ?>

			<?php
				foreach ( WC()->cart->get_cart() as $cart_item_key => $cart_item ) {
					$_product     = apply_filters( 'woocommerce_cart_item_product', $cart_item['data'], $cart_item, $cart_item_key );
					$product_id   = apply_filters( 'woocommerce_cart_item_product_id', $cart_item['product_id'], $cart_item, $cart_item_key );

					if ( $_product && $_product->exists() && $cart_item['quantity'] > 0 && apply_filters( 'woocommerce_widget_cart_item_visible', true, $cart_item, $cart_item_key ) ) {
						$product_name      = apply_filters( 'woocommerce_cart_item_name', $_product->get_name(), $cart_item, $cart_item_key );
						$thumbnail         = apply_filters( 'woocommerce_cart_item_thumbnail', $_product->get_image(), $cart_item, $cart_item_key );
						$product_price     = apply_filters( 'woocommerce_cart_item_price', WC()->cart->get_product_price( $_product ), $cart_item, $cart_item_key );
						$product_permalink = apply_filters( 'woocommerce_cart_item_permalink', $_product->is_visible() ? $_product->get_permalink( $cart_item ) : '', $cart_item, $cart_item_key );
						?>
						<li class="woocommerce-mini-cart-item <?php echo esc_attr( apply_filters( 'woocommerce_mini_cart_item_class', 'mini_cart_item', $cart_item, $cart_item_key ) ); ?>">
							<div class="cart-left">
								<?php if ( ! $_product->is_visible() ) { ?>
									<?php echo str_replace( array( 'http:', 'https:' ), '', $thumbnail ); ?>
								<?php } else { ?>
									<a href="<?php echo esc_url( $product_permalink ); ?>">
										<?php echo str_replace( array( 'http:', 'https:' ), '', $thumbnail ) ?>
									</a>
								<?php } ?>
							</div>
							<div class="cart-right">
								<?php if ( ! $_product->is_visible() ) { ?>
									<?php echo esc_html($product_name); ?>
								<?php } else { ?>
									<a href="<?php echo esc_url( $product_permalink ); ?>">
										<?php echo esc_html($product_name); ?>
									</a>
								<?php } ?>
								<?php echo wc_get_formatted_cart_item_data( $cart_item ); ?>

								<?php echo apply_filters( 'woocommerce_widget_cart_item_quantity', '<span class="quantity">' . sprintf( '%s &times; %s', $cart_item['quantity'], $product_price ) . '</span>', $cart_item, $cart_item_key ); ?>

								<?php echo apply_filters( 'woocommerce_cart_item_remove_link', sprintf('<a href="%s" class="mini-cart-remove remove remove_from_cart_button" aria-label="%s" data-product_id="%s" data-cart_item_key="%s" data-product_sku="%s">&times;</a>',
									esc_url( wc_get_cart_remove_url( $cart_item_key ) ),
									esc_html__( 'Remove this item', 'yolo-giraffe' ),
									esc_attr( $product_id ),
									esc_attr( $cart_item_key ),
									esc_attr( $_product->get_sku() )
								), $cart_item_key );?>
							</div>
						</li>
						<?php
					}
				}
			?>

			<?php do_action( 'woocommerce_mini_cart_contents' ); ?>

		<?php else : ?>

			<li class="empty"><?php esc_html_e( 'No products in the cart.', 'yolo-giraffe' ); ?></li>

		<?php endif; ?>

	</ul><!-- end product list -->

	<?php if ( sizeof( WC()->cart->get_cart() ) > 0 ) : ?>
		<div class="cart-total">
			<p class="total"><strong><?php esc_html_e( 'Total', 'yolo-giraffe' ); ?>:</strong> <?php echo WC()->cart->get_cart_subtotal(); ?></p>

			<?php do_action( 'woocommerce_widget_shopping_cart_before_buttons' ); ?>

			<p class="buttons">
				<?php if (isset($yolo_giraffe_options['header_shopping_cart_button']) && ($yolo_giraffe_options['header_shopping_cart_button']['view-cart'] == '1')):?>
					<a href="<?php echo esc_url(wc_get_cart_url()) ?>" class="button wc-forward"><?php esc_html_e( 'View Cart', 'yolo-giraffe' ); ?></a>
				<?php endif; ?>
				<?php if (isset($yolo_giraffe_options['header_shopping_cart_button']) && ($yolo_giraffe_options['header_shopping_cart_button']['checkout'] == '1')):?>
					<a href="<?php echo wc_get_checkout_url(); ?>" class="button checkout wc-forward"><?php esc_html_e( 'Checkout', 'yolo-giraffe' ); ?></a>
				<?php endif; ?>
			</p>
		</div>
	<?php endif; ?>

	<?php do_action( 'woocommerce_after_mini_cart' ); ?>