<?php
/**
 * The Template for displaying all single products.
 *
 * Override this template by copying it to yourtheme/woocommerce/single-product.php
 *
 * @author 		WooThemes
 * @package 	WooCommerce/Templates
 * @version     3.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}
global $yolo_woocommerce_loop,$yolo_giraffe_options;
$prefix = 'yolo_';
$layout_style = get_post_meta(get_the_ID(), $prefix.'page_layout',true);
if (($layout_style === '') || ($layout_style == '-1')) {
    $layout_style = isset($yolo_giraffe_options['single_product_layout']) ? $yolo_giraffe_options['single_product_layout'] : 'container';
}
$sidebar = get_post_meta(get_the_ID(), $prefix.'page_sidebar',true);
if (($sidebar === '') || ($sidebar == '-1')) {
    $sidebar = isset($yolo_giraffe_options['single_product_sidebar']) ? $yolo_giraffe_options['single_product_sidebar'] : '';
}
$left_sidebar = get_post_meta(get_the_ID(), $prefix.'page_left_sidebar',true);
if (($left_sidebar === '') || ($left_sidebar == '-1')) {
    $left_sidebar = isset($yolo_giraffe_options['single_product_left_sidebar']) ? $yolo_giraffe_options['single_product_left_sidebar'] : '';
}
$right_sidebar = get_post_meta(get_the_ID(), $prefix.'page_right_sidebar',true);
if (($right_sidebar === '') || ($right_sidebar == '-1')) {
    $right_sidebar = isset($yolo_giraffe_options['single_product_right_sidebar']) ? $yolo_giraffe_options['single_product_right_sidebar'] : '';
}
$sidebar_width = get_post_meta(get_the_ID(), $prefix.'sidebar_width',true);
if (($sidebar_width === '') || ($sidebar_width == '-1')) {
    $sidebar_width = isset($yolo_giraffe_options['single_product_sidebar_width']) ? $yolo_giraffe_options['single_product_sidebar_width'] : 'small';
}
// Calculate sidebar column & content column
$sidebar_col = 'col-md-3';
if ($sidebar_width == 'large') {
    $sidebar_col = 'col-md-4';
}

$sidebar_class = '';

$content_col_number = 12;
if (is_active_sidebar($left_sidebar) && ($sidebar == 'left') || is_active_sidebar($right_sidebar) && ($sidebar == 'right')) {
    if ($sidebar_width == 'large') {
        $content_col_number -= 4;
    } else {
        $content_col_number -= 3;
    }

    $sidebar_class = 'sidebar-' . $sidebar;
}

$content_col = 'col-md-' . $content_col_number;
if (($content_col_number == 12) && ($layout_style == 'full')) {
    $content_col = '';
}
$main_class = array('single-product-wrap single-content-main');
if ($content_col_number < 12) {
    $main_class[] = 'has-sidebar';
}
get_header( 'shop' ); ?>

<?php
/**
 * @hooked - yolo_page_heading - 5
 **/
do_action('yolo_before_page');

?>
<main class="<?php echo esc_attr(join(' ',$main_class)); ?>">

    <div class="<?php echo esc_attr($layout_style) ?> clearfix">

        <?php if (($content_col_number != 12) || ($layout_style != 'full')): ?>
        <div class="row clearfix  <?php echo esc_attr($sidebar_class); ?> ">
        <?php endif;?>

            <div class="site-content-single-product <?php echo esc_attr($content_col) ?>">
                <div class="single-product-inner">
                    <?php while ( have_posts() ) : the_post(); ?>

                        <?php wc_get_template_part( 'content', 'single-product' ); ?>

                    <?php endwhile; // end of the loop. ?>
                </div>
            </div>

            <?php if ( is_active_sidebar( $right_sidebar ) && $sidebar == 'right' ) : ?>
                <div class="sidebar woocommerce-sidebar <?php echo esc_attr($sidebar_col) ?> hidden-sm hidden-xs">
                    <?php dynamic_sidebar( $right_sidebar );?>
                </div>
            <?php endif; ?>

            <?php if (is_active_sidebar( $left_sidebar ) && $sidebar == 'left' ) : ?>
                <div class="sidebar woocommerce-sidebar <?php echo esc_attr($sidebar_col) ?> hidden-sm hidden-xs">
                    <?php dynamic_sidebar( $left_sidebar ); ?>
                </div>
            <?php endif; ?>

        <?php if (($content_col_number != 12) || ($layout_style != 'full')): ?>
        </div>
        <?php endif;?>

    </div>

    <?php
        /**
         * woocommerce_after_single_product_summary hook
         *
         * @hooked woocommerce_output_product_data_tabs - 10
         * @hooked woocommerce_upsell_display - 15
         * @hooked woocommerce_output_related_products - 20
         */
    ?>

</main>
<?php get_footer( 'shop' ); ?>