<?php
/**
 * The template for displaying class content within loops
 *
 * This template can be overridden by copying it to yourtheme/yolo-timetable/content-class.php.
 *
 * @author      YoloTheme
 * @package     YoloTimetable/Templates
 * @version     1.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly
}

global $post_options, $post, $post_class;

if ( $post_options )
    extract($post_options, EXTR_PREFIX_SAME, "ntt");

$color = Yolo__Timetable__Class::get_color_by_category(get_the_ID());
$class_color = str_replace('#', 'class_category_', $color);

$price          = yolo_timetable_get_post_meta( get_the_ID(), "_price", '' );
$lesson         = yolo_timetable_get_post_meta( get_the_ID(), "_lesson",'');
$class_size     = yolo_timetable_get_post_meta( get_the_ID(), "_class_size",'');
$open_time      = yolo_timetable_get_post_meta( get_the_ID(), "_open_time", '' );
$close_time     = yolo_timetable_get_post_meta( get_the_ID(), "_close_time", '' );

$layout_style = YOLO_Settings()->get_option('yolo_classes_style', 'grid');
$columns = YOLO_Settings()->get_option('yolo_classes_grid_columns', 2);

if ( $layout_style == 'list' ) {
    $columns = 1;
}
                            
$mansory_filter_class = array();
$mansory_filter_class[] = $class_color;
$mansory_filter_class[] = $post_class;
foreach ( (array) get_the_terms($post->ID,'class_category') as $cat ) {
    if ( empty($cat->slug ) )
        continue;
    $mansory_filter_class[] =  'filter-cat-'.$cat->term_id;
}
foreach ( (array) get_the_terms($post->ID,'class_level') as $level ) {
    if ( empty($level->slug ) )
        continue;
    $mansory_filter_class[] =  'filter-level-'.$level->term_id;
}

$teacher = (array) yolo_timetable_json_decode( yolo_timetable_get_post_meta( get_the_ID(), '_teacher') );
foreach ($teacher as $teacher_id) {
    $mansory_filter_class[]='filter-teacher-'.$teacher_id;
}

foreach ((array)yolo_timetable_json_decode( yolo_timetable_get_post_meta( get_the_ID(), "_number_day", '' ) ) as $dayindex){
    $mansory_filter_class[] = 'filter-day-'.$dayindex;
}

$thumbnail = get_the_post_thumbnail_url(get_the_ID());
empty($thumbnail) ? $thumbnail = get_template_directory_uri() . '/assets/images/placeholder.jpg' : $thumbnail;

?>
<article <?php post_class($mansory_filter_class); ?>>
    <div class="loop-item-wrap">
        <div class="content-meta">
            <?php if(!empty( $open_time ) && !empty( $close_time ) ) : ?>
                <span class="meta-time">
                    <?php echo date_i18n(get_option('time_format'),$open_time).' - '. date_i18n(get_option('time_format'),$close_time); ?>
                </span>
            <?php endif;?>
            <?php 
                $cat_ids = get_the_terms(get_the_ID(),'class_category', 1);
                $class_tr    = '';
                $thumb_id = get_term_meta( $cat_ids[0]->term_id, 'thumbnail_id', true ); ?>
                <div class="thumbnail <?php echo esc_attr( $class_tr ); ?>">
                    <?php  echo wp_get_attachment_image ( $thumb_id, 'thumbnail'); ?>
                </div>
                <?php 
            ?>
        </div>
        <a class="featured-link" href="<?php the_permalink(); ?>" aria-hidden="true" >
            <div class="loop-item-featured">
                <div class="item-featured-bg" style="background-image: url('<?php echo esc_url($thumbnail); ?>')">
                </div>
            </div>
        </a>

        <div class="loop-item-content">

            <div class="loop-item-price">
                <span>
                    <?php if( !empty($price )): ?>
                        <?php echo esc_attr($price); ?></span>
                    <?php else: ?>
                        <?php echo esc_html__(' Free', 'yolo-giraffe') ?>
                    <?php endif; ?>
            </div>
            <div class="loop-item-content-summary">
                <h4 class="title">
                    <a href="<?php the_permalink(); ?>" title="<?php echo esc_attr( sprintf( wp_kses( esc_html__( 'Permanent link to: "%s"', 'yolo-giraffe' ), yolo_timetable_allowed_html() ), the_title_attribute( 'echo=0' ) ) ); ?>"><?php the_title(); ?></a>
                </h4>

                <div class="entry-meta meta">
                    <?php if(!empty($lesson)): ?>
                        <span class="class-lesson"><i class="far fa-file-alt"></i><?php echo esc_html($lesson); ?><?php echo esc_html_e(' Lessons', 'yolo-giraffe') ?></span>
                    <?php endif; ?>
                    <?php if(!empty($class_size)): ?>
                        <span class="class-size"><i class="far fa-user"></i><?php echo esc_html($class_size); ?><?php echo esc_html_e(' Students', 'yolo-giraffe') ?></span>
                    <?php endif; ?>
                </div>

                <div class="course-meta meta">
                    <i class="fas fa-user-tie"></i><?php 
                    $teacher_ids = yolo_get_post_meta(get_the_ID(),'_teacher',true);
                    if( !empty( $teacher_ids )):
                        foreach ($teacher_ids as $k => $teid) :
                            ?>
                            <a href="<?php echo get_permalink($teid)?>"><?php echo get_the_title($teid)?></a>
                            <?php if ( ($k+1) < count($teacher_ids) ) echo ','; ?>
                        <?php
                        endforeach;
                    endif; ?>
                </div>

                <div class="entry-meta-more">
                    <div class="nbi__readmore">
                        <a class="icon-btn btn-readmore-wrap" href="<?php the_permalink(); ?>">
                            <h6 class="m0 text btn-readmore btn-readmore-heading">
                                <?php esc_html_e('Enroll Now', 'yolo-giraffe') ?>
                            </h6>
                        </a>

                    </div>
                </div>

            </div>
        </div>
    </div>
</article>