<?php
/**
 * The template for displaying event content within loops
 *
 * This template can be overridden by copying it to yourtheme/yolo-timetable/content-event.php.
 *
 * @author      YoloTheme
 * @package     YoloTimetable/Templates
 * @version     1.0.0
 */

if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly
}

global $post_options, $post, $layout_style,$post_class;

if ($post_options)
    extract($post_options, EXTR_PREFIX_SAME, "ntt");

$color = get_post_meta(get_the_ID(), "_yolo_event_bg_color", '#fff');
$class_color = str_replace('#', 'event_', $color);
$post_class = 'event-item';

$thumbnail = get_the_post_thumbnail_url($post->ID);
empty($thumbnail) ? $thumbnail = get_template_directory_uri() . '/assets/images/placeholder.jpg' : $thumbnail;
$event_time = yolo_timetable_get_post_meta($post->ID, "_yolo_event_start_date", '');
if (!empty($event_time)) {
    $month = date_i18n('M', $event_time);
    $date = date_i18n('j', $event_time);
}
$add = Yolo__Timetable__Event::address();
$form = Yolo__Timetable__Event::start_time();
$to = Yolo__Timetable__Event::end_time();
$price = Yolo__Timetable__Event::show_price();
if (isset($item_style)) {

}


if ($layout_style == 'slider') {
    $columns = '';
}
$layout = 'layout-' . $columns;

$post_columns = '';

if( $layout_style == 'grid'){
    $post_columns = 'col-sm-6 col-md-6 col-lg-'.absint((12 / $columns));
}

$mansory_filter_class = array();
$mansory_filter_class[] = $class_color;
$mansory_filter_class[] = $post_class;
$mansory_filter_class[] = $layout;
$mansory_filter_class[] = $post_columns;
foreach ( (array) get_the_terms($post->ID,'event_category') as $cat ) {
    if ( empty($cat->slug ) )
        continue;
    $mansory_filter_class[] =  'filter-cat-'.$cat->term_id;
}
$event_organizers = (array) yolo_timetable_json_decode( yolo_timetable_get_post_meta( get_the_ID(), '_yolo_event_organizers') );
foreach ($event_organizers as $event_organizer_id) {
    $mansory_filter_class[]='filter-organizer-'.$event_organizer_id;
}
?>

<article <?php post_class($mansory_filter_class); ?>>
    <div class="loop-item-wrap">
        <a class="featured-link" href="<?php echo get_post_permalink($post->ID); ?>" title="<?php echo the_title(); ?>">
            <div class="loop-item-featured">
                <div class="item-featured-bg" style="background-image: url('<?php echo esc_url($thumbnail); ?>')">
                </div>
                <?php if (!empty($event_time)): ?>
                    <div class="date" style="color: <?php echo rand_color('hex') ?>">
                        <span><?php echo esc_attr($date); ?></span><br>
                        <span><?php echo esc_attr($month); ?></span>
                    </div>
                <?php endif; ?>
            </div>
        </a>
        <div class="evi__content loop-item-content">
            <div class="evi__title item-title">
                <span class="location">
                        <?php if (!empty($add)): ?>
                            <i class="fas fa-map-marker-alt"></i>
                            <?php echo esc_attr($add); ?>
                        <?php endif; ?>
                </span>
                <h4 class="title">
                    <a href="<?php echo get_post_permalink($post->ID); ?>"><?php echo the_title(); ?></a>
                </h4>
            </div>
            <div class="item-meta">
                <div class="time">
                    <span class="schedule"><i class="far fa-clock"></i>
                        <span class="time__event"><?php echo esc_attr($form) . ' - ' . esc_attr($to) ?></span>
                    </span>
                </div>
                    <div class="price">
                        <span><?php echo esc_attr($price); ?></span>
                    </div>
            </div>
        </div>
    </div>
</article>