<?php
/**
 * The template for displaying event content within loops
 *
 * This template can be overridden by copying it to yourtheme/yolo-timetable/content-event.php.
 *
 * @author      YoloTheme
 * @package     YoloTimetable/Templates
 * @version     1.0.0
 */

if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly
}

global $post_options, $post ,$columns, $post_class;
if ($post_options)
    extract($post_options, EXTR_PREFIX_SAME, "ntt");

$color = get_post_meta(get_the_ID(), "_yolo_event_bg_color", '#fff');
$class_color = str_replace('#', 'event_', $color);
$post_class = $post_class .' '.'event-item';

$thumbnail = get_the_post_thumbnail_url($post->ID);
empty($thumbnail) ? $thumbnail = get_template_directory_uri() . '/assets/images/placeholder.jpg' : $thumbnail;
$event_time = yolo_timetable_get_post_meta($post->ID, "_yolo_event_start_date", '');
if (!empty($event_time)) {
    $month = date_i18n('M', $event_time);
    $date = date_i18n('j', $event_time);
}
$add = Yolo__Timetable__Event::address();
$form = Yolo__Timetable__Event::start_time();
$to = Yolo__Timetable__Event::end_time();
$price = Yolo__Timetable__Event::show_price();
isset($item_style) ? $item_style = '1' : '';
$layout = 'layout-1' . $columns;
?>

<article <?php post_class($post_class . ' ' . $layout); ?>>
    <div class="evi__wrap">
        <a target="_blank" href="<?php echo get_post_permalink($post->ID); ?>">
            <div class="evi__thumbnail" style="background-image: url('<?php echo esc_url($thumbnail); ?>')">
                <?php if (!empty($event_time)): ?>
                    <div class="evi__date" style="color: <?php echo rand_color('hex') ?>">
                        <span><?php echo esc_attr($date) ?></span><br>
                        <span><?php echo esc_attr($month) ?></span>
                    </div>
                <?php endif; ?>
            </div>
        </a>
        <div class="evi__content">
            <div class="evi__title">
                <small class="fs-8r c-grey">
                    <?php if (!empty($add)): ?>
                        <i class="fas fa-map-marker-alt"></i>
                        <?php echo esc_attr($add); ?>
                    <?php endif; ?>
                </small>
                <h3 class="mt-0 mb-1">
                    <a target="_blank" href="<?php echo get_post_permalink($post->ID); ?>"><?php echo the_title(); ?></a>
                </h3>
            </div>
            <div class="evi__meta">
                <div class="evi__time">
                <span class="schedule"><i class="fa fa-clock-o"></i>
                    <?php echo esc_attr($form) . ' - ' . esc_attr($to) ?>
                </span>
                </div>
                <div class="evi__price">
                    <span><?php esc_html_e('FROM ', 'yolo-giraffe'); ?></span>
                    <span class="price"><?php echo esc_attr($price); ?></span>
                </div>
            </div>
        </div>
    </div>
</article>